@@ -1,6 +1,4 @@
 #include "awards.h"
-
-
 /***************************************************************************
                           awards.cpp  -  description
                              -------------------
@@ -9,20 +7,20 @@
     email                : jaime@robles.es
  ***************************************************************************/
 /*****************************************************************************
- * This file is part of KLog.                                             *
+ * This file is part of KLog.                                                *
  *                                                                           *
- *    KLog is free software: you can redistribute it and/or modify         *
+ *    KLog is free software: you can redistribute it and/or modify           *
  *    it under the terms of the GNU General Public License as published by   *
  *    the Free Software Foundation, either version 3 of the License, or      *
  *    (at your option) any later version.                                    *
  *                                                                           *
- *    KLog is distributed in the hope that it will be useful,             *
+ *    KLog is distributed in the hope that it will be useful,                *
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.       *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
@@ -109,7 +107,7 @@ QString Awards::getQSOofAward (const int _enti, const int _bandid)
         }
     }
     else
-    {        
+    {
         emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
         query.finish();
            //qDebug() << "Awards::getQSOofAward: Query error" << endl;
@@ -174,11 +172,11 @@ int Awards::getDXCCWorked(const int _logNumber)
 
     if (dataProxy->doesThisLogExist(_logNumber))
     {
-        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log WHERE dxcc>'0' AND lognumber='%1'").arg(_logNumber);
+        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log WHERE dxcc>'0' AND dxcc < '1000' AND lognumber='%1'").arg(_logNumber);
     }
     else
     {
-        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log WHERE dxcc>'0'");
+        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log WHERE dxcc>'0' AND dxcc < '1000' ");
     }
 
 
@@ -201,7 +199,7 @@ int Awards::getDXCCWorked(const int _logNumber)
         }
     }
     else
-    {        
+    {
         emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
         query.finish();
            //qDebug() << "Awards::getDXCCWorked: Query error" << endl;
@@ -212,16 +210,19 @@ int Awards::getDXCCWorked(const int _logNumber)
 int Awards::getDXCCConfirmed(const int _logNumber)
 {
      //qDebug() << "Awards::getDXCCConfirmed (logNumber): " << QString::number(_logNumber) << endl;
+
+    return dataProxy->getFieldInBand (DXCC, "ALL", true, "ALL", _logNumber);
+    /*
     QSqlQuery query;
     QString stringQuery;
     bool sqlOK;
     if (dataProxy->doesThisLogExist(_logNumber))
     {
-        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log where (qsl_rcvd='Y' OR lotw_qsl_rcvd='Y') AND dxcc!='' AND dxcc >'0' AND lognumber='%1'").arg(_logNumber);
+        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log where (qsl_rcvd='Y' OR lotw_qsl_rcvd='Y') AND dxcc!='' AND dxcc >'0' AND dxcc < '1000' AND lognumber='%1'").arg(_logNumber);
     }
     else
     {
-        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log where (qsl_rcvd='Y' OR lotw_qsl_rcvd='Y') AND dxcc!='' AND dxcc >'0'");
+        stringQuery = QString("SELECT COUNT (DISTINCT dxcc) FROM log where (qsl_rcvd='Y' OR lotw_qsl_rcvd='Y') AND dxcc!='' AND dxcc >'0' AND dxcc < '1000' ");
     }
 
     sqlOK = query.exec(stringQuery);
@@ -252,7 +253,7 @@ int Awards::getDXCCConfirmed(const int _logNumber)
       return 0;
     }
 
-
+    */
 }
 
 int Awards::getWAZWorked(const int _logNumber)
@@ -354,7 +355,7 @@ bool Awards::isThisSpotConfirmed(const QStringList &_qs)
 int Awards::getDXStatus (const QStringList &_qs)
 {
 
-       //qDebug() << "Awards::getDXStatus: Entity: " << _qs.at(0) << "/ Band: " << _qs.at(1) << "/ Mode: " << _qs.at(2)  << "/ Log: " << _qs.at(3)  <<  endl;
+    //qDebug() << "Awards::getDXStatus: Entity: " << _qs.at(0) << "/ Band: " << _qs.at(1) << "/ Mode: " << _qs.at(2)  << "/ Log: " << _qs.at(3)  <<  endl;
     // Receives:  QStringList _qs;
     //_qs << Entity << BandId << << ModeId << lognumber;
 
@@ -406,24 +407,20 @@ int Awards::getDXStatus (const QStringList &_qs)
     int _mode = _qs.at(2).toInt();
     int _logNumber = _qs.at(3).toInt();
     int dxccEntity = (_qs.at(0)).toInt();
-    //int dxccEntity = world->getQRZARRLId(_qs.at(0) );
-       //qDebug() << "Awards::getDXStatus: dxccEntity: " << QString::number(dxccEntity) << endl;
+
+    //qDebug() << "Awards::getDXStatus: dxccEntity: " << QString::number(dxccEntity) << endl;
     if (dxccEntity<=0)
     {
-           //qDebug() << "Awards::getDXStatus: dxccEntity <= 0, return -1" << endl;
+        //qDebug() << "Awards::getDXStatus: dxccEntity <= 0, return -1" << endl;
         return -1;
     }
 
-
-
-
     bool checkingMode = true;
     if ( (_mode==-1) || (manageModes==false))
     {
         checkingMode = false;
-          //qDebug() << "Awards::getDXStatus: checkingMode = FALSE" << endl;
+        //qDebug() << "Awards::getDXStatus: checkingMode = FALSE" << endl;
     }
-    // dxccStatusMode(const int _ent, const int _mode, const int _logNumber) //-1 error / 0 Not worked / 1 worked / 2 confirmed
 
     int wb = dxccStatusBand(dxccEntity, _band, _logNumber); //-1 error / 0 Not worked / 1 worked / 2 confirmed
     int wm = -1;
@@ -438,13 +435,13 @@ int Awards::getDXStatus (const QStringList &_qs)
         checkingMode = false;
     }
 
-       //qDebug() << "Awards::getDXStatus: wb=" << QString::number(wb) << " - wm=" << QString::number(wm) << endl;
-       //qDebug() << "Awards::getDXStatus: dxccStatus: " << QString::number(dxccStatus(dxccEntity, _logNumber)) << endl;
+    //qDebug() << "Awards::getDXStatus: wb=" << QString::number(wb) << " - wm=" << QString::number(wm) << endl;
+    //qDebug() << "Awards::getDXStatus: dxccStatus: " << QString::number(dxccStatus(dxccEntity, _logNumber)) << endl;
 
     switch(dxccStatus(dxccEntity, _logNumber))
     {
     case 0:
-           //qDebug() << "Awards::getDXStatus: return 0" << endl;
+        //qDebug() << "Awards::getDXStatus: return 0" << endl;
         return 0;                   // ATNO
         //break;
     case 1:                         // Worked, not confirmed
@@ -455,18 +452,18 @@ int Awards::getDXStatus (const QStringList &_qs)
             {
                 if (wm==1)
                 {
-                       //qDebug() << "Awards::getDXStatus: return 4" << endl;
+                    //qDebug() << "Awards::getDXStatus: return 4" << endl;
                     return 4;
                 }
                 else
                 {
-                       //qDebug() << "Awards::getDXStatus: return 1" << endl;
+                    //qDebug() << "Awards::getDXStatus: return 1" << endl;
                     return 1;
                 }
             }
             else
             {
-                   //qDebug() << "Awards::getDXStatus: return 4 nc" << endl;
+                //qDebug() << "Awards::getDXStatus: return 4 nc" << endl;
                 return 4;
             }
         case 1:                     // Worked in this band
@@ -474,7 +471,7 @@ int Awards::getDXStatus (const QStringList &_qs)
             {
                 if (wm==1)
                 {
-                       //qDebug() << "Awards::getDXStatus: return 3" << endl;
+                    //qDebug() << "Awards::getDXStatus: return 3" << endl;
                     return 3;
                 }
                 else
@@ -569,21 +566,21 @@ int Awards::getDXStatus (const QStringList &_qs)
         }
         else
         {
-               //qDebug() << "Awards::getDXStatus: return -1 - 2" << endl;
+            //qDebug() << "Awards::getDXStatus: return -1 - 2" << endl;
             return -1;
         }
     default:
-           //qDebug() << "Awards::getDXStatus: return -1 default2" << endl;
+        //qDebug() << "Awards::getDXStatus: return -1 default2" << endl;
         return -1;
     }   // END OF SWITCH
-       //qDebug() << "Awards::getDXStatus: END, return -1" << endl;
+    //qDebug() << "Awards::getDXStatus: END, return -1" << endl;
     //return -1;
 }
 
 
 int Awards::dxccStatusBandMode(const int _ent, const int _band, const int _mode, const int _logNumber, bool _checkingMode)
 {//-1 error / 0 Not worked / 1 worked / 2 confirmed
-       //qDebug() << "Awards::dxccStatusBandMode: " << QString::number(_ent) << "/" << QString::number(_band) << "/" << QString::number(_mode) << endl;
+    //qDebug() << "Awards::dxccStatusBandMode: " << QString::number(_ent) << "/" << QString::number(_band) << "/" << QString::number(_mode) << endl;
     QSqlQuery query = QSqlQuery();
     QString queryString = QString();
 
@@ -695,13 +692,9 @@ int Awards::dxccStatus(const int _ent, const int _logNumber)
 QColor Awards::getQRZDXStatusColor(const QStringList &_qs)
 {
     //qs << Entity << spotBand << "-1" << QString::number(currentLog) ;
-
-
-       //qDebug() << "Awards::getQRZDXStatusColor qs.length: " << QString::number(_qs.length()) << endl;
+    //qDebug() << "Awards::getQRZDXStatusColor qs.length: " << QString::number(_qs.length()) << endl;
 
     //From Search QSO to QSL: q << _call << bandid << _mode << QString::number(currentLog);
-
-
     //qDebug() << "Awards::getQRZDXStatusColor: " << _qs.at(0) << "/" << _qs.at(1) << "/" << _qs.at(2) << _qs.at(3) << endl;
     // Receives:  QStringList _qs;
     //_qs << Entity << BandID << ModeId << lognumber;
@@ -1052,7 +1045,7 @@ void Awards::setColors (const QString &_newOne, const QString &_needed, const QS
         newOneColor.setNamedColor(_newOne.toUpper());
     }
     else
-    {     
+    {
     }
 
     if (workedColor.isValid())
@@ -1078,7 +1071,7 @@ void Awards::recalculateAwards()
     Should go in a transaction
 */
 
-       //qDebug() << "Awards::recalculateAwards" << endl;
+    //qDebug() << "Awards::recalculateAwards" << endl;
     dataProxy->updateAwardDXCC();
     emit awardDXCCUpdated();
     dataProxy->updateAwardWAZ();
@@ -1229,9 +1222,9 @@ int Awards::setAwardDXCCst(const int _dxcc, const int _band, const int _mode, co
             }
             else
             { // Something failed. Trace it!
-                emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());                
+                emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
                 errorCode = query.lastError().number();
-                query.finish();                
+                query.finish();
                 return -1;
 
             }
@@ -1494,7 +1487,7 @@ bool Awards::isDXMarathonNeed(const int _dxcc, const int _cq, const int _year, c
 int Awards::dxccStatusBand(const int _ent, const int _band, const int _logNumber) //-1 error / 0 Not worked / 1 worked / 2 confirmed
 {
     //-1 error / 0 Not worked / 1 worked / 2 confirmed
-          //qDebug() << "Awards::dxccStatusBand: " << QString::number(_ent) << "/" << QString::number(_band) << endl;
+    //qDebug() << "Awards::dxccStatusBand: " << QString::number(_ent) << "/" << QString::number(_band) << endl;
 
         QSqlQuery query = QSqlQuery();
         QString queryString = QString();
