@@ -1,3 +1,29 @@
+/***************************************************************************
+                          awardswidget.cpp  -  description
+                             -------------------
+    begin                : nov 2019
+    copyright            : (C) 2019 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "awardswidget.h"
 
 AwardsWidget::AwardsWidget(DataProxy_SQLite *dp, QWidget *parent) :
@@ -5,8 +31,8 @@ AwardsWidget::AwardsWidget(DataProxy_SQLite *dp, QWidget *parent) :
 {
       //qDebug() << "AwardsWidget::AwardsWidget"   << endl;
     manageDXMarathon = false;
-    logSeverity = 7;  //7 Debug /0=emergency or no debug
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    logSeverity = Info;  //7 Debug /0=emergency or no debug
+    emit debugLog (Q_FUNC_INFO, "Start", Debug);
     currentLog = -1;
 
     dxccConfirmedQLCDNumber = new QLCDNumber;
@@ -37,7 +63,7 @@ AwardsWidget::AwardsWidget(DataProxy_SQLite *dp, QWidget *parent) :
 
     clear();
     createUI();
-    emit debugLog (Q_FUNC_INFO, "End", logSeverity);
+    emit debugLog (Q_FUNC_INFO, "END", Debug);
        //qDebug() << "AwardsWidget::AwardsWidget - END"   << endl;
 }
 
@@ -48,7 +74,7 @@ AwardsWidget::~AwardsWidget()
 
 void AwardsWidget::clear()
 {
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    emit debugLog (Q_FUNC_INFO, "Start", Debug);
       //qDebug() << "AwardsWidget::clear"   << endl;
     /*
     searchBoxLineEdit->clear();
@@ -57,7 +83,7 @@ void AwardsWidget::clear()
     searchSelectAllClicked = false;
     */
 
-    emit debugLog (Q_FUNC_INFO, "End", logSeverity);
+    emit debugLog (Q_FUNC_INFO, "END", Debug);
       //qDebug() << "AwardsWidget::clear-END"   << endl;
 }
 
@@ -66,7 +92,7 @@ void AwardsWidget::createUI()
 {
     //searchBoxClearButton->setToolTip(tr("Clear the searches."));
       //qDebug() << "AwardsWidget::createUI"   << endl;
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    emit debugLog (Q_FUNC_INFO, "Start", Debug);
 
     recalculateAwardsButton = new QPushButton(tr("Recalculate"), this);
     recalculateAwardsButton->setToolTip(tr("Click to recalculate the award status."));
@@ -226,7 +252,7 @@ void AwardsWidget::createUI()
     connect(operatingYearsComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotOperatingYearComboBoxChanged() ) ) ;
     connect(recalculateAwardsButton, SIGNAL(clicked()), this, SLOT(slotRecalculateAwardsButtonClicked() ) );
 
-    emit debugLog (Q_FUNC_INFO, "End", logSeverity);
+    emit debugLog (Q_FUNC_INFO, "END", Debug);
       //qDebug() << "AwardsWidget::createUI-END"   << endl;
 }
 
@@ -251,7 +277,7 @@ void AwardsWidget::slotSearchClearButtonClicked()
 
 void AwardsWidget::setToolTips()
 {
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    emit debugLog (Q_FUNC_INFO, "Start", Debug);
     dxccConfirmedQLCDNumber->setToolTip(tr("Number of confirmed DXCC entities."));
     dxccWorkedQLCDNumber->setToolTip(tr("Number of worked DXCC entities."));
     wazConfirmedQLCDNumber->setToolTip(tr("Number of confirmed WAZ zones."));
@@ -267,24 +293,24 @@ void AwardsWidget::setToolTips()
     yearlyScoreQLCDNumber->setToolTip(tr("Score for the DXMarathon in the selected year."));
     operatingYearsComboBox->setToolTip(tr("Select the year you want to check."));
 
-    emit debugLog (Q_FUNC_INFO, "End", logSeverity);
+    emit debugLog (Q_FUNC_INFO, "END", Debug);
 }
 
 void AwardsWidget::slotRecalculateAwardsButtonClicked()
 {
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    emit debugLog (Q_FUNC_INFO, "Start", Debug);
     awards->recalculateAwards();
     //emit recalculateAwardsSignal();
     showAwards();
-    emit debugLog (Q_FUNC_INFO, "End", logSeverity);
+    emit debugLog (Q_FUNC_INFO, "END", Debug);
 }
 
 void AwardsWidget::slotOperatingYearComboBoxChanged()
 {
-    emit debugLog (Q_FUNC_INFO, "Start", logSeverity);
+    emit debugLog (Q_FUNC_INFO, "Start", Debug);
     selectedYear = (operatingYearsComboBox->currentText()).toInt();
     showDXMarathon(selectedYear);
-    emit debugLog (Q_FUNC_INFO, "End", logSeverity);
+    emit debugLog (Q_FUNC_INFO, "END", Debug);
 }
 
 void AwardsWidget::showAwards()
@@ -323,16 +349,17 @@ void AwardsWidget::showAwards()
     }
 
     qsoConfirmedQLCDNumber->display(_num);
-    _num = 0;
+    //_num = 0;
 
-    dxccWorkedQLCDNumber->display(awards->getDXCCWorked(currentLog));
-    _num = 0;
+    dxccWorkedQLCDNumber->display(dataProxy->getFieldInBand (DXCC, "ALL", false, "ALL", currentLog));
+    int getFieldInBand(ValidFieldsForStats _field, const QString _band, bool confirmedOnly, QString _mode = "ALL", int _log=-1);_num = 0;
 
-    dxccConfirmedQLCDNumber->display(awards->getDXCCConfirmed(currentLog));
-    _num = 0;
+
+    dxccConfirmedQLCDNumber->display(dataProxy->getFieldInBand (DXCC, "ALL", true, "ALL", currentLog));
+    //_num = 0;
 
     wazWorkedQLCDNumber->display(awards->getWAZWorked(currentLog));
-    _num = 0;
+    //_num = 0;
 
     wazConfirmedQLCDNumber->display(awards->getWAZConfirmed(currentLog));
 
