@@ -1,3 +1,29 @@
+/***************************************************************************
+                          statscqzperyearbarchatwidget.cpp  -  description
+                             -------------------
+    begin                : oct 2018
+    copyright            : (C) 2018 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "charts/statscqzperyearbarchartwidget.h"
 
 
@@ -10,11 +36,9 @@ StatsCQZPerYearBarChartWidget::StatsCQZPerYearBarChartWidget(DataProxy_SQLite *d
     dataProxy = dp;
     chart = new QChart();
     chartView = new QChartView(chart);
-    //chart->setTheme(QChart::ChartThemeQt);
-    //chart->setTheme(QChart::ChartThemeBlueCerulean);
 
     createUI();
-    prepareChart();
+    //prepareChart();
 }
 
 void StatsCQZPerYearBarChartWidget::createUI()
@@ -29,7 +53,7 @@ void StatsCQZPerYearBarChartWidget::createUI()
     setLayout(graphLayout);
 }
 
-void StatsCQZPerYearBarChartWidget::prepareChart()
+void StatsCQZPerYearBarChartWidget::prepareChart(const int _log)
 {
 
     QString categoriesTitle;
@@ -53,14 +77,14 @@ void StatsCQZPerYearBarChartWidget::prepareChart()
     progress.setWindowModality(Qt::WindowModal);
 
        //qDebug() << "StatsCQZPerYearBarChartWidget::prepareChart: SelectedGrapth-1: YEARS " << endl;
-     categories.append(dataProxy->getOperatingYears(-1));
+     categories.append(dataProxy->getOperatingYears(_log));
      categoriesElem = tr("CQ zones");
      categoriesTitle = tr("CQ zones per year");
 
      aux.clear();
     for (int i = 0; i < categories.count();i++ )
     {
-        numberPerX = dataProxy->getCQzonYear((categories.at(i)).toInt(), -1);
+        numberPerX = dataProxy->getCQzonYear((categories.at(i)).toInt(), _log);
         //numberPerX = dataProxy->getQSOonYear((categories.at(i)).toInt(), -1);
            //qDebug() << categories.at(i) + "-" + QString::number(numberPerX) << endl;
         *set0 << numberPerX;
