@@ -1,3 +1,28 @@
+/***************************************************************************
+                          statsentitiesperyearbarchatwidget.cpp  -  description
+                             -------------------
+    begin                : oct 2018
+    copyright            : (C) 2018 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
 #include "charts/statsentitiesperyearbarchartwidget.h"
 
 
@@ -12,7 +37,7 @@ StatsEntitiesPerYearBarChartWidget::StatsEntitiesPerYearBarChartWidget(DataProxy
     chartView = new QChartView(chart);
 
     createUI();
-    prepareChart();
+    //prepareChart();
 }
 
 void StatsEntitiesPerYearBarChartWidget::createUI()
@@ -27,7 +52,7 @@ void StatsEntitiesPerYearBarChartWidget::createUI()
     setLayout(graphLayout);
 }
 
-void StatsEntitiesPerYearBarChartWidget::prepareChart()
+void StatsEntitiesPerYearBarChartWidget::prepareChart(const int _log)
 {
 
     QString categoriesTitle;
@@ -53,13 +78,13 @@ void StatsEntitiesPerYearBarChartWidget::prepareChart()
 
        //qDebug() << "StatsEntitiesPerYearBarChartWidget::prepareChart: SelectedGrapth-1: YEARS " << endl;
        //qDebug() << "BarChartStats::prepareChart: SelectedGrapth-2: DXCC " << endl;
-        categories.append(dataProxy->getOperatingYears(-1));
+        categories.append(dataProxy->getOperatingYears(_log));
         categoriesElem = tr("DXCC Entities");
         categoriesTitle = tr("DXCC Entities per year");
         aux.clear();
         for (int i = 0; i < categories.count();i++ )
         {
-            numberPerX = dataProxy->getDXCConYear((categories.at(i)).toInt(), -1);
+            numberPerX = dataProxy->getDXCConYear((categories.at(i)).toInt(), _log);
             *set0 << numberPerX;
             numberPerX = 0;
 
