@@ -1,3 +1,29 @@
+/***************************************************************************
+                          statsqsosperbandbarchatwidget.cpp  -  description
+                             -------------------
+    begin                : nov 2018
+    copyright            : (C) 2018 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "charts/statsqsosperbandbarchartwidget.h"
 
 
@@ -12,7 +38,7 @@ StatsQSOsPerBandBarChartWidget::StatsQSOsPerBandBarChartWidget(DataProxy_SQLite
     chartView = new QChartView(chart);
 
     createUI();
-    prepareChart();
+    //prepareChart();
 }
 
 void StatsQSOsPerBandBarChartWidget::createUI()
@@ -27,7 +53,7 @@ void StatsQSOsPerBandBarChartWidget::createUI()
     setLayout(graphLayout);
 }
 
-void StatsQSOsPerBandBarChartWidget::prepareChart()
+void StatsQSOsPerBandBarChartWidget::prepareChart(const int _log)
 {
 
     QString categoriesTitle;
@@ -52,14 +78,14 @@ void StatsQSOsPerBandBarChartWidget::prepareChart()
     progress.setWindowModality(Qt::WindowModal);
 
        //qDebug() << "StatsQSOsPerBandBarChartWidget::prepareChart: SelectedGrapth-1: YEARS " << endl;
-     categories.append(dataProxy->getBandsInLog(-1));
+     categories.append(dataProxy->getBandsInLog(_log));
      categoriesElem = tr("Bands");
      categoriesTitle = tr("QSOs per band distribution");
 
      aux.clear();
     for (int i = 0; i < categories.count();i++ )
     {
-        numberPerX = dataProxy->getQSOsInBand((categories.at(i)), -1);
+        numberPerX = dataProxy->getQSOsInBand((categories.at(i)), _log);
            //qDebug() << categories.at(i) + "-" + QString::number(numberPerX) << endl;
         *set0 << numberPerX;
         numberPerX = 0;
