@@ -1,3 +1,28 @@
+/***************************************************************************
+                          statsqsospercontinentbarchatwidget.cpp  -  description
+                             -------------------
+    begin                : nov 2018
+    copyright            : (C) 2018 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
 #include "charts/statsqsospercontinentbarchartwidget.h"
 
 
@@ -12,7 +37,7 @@ StatsQSOsPerContinentBarChartWidget::StatsQSOsPerContinentBarChartWidget(DataPro
     chartView = new QChartView(chart);
 
     createUI();
-    prepareChart();
+    //prepareChart();
 }
 
 void StatsQSOsPerContinentBarChartWidget::createUI()
@@ -27,7 +52,7 @@ void StatsQSOsPerContinentBarChartWidget::createUI()
     setLayout(graphLayout);
 }
 
-void StatsQSOsPerContinentBarChartWidget::prepareChart()
+void StatsQSOsPerContinentBarChartWidget::prepareChart(const int _log)
 {
 
     QString categoriesTitle;
@@ -62,7 +87,7 @@ void StatsQSOsPerContinentBarChartWidget::prepareChart()
      aux.clear();
      for (int i = 0; i < categories.count(); i++ )
      {
-         numberPerX = dataProxy->getQSOsWithContinent(categories.at(i), -1);
+         numberPerX = dataProxy->getQSOsWithContinent(categories.at(i), _log);
             //qDebug() << "BarChartStats::prepareChart SelectedGrapth-7: QSO/hour: " << categories.at(i) << " - " << QString::number(numberPerX) << endl;
          *set0 << numberPerX;
          numberPerX = 0;
