@@ -1,3 +1,29 @@
+/***************************************************************************
+                          statsqsosperdxccbarchatwidget.cpp  -  description
+                             -------------------
+    begin                : nov 2018
+    copyright            : (C) 2018 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "charts/statsqsosperdxccbarchartwidget.h"
 
 
@@ -12,7 +38,7 @@ StatsQSOsPerDXCCBarChartWidget::StatsQSOsPerDXCCBarChartWidget(DataProxy_SQLite
     chartView = new QChartView(chart);
 
     createUI();
-    prepareChart();
+   // prepareChart();
 }
 
 void StatsQSOsPerDXCCBarChartWidget::createUI()
@@ -27,7 +53,7 @@ void StatsQSOsPerDXCCBarChartWidget::createUI()
     setLayout(graphLayout);
 }
 
-void StatsQSOsPerDXCCBarChartWidget::prepareChart()
+void StatsQSOsPerDXCCBarChartWidget::prepareChart(const int _log)
 {
 
     QString categoriesTitle;
@@ -37,7 +63,7 @@ void StatsQSOsPerDXCCBarChartWidget::prepareChart()
     QBarCategoryAxis *axis = new QBarCategoryAxis();
     QString aux;
 
-    int numberPerX = 0;
+    //int numberPerX = 0;
     chart->removeAllSeries();
     categoriesTitle = QString();
     categoriesElem = QString();
@@ -61,13 +87,29 @@ void StatsQSOsPerDXCCBarChartWidget::prepareChart()
        //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart: SelectedGrapth-1: YEARS " << endl;
 
      QMap<int, int> map; // key,value = number of QSO, dxcc
-     int qsos = -1;
+     //int qsos = -1;
      map.clear();
      aux.clear();
 
+     QList<QList<int>> data;
+     data.clear();
+    data <<  dataProxy->getTop10QSOPerDXCC(_log);
+    //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart: Length: " << QString::number(data.length()) << endl;
+
+    foreach(QList<int> pair, data)
+    {
+        map.insert(pair.at(0), pair.at(1));
+        //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart:Pair(0): " << QString::number(pair.at(0)) << endl;
+        //qDebug() << "StatsQSOsPerDXCCBarChartWidget::prepareChart:Pair(1): " << QString::number(pair.at(1)) << endl;
+        categories.append(dataProxy->getEntityMainPrefix(pair.at(0)) + " (" + QString::number(pair.at(1)) + ")");
+        set0->append(pair.at(1));
+        //*set0 << pair.at(1);
+    }
+
+    /*
      for (int i = 0; i < entities.size(); ++i)
      {
-         qsos = dataProxy->getQSOsWithDXCC((entities.at(i)).toInt(), -1);
+         qsos = dataProxy->getQSOsWithDXCC((entities.at(i)).toInt(), _log);
          if (qsos>0)
          {
                 //qDebug() << "Checking: " << dataProxy->getEntityNameFromId((entities.at(i)).toInt()) << " - " << entities.at(i) << " - QSOs: " << QString::number(qsos) ;
@@ -103,11 +145,13 @@ void StatsQSOsPerDXCCBarChartWidget::prepareChart()
          }
          //qDebug() << "End of for iteration" << endl;
      }
-
+    */
+    /*
      QMapIterator<int, int> it(map);
      while (it.hasNext()) {
          it.next();
          categories.append(dataProxy->getEntityMainPrefix(it.value()));
+         //qDebug() << "While iteration: " << dataProxy->getEntityMainPrefix(it.value()) << endl;
 
          numberPerX = it.key();
          *set0 << numberPerX;
@@ -115,7 +159,7 @@ void StatsQSOsPerDXCCBarChartWidget::prepareChart()
             //qDebug() << "End of while iteration" << endl;
      }
         //qDebug() << "Out of while" << endl;
-
+    */
      categoriesElem = tr("DXCC");
      categoriesTitle = tr("Top ten DXCC per QSO");
 
