@@ -1,3 +1,29 @@
+/***************************************************************************
+                          statsqsospermodebarchatwidget.cpp  -  description
+                             -------------------
+    begin                : nov 2018
+    copyright            : (C) 2018 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "charts/statsqsospermodebarchartwidget.h"
 
 
@@ -12,7 +38,7 @@ StatsQSOsPerModeBarChartWidget::StatsQSOsPerModeBarChartWidget(DataProxy_SQLite
     chartView = new QChartView(chart);
 
     createUI();
-    prepareChart();
+    //prepareChart();
 }
 
 void StatsQSOsPerModeBarChartWidget::createUI()
@@ -27,7 +53,7 @@ void StatsQSOsPerModeBarChartWidget::createUI()
     setLayout(graphLayout);
 }
 
-void StatsQSOsPerModeBarChartWidget::prepareChart()
+void StatsQSOsPerModeBarChartWidget::prepareChart(const int _log)
 {
 
     QString categoriesTitle;
@@ -52,14 +78,14 @@ void StatsQSOsPerModeBarChartWidget::prepareChart()
     progress.setWindowModality(Qt::WindowModal);
 
        //qDebug() << "StatsQSOsPerModeBarChartWidget::prepareChart: SelectedGrapth-1: MODES " << endl;
-     categories.append(dataProxy->getModesInLog(-1));
+     categories.append(dataProxy->getModesInLog(_log));
      categoriesElem = tr("Modes");
      categoriesTitle = tr("QSOs per mode distribution");
 
      aux.clear();
     for (int i = 0; i < categories.count();i++ )
     {
-        numberPerX = dataProxy->getQSOsInMode((categories.at(i)), -1);
+        numberPerX = dataProxy->getQSOsInMode((categories.at(i)), _log);
            //qDebug() << categories.at(i) + "-" + QString::number(numberPerX) << endl;
         *set0 << numberPerX;
         numberPerX = 0;
