@@ -1,3 +1,29 @@
+/***************************************************************************
+                          statsqsosperyearbarchatwidget.cpp  -  description
+                             -------------------
+    begin                : oct 2018
+    copyright            : (C) 2018 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "charts/statsqsosperyearbarchartwidget.h"
 
 
@@ -12,7 +38,7 @@ StatsQSOsPerYearBarChartWidget::StatsQSOsPerYearBarChartWidget(DataProxy_SQLite
     chartView = new QChartView(chart);
 
     createUI();
-    prepareChart();
+    //prepareChart();
 }
 
 void StatsQSOsPerYearBarChartWidget::createUI()
@@ -27,7 +53,7 @@ void StatsQSOsPerYearBarChartWidget::createUI()
     setLayout(graphLayout);
 }
 
-void StatsQSOsPerYearBarChartWidget::prepareChart()
+void StatsQSOsPerYearBarChartWidget::prepareChart(const int _log)
 {
 
     QString categoriesTitle;
@@ -44,22 +70,21 @@ void StatsQSOsPerYearBarChartWidget::prepareChart()
     categories.clear();
     axis->clear();
     series->clear();
-    QBarSet *set0 = new QBarSet(tr("Chart title"));
+    QBarSet *set0 = new QBarSet(tr("QSOs per year"));
 
     //*set0->remove(0, set0->count()-1);
     qreal sum = 0;
     QProgressDialog progress(tr("Reading data ... "), tr("Abort reading"), 0, categories.count(), this);
     progress.setWindowModality(Qt::WindowModal);
 
-       //qDebug() << "StatsQSOsPerYearBarChartWidget::prepareChart: SelectedGrapth-1: YEARS " << endl;
-     categories.append(dataProxy->getOperatingYears(-1));
+     categories.append(dataProxy->getOperatingYears(_log));
      categoriesElem = tr("QSOs");
      categoriesTitle = tr("QSOs per year");
 
      aux.clear();
     for (int i = 0; i < categories.count();i++ )
     {
-        numberPerX = dataProxy->getQSOonYear((categories.at(i)).toInt(), -1);
+        numberPerX = dataProxy->getQSOonYear((categories.at(i)).toInt(), _log);
            //qDebug() << categories.at(i) + "-" + QString::number(numberPerX) << endl;
         *set0 << numberPerX;
         numberPerX = 0;
