@@ -40,9 +40,7 @@
 #include "utilities.h"
 
 class QSqlRelationalTableModel;
-// Previous db update 0.011
-
-const float DBVersionf = 0.019f; // This is the latest version of the DB.
+const float DBVersionf = 0.022f; // This is the latest version of the DB.
 
 
 struct AwarddxccEntry
@@ -167,6 +165,9 @@ private:
     bool updateTo017(); // Merges the qso_date & time_on fields
     bool updateTo018(); // Creates Subdivision
     bool updateTo019(); // Adds FTS4 and FST4W modes and RS-44 satellite
+    //bool updateTo020(); // Adds Q65 mode
+    bool updateTo021(); // Adds 5M & 8M bands
+     bool updateTo022(); // Recovers the 020 that was not executed and adds the Q65 mode
 
     bool updateTableLog(const int _v);
     bool updateDBVersion(QString _softV, QString _dbV);
@@ -192,6 +193,7 @@ private:
     bool createTableBand(const bool NoTmp);
     bool populateTableBand(const bool NoTmp);
     bool recreateTableBand();
+    bool syncLogQSOsOnBandTableChange();
 
     bool recreateTableDXCC();
     bool createTableAwardDXCC();
@@ -199,7 +201,7 @@ private:
     bool createTableAwardWAZ();
 
     bool createTableSubdivision(const bool NoTmp);
-    
+
     bool recreateSatelliteData();
     bool createTableSatellites(const bool NoTmp);
     bool populateTableSatellites(const bool NoTmp);
