@@ -31,6 +31,7 @@
 #include <QObject>
 #include "database.h"
 #include "qso.h"
+#include "klogdefinitions.h"
 //#include "regionalaward.h"
 
 //Class QSO;
@@ -48,10 +49,9 @@ class DataProxy_SQLite : public QObject
 
 public:
 
-    DataProxy_SQLite(const QString &_parentFunction, const QString &_softVersion = "0");
+    DataProxy_SQLite(const QString &_parentFunction, const QString &_softVersion="0.0");
     ~DataProxy_SQLite();
 
-
     QString getSoftVersion();
     QString getDBVersion();
     bool reconnectDB();
@@ -92,6 +92,7 @@ public:
 
     double getLowLimitBandFromBandName(const QString &_sm);
     double getLowLimitBandFromBandId(const int _sm);
+    double getUpperLimitBandFromBandName(const QString &_sm);
     bool isThisFreqInBand(const QString &_band, const QString &_fr);
 
     int getLastQSOid();
@@ -104,17 +105,19 @@ public:
                           const QString &_comment,
                           const QString &_stationcallsign, const QString &_name, const QString &_operator,
                           const QDateTime &_datetime, const QDateTime &_datetime_off, const double txpower,
-                          const int _dxcc, const int _logNumber);
+                          const int _dxcc, const int _logNumber, bool _sendQSL = true);
 
     int addQSOFromLoTW(const QString &_call, const QDateTime _datetime, const QString &_mode, const QString &_band, const double _freq, const QDate _qslrdate, const QString &_stationcallsign, const int _logn);
     int addQSO(QSO &_qso);
 
     bool deleteQSO(const int _qsoId);
     int isWorkedB4(const QString &_qrz, const int _currentLog);
-    QList<int> isThisQSODuplicated(const QString &_qrz, const QDateTime &_dateTime, const int _band, const int _mode);
+    QList<int> isThisQSODuplicated(const QString &_callingFunc, const QString &_qrz, const QDateTime &_dateTime, const int _band, const int _mode, const int _secs);
     int getDuplicatedQSOId(const QString &_qrz, const QDateTime &_datetime, const int _band, const int _mode);
     bool isDXCCConfirmed(const int _dxcc, const int _currentLog);
     bool isQSLReceived(const int _qsoId);
+    bool isQSLLoTWReceived(const int _qsoId);
+    bool isQSOConfirmed(const int _qsoId, const bool _checkPaper, const bool _checkLoTW);
     bool isQSLSent(const int _qsoId);
 
     bool qslSentViaDirect(const int _qsoId, const QDate &_updateDate);
@@ -137,6 +140,8 @@ public:
     int getModeFromId(const int _qsoId);
     int getDXCCFromId(const int _qsoId);
     int getCQZFromId(const int _qsoId);
+    QList<int> getBandModeDXCCCQZlogIDFromId(const int _qsoId);
+
     QString getCallFromId(const int _qsoId);
     QStringList getClubLogRealTimeFromId(const int _qsoId);
     // Complete with previous
@@ -193,6 +198,7 @@ public:
     QString getEntityNameFromId(const int _n);
     int getEntityIdFromName(const QString &_e);
     QString getEntityMainPrefix(const int _entityN);
+    QStringList getEntiNameAndPrefixFromId(const int _dxcc);
     int getEntityIdFromMainPrefix(const QString &_e);
     bool isNewCQz(int _c);
     bool isNewEntity(int _e);
@@ -230,8 +236,10 @@ public:
     int getQSOsInBand(const QString &_band, const int _log);
     int getQSOsInMode(const QString &_mode, const int _log);
 
-    // Stats - end
+    QList<QList<int>> getTop10QSOPerDXCC(const int _log);
 
+    // Stats - end
+    bool updateQSONumberPerLog();
 
     bool newDXMarathon(const int _dxcc, const int _cq, const int _year, const int _logNumber);
 
@@ -251,7 +259,7 @@ public:
     bool clearSatList();
     bool addSatellite(const QString &_arrlId, const QString &_name, const QString &_downLink, const QString &_upLink, const QString &_mode, int id = -1);
     int getDBSatId(const QString &_arrlId);
-    QStringList getSatellitesList();   
+    QStringList getSatellitesList();
     QString getSatelliteUplink(const QString &_sat);
     QString getSatelliteDownlink(const QString &_sat);
     QString getSatelliteMode(const QString &_sat);
@@ -295,6 +303,11 @@ public:
     QString getADIFQSO(const int _qsoId);
     bool showInvalidCallMessage(const QString &_call);
 
+    QList<QSO*> getSatGridStats(int _log=-1);
+
+    QList<QSO*> getGridStats(int _log=-1);
+    QList<QSO*> getSatDXCCStats(int _log=-1);
+    int getFieldInBand(ValidFieldsForStats _field, const QString _band, bool confirmedOnly, QString _mode = "ALL", int _log=-1);
     //bool queryPrepare(const QString &_query);
     //bool queryBind(const QString &_field, const QString &value);
     //bool queryExec();
@@ -315,12 +328,12 @@ private:
     //QSqlQuery preparedQuery;
     //QSqlRelationalTableModel *logModel;
 private slots:
-    void slotCaptureDebugLogs(const QString &_func, const QString &_msg, const int _level=7);
+    void slotCaptureDebugLogs(const QString &_func, const QString &_msg, const DebugLogLevel _level=Info);
 
 signals:
     void qsoFound(const QStringList _qs); // Each: QString with format: Fieldname:value
     void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
-    void debugLog(QString functionFailed, QString errorCode, int level); // emitted as the KLog application log
+    void debugLog(QString functionFailed, QString errorCode, DebugLogLevel level); // emitted as the KLog application log
 
 };
 
