@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 #include <QWidget>
@@ -33,6 +33,7 @@
 #include "world.h"
 #include "dataproxy_sqlite.h"
 #include "locator.h"
+#include "klogdefinitions.h"
 
 
 //TODO: Creating the widget to show the DXCC status
@@ -43,10 +44,10 @@ class DXCCStatusWidget : public QWidget
 public:
     explicit DXCCStatusWidget(DataProxy_SQLite *dp, const QString &_parentFunction, QWidget *parent = nullptr);
     ~DXCCStatusWidget();
-    
-    void update();    
+
+    void update();
     //void awardsUpdated();
-    void setBands(const QStringList &_ent, const bool _creating = false); // Receives the list of bandIDs
+    void setBands(const QString &_callingFunc, const QStringList &_ent, const bool _creating = false); // Receives the list of bandIDs
     void setCurrentLog(const int _logN);
     void setMyLocator(const QString &_loc);
 
@@ -55,6 +56,7 @@ public:
 signals:
     //void showQso(const int _qsoid); // identified QSO double clicking on DXCC
     void showQsos(QList<int> _qsos);
+    void debugLog (QString _func, QString _msg, DebugLogLevel _level);
     //void updateAwards();
 
 public slots:
@@ -85,7 +87,7 @@ private:
     QHeaderView *hv, *hh;
     //QLineEdit *searchLineEdit;
     QPushButton *refreshButton;
-    //QRadioButton *showAllLogsButton;
+    //QCheckBox *showAllLogsButton;
 
 
     int numberOfColumns; // Columns will be number Of Bands + 2 (Id + Name)
