@@ -23,6 +23,7 @@ email                : jaime@robles.es
 *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
 *                                                                           *
 *****************************************************************************/
+#include <QFont>
 #include "dxcluster.h"
 
 DXClusterWidget::DXClusterWidget(DataProxy_SQLite *dp, QWidget *parent)
@@ -121,7 +122,7 @@ void DXClusterWidget::initClass()
     showann = true;
     showwwv = true;
     showwcy = true;
-    saveSpots = false;    
+    saveSpots = false;
     myQrz = QString();
     currentLog = 0;
     saveSpotsFile->setFileName(util->getSaveSpotsLogFile());
@@ -347,6 +348,8 @@ void DXClusterWidget::slotClusterDataArrived()
     {
         dxClusterString =  tcpSocket->readLine();
         dxClusterString = dxClusterString.trimmed();
+        // Remove BELL-string if exists
+        dxClusterString = dxClusterString.remove("\a");
         saveSpot(dxClusterString);
 
         QStringList tokens = dxClusterString.split(" ", QString::SkipEmptyParts);
@@ -447,6 +450,7 @@ void DXClusterWidget::slotClusterDataArrived()
 
         QListWidgetItem *item = new QListWidgetItem();
         item->setForeground(QBrush(dxSpotColor));
+        item->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
         item->setText(dxClusterString);
 
 /*
@@ -555,13 +559,21 @@ void DXClusterWidget::slotClusterSendToServer()
         connectToDXCluster();
         return; // If we try to connect...
     }
-    if ( inputCommand ->text().length() < 1 )
+    if (( inputCommand ->text().length() < 1 ) && ( sendButton->text() == tr("Disconnect") ) )
     {
-           //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Vacio..." << endl;
+
+        //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Disconnecting" << endl;
         QTextStream os(tcpSocket);
         os << "bye\n";
         return;
     }
+    else if ( inputCommand ->text().length() < 1 )
+    {
+        //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Empty" << endl;
+        return;
+    }
+
+
     //  write to the server
     QTextStream os(tcpSocket);
     os << inputCommand ->text() << "\n";
@@ -572,22 +584,7 @@ void DXClusterWidget::slotClusterClearLineInput()
 {
        //qDebug() << "DXClusterWidget::slotClusterClearLineInput" << endl;
 
-    if ( ((inputCommand->text()).length()) <= 0 )
-    {
-        if ( dxClusterConnected )
-        {
-            QTextStream os(tcpSocket);
-            os << "bye\n";
-        }
-        else
-        {
-        }
-    }
-    else
-    {
-        inputCommand->clear();
-    }
-
+    inputCommand->clear();
 }
 
 void DXClusterWidget::slotClusterInputTextChanged()
@@ -698,7 +695,7 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
     if (item) {
 
         fields.clear();
-        dxClusterString = ((item->data(0)).toString()).simplified();        
+        dxClusterString = ((item->data(0)).toString()).simplified();
         fields << dxClusterString.split(" ");
 
         (fields.at(0)).toFloat(&FirstFrecOK); // Just to see if the first string is a frecuency
@@ -728,7 +725,7 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
                 }
             }
             else
-            { // The call is not from a valid country
+            { // The callsign is not from a valid country
               // TODO: if it is from a new entity/prefix it would not work.
                    //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Entity not valid"  << endl;
                 dxCallsign.clear();
@@ -784,7 +781,7 @@ bool DXClusterWidget::openFile()
     {
         return true;
     }
-    if (!saveSpotsFile->open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Append))
+    if (!saveSpotsFile->open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Append)) /* Flawfinder: ignore */
     {
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Warning);
