@@ -1,3 +1,29 @@
+/***************************************************************************
+                          elogclublog.cpp  -  description
+                             -------------------
+    begin                : feb 2015
+    copyright            : (C) 2015 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "elogclublog.h"
 #include <QCoreApplication>
 #include <QUrl>
@@ -692,7 +718,7 @@ void eLogClubLog::sendLogFile(const QString &_file, QList<int> _qso, bool _overw
 
     //QFile *file = new QFile("_file");
     QFile *file = new QFile(util->getClubLogFile());
-    if (file->open(QIODevice::ReadOnly))
+    if (file->open(QIODevice::ReadOnly))        /* Flawfinder: ignore */
     {
          blob = file->readAll();
 
