@@ -1,3 +1,29 @@
+/***************************************************************************
+                          elogqrzlog.cpp  -  description
+                             -------------------
+    begin                : nov 2020
+    copyright            : (C) 2020 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "elogqrzlog.h"
 #include <QCoreApplication>
 #include <QUrl>
@@ -547,7 +573,7 @@ int eLogQrzLog::sendQSO(const int _qsoID)
     QByteArray postData;
 
     postData = params.query(QUrl::FullyEncoded).toUtf8();
-    params.setQuery(postData);    
+    params.setQuery(postData);
 
     QNetworkRequest requestLog(QUrl("https://logbook.qrz.com/api"));
     requestLog.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
@@ -610,7 +636,7 @@ void eLogQrzLog::login()
     QUrlQuery params;
 
     params.addQueryItem("username", user);
-    params.addQueryItem("password", pass);    
+    params.addQueryItem("password", pass);
     params.addQueryItem("agent", util->getGlobalAgent(klogVersion));
     sendDataParams(params);
 
@@ -623,7 +649,7 @@ void eLogQrzLog::login()
 }
 
 int eLogQrzLog::sendDataParams(const QUrlQuery &_params)
-{     
+{
     //qDebug()<< "eLogQrzLog::sendDataParams: Params: " << _params.query(QUrl::FullyEncoded).toUtf8() << endl;
 
     QByteArray postData;
