@@ -1,6 +1,32 @@
 #ifndef HAMLIBCLASS_H
 #define HAMLIBCLASS_H
 
+/***************************************************************************
+                          hamlibclass.h  -  description
+                             -------------------
+    begin                : oct 2020
+    copyright            : (C) 2020 by Jaime Robles
+    user                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include <QObject>
 #include <QTimer>
 #include <QMap>
@@ -11,6 +37,14 @@
 #include <unistd.h>
 #include <stdlib.h>
 
+// Potential fix of hamlib 4.2 migration
+#ifndef HAMLIB_FILPATHLEN
+#define HAMLIB_FILPATHLEN FILEPATHLEN
+#endif
+
+#ifndef FILPATHLEN
+#define FILPATHLEN 100
+#endif
 
 
 class HamLibClass : public QObject
@@ -38,13 +72,14 @@ public:
     void setMode(const QString &_m);
     void setReadOnly(const bool _r);
     bool isModeADIFMode(const QString &_m);
-
+    void setNetworkAddress(const QString &_address);
+    void setNetworkPort(const int _port);
    // bool isModeExisting(const QString &_m);
 
 
-    void init(bool _active);
-    void stop();
-    void readRadio(bool _forceRead);
+    bool init(bool _active);
+    bool stop();
+    bool readRadio(bool _forceRead);
     bool isRunning();
     void clean();
     void checkErrorCountAndStop();
@@ -61,10 +96,10 @@ public slots:
     void slotTimer();
 
 private:
-    void readRadioInternal(bool _forceRead);
+    bool readRadioInternal(bool _forceRead);
     static int addRigToList(const struct rig_caps* caps, void* data);
     QString hamlibMode2Mode(rmode_t _rmode);
-    rmode_t mode2HamlibMode(const QString &_m);
+    //rmode_t mode2HamlibMode(const QString &_m);
     QStringList strings;
     QTimer *timer;
     QMap<QString, rig_model_t> rigName2RigId;
@@ -96,6 +131,8 @@ private:
     QString flowControl;            // default QSerialPort::NoFLowControl
     QString parity;                 // default QSerialPort::NoParity
     QString serialPort;
+    QString networkAddress;
+    int networkPort;
     int pollInterval;           // Poll interval in mSecs
     int errorCount;            // Number of times that the rig has returned an error since last time OK.
     bool rigLaunched;
