@@ -1,3 +1,29 @@
+/***************************************************************************
+                          infowidget.h  -  description
+                             -------------------
+    begin                : ago 2017
+    copyright            : (C) 2017 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "infowidget.h"
 
 InfoWidget::InfoWidget(DataProxy_SQLite *dp, QWidget *parent) :
@@ -337,13 +363,13 @@ void InfoWidget::setImperialSystem (const  bool _imp)
 
 QString InfoWidget::getStyleColorToLabelFromBand(const QString _b, const QString _q)
 { // Receives band name, Entity number (as a String)
-       //qDebug() << "InfoWidget::getStyleColorToLabelFromBand: " << _b << "/" << _q << endl;
+   //qDebug() << "InfoWidget::getStyleColorToLabelFromBand: " << _b << "/" << _q << endl;
    QStringList _qs;
     _qs.clear();
 
     _qs << _q << QString::number(dataProxy->getIdFromBandName(_b)) << QString::number(-1) << QString::number(currentLog);
     //TODO: Check if we can know the mode and replace the -1
-       //qDebug() << "InfoWidget::getStyleColorToLabelFromBand (Band/background-color): " << _b << (awards->getQRZDXStatusColor(_qs)).name()  << endl;
+    //qDebug() << "InfoWidget::getStyleColorToLabelFromBand (Band/background-color): " << _b << (awards->getQRZDXStatusColor(_qs)).name()  << endl;
     return "* { background-color: " + (awards->getQRZDXStatusColor(_qs)).name() + "; }";
 }
 
@@ -351,8 +377,8 @@ QString InfoWidget::getStyleColorToLabelFromBand(const QString _b, const QString
 //void InfoWidget::showInfo(const int _entity, const int _bandid, const int _modeid, const int _log)
 void InfoWidget::showInfo(const int _entity)
 { // Default values of _modeid & _log = -1
-       //qDebug() << "InfoWidget::showInfo: " << QString::number(_entity) << endl;
- //QColor getQRZDXStatusColor(const QStringList _qs); // Receives Entity, band, mode & log
+    //qDebug() << "InfoWidget::showInfo: " << QString::number(_entity) << endl;
+    //QColor getQRZDXStatusColor(const QStringList _qs); // Receives Entity, band, mode & log
 
     bandLabel1->setStyleSheet(getStyleColorToLabelFromBand(bandLabel1->text(), QString::number(_entity)));
     bandLabel2->setStyleSheet(getStyleColorToLabelFromBand(bandLabel2->text(), QString::number(_entity)));
@@ -370,7 +396,7 @@ void InfoWidget::showInfo(const int _entity)
 
 void InfoWidget::showEntityInfo(const int _enti, int _cq, int _itu)
 {
-     //qDebug() << "InfoWidget::showEntityInfo" << QString::number(_enti) << endl;
+    //qDebug() << "InfoWidget::showEntityInfo" << QString::number(_enti) << endl;
 
     if (_enti<=0)
     {
