@@ -42,7 +42,6 @@ LogWindow::LogWindow(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent)
     currentLog = -1;
     //proxyModel = new LogViewSortFilterProxyModel(this);
 
-
     awards = new Awards(dataProxy, Q_FUNC_INFO);
 
     createUI();
@@ -84,7 +83,7 @@ void LogWindow::createUI()
 void LogWindow::setDefaultData()
 {
 
-       //qDebug() << "LogWindow::setDefaultData"  << endl;    
+       //qDebug() << "LogWindow::setDefaultData"  << endl;
 }
 
 
@@ -184,7 +183,7 @@ void LogWindow::slotRighButtonFromLog(const QPoint& pos)
     QModelIndexList list = select->selectedRows();
 
     if (select->hasSelection() && (list.length()>1) )
-    {       
+    {
         rightButtonMultipleFromLogMenu();
     }
     else
@@ -302,7 +301,8 @@ void LogWindow::slotDoubleClickLog(const QModelIndex & index)
 bool LogWindow::isQSLReceived(const int _qsoId)
 {
        //qDebug() << "LogWindow::isQSLReceived: " << QString::number(_qsoId) << endl;
-    return dataProxy->isQSLReceived(_qsoId);
+    return dataProxy->isQSOConfirmed(_qsoId, true, false); // We check just paper QSL
+    //return dataProxy->isQSLReceived(_qsoId);
 }
 
 bool LogWindow::isQSLSent(const int _qsoId)
@@ -492,7 +492,7 @@ void LogWindow::deleteQSO(const int _qsoID)
 
     //logModel->removeRow((delQSOFromLogAct->data()).toInt()); //TODO: This has been replaced by the previous line
     //awards->recalculateAwards();
-    refresh();       
+    refresh();
     //dxccStatusWidget->refresh();
     emit updateAwards();
     emit updateSearchText();
