@@ -1,3 +1,29 @@
+/***************************************************************************
+                          lotwutilities.cpp  -  description
+                             -------------------
+    begin                : apr 2020
+    copyright            : (C) 2020 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "lotwutilities.h"
 #include <QCoreApplication>
 #include <QUrl>
@@ -10,7 +36,7 @@ LoTWUtilities::LoTWUtilities(const QString &_klogDir, const QString &_klogVersio
    //qDebug() << "LoTWUtilities::LoTWUtilities(): " << _klogDir << endl;
     dataProxy = dp;
     calendar = new QCalendarWidget;
-    util = new Utilities;    
+    util = new Utilities;
     manager = new QNetworkAccessManager(this);
 
     reply = nullptr;
@@ -112,39 +138,42 @@ bool LoTWUtilities::setStationCallSign(const QString &_call)
     //qDebug() << "LoTWUtilities::setStationCallSign: " << _call << endl;
     if (!util->isValidCall(_call))
     {
-        //qDebug() << "LoTWUtilities::setStationCallSign: FALSE "  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign: FALSE 1"  << endl;
         return false;
     }
     if (((dataProxy->getStationCallSignsFromLog(-1)).contains(_call)))
     {
-       //qDebug() << "LoTWUtilities::setStationCallSign: TRUE"  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign: TRUE"  << endl;
         stationCallsign = _call;
         QDate date = dataProxy->getFirstQSODateFromCall(stationCallsign);
-       //qDebug() << "LoTWUtilities::setStationCallSign: Date: " << startDate  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign: Date: " << startDate  << endl;
         if (date.isValid())
         {
             startDate = date.toString("yyyyMMdd");
-            //qDebug() << "LoTWUtilities::setStationCallSign: StartDate" << startDate  << endl;
+             //qDebug() << "LoTWUtilities::setStationCallSign: StartDate" << startDate  << endl;
         }
         else
         {
             startDate.clear();
-            //qDebug() << "LoTWUtilities::setStationCallSign: StartDate not valid Date" << endl;
+             //qDebug() << "LoTWUtilities::setStationCallSign: StartDate not valid Date" << endl;
+             //qDebug() << Q_FUNC_INFO << "False 2 - END";
             return false;
         }
 
-       //qDebug() << "LoTWUtilities::setStationCallSign: startDate: " << startDate  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign: startDate: " << startDate  << endl;
+        //qDebug() << Q_FUNC_INFO << "True 1 - END";
         return true;
     }
     else if (dataProxy->getHowManyQSOInLog(-1) <1)
     {
-       //qDebug() << "LoTWUtilities::setStationCallSign:TRUE Empty log"  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign:TRUE Empty log"  << endl;
         stationCallsign = _call;
+        //qDebug() << Q_FUNC_INFO << "True 2 - END";
         return true;
     }
     else
     {
-       //qDebug() << "LoTWUtilities::setStationCallSign: Not a single QSO in the log with that StationCallsign: " << stationCallsign  << endl;
+        //qDebug() << "LoTWUtilities::setStationCallSign: Not a single QSO in the log with that StationCallsign: " << stationCallsign  << endl;
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Question);
         msgBox.setWindowTitle(tr("KLog - LoTW Station callsign"));
@@ -154,15 +183,17 @@ bool LoTWUtilities::setStationCallSign(const QString &_call)
         msgBox.setStandardButtons(QMessageBox::Yes|QMessageBox::No);
         msgBox.setDefaultButton(QMessageBox::Yes);
         int ret = msgBox.exec();
-        //qDebug() << "LoTWUtilities::download: - 13" << endl;
+
         if (ret == QMessageBox::Yes)
         {
             stationCallsign = _call;
+            //qDebug() << Q_FUNC_INFO << "True 3 - END";
             return true;
         }
         else
         {
-           //qDebug() << "LoTWUtilities::setStationCallSign: FALSE 2"  << endl;
+            //qDebug() << "LoTWUtilities::setStationCallSign: FALSE 2"  << endl;
+            //qDebug() << Q_FUNC_INFO << "FALSE 3 - END";
             return false;
         }
     }
@@ -232,7 +263,7 @@ int LoTWUtilities::download()
         }
         //qDebug() << "LoTWUtilities::download: - 23 Filename: -" << endl;
 
-      if (!file->open(QIODevice::WriteOnly))
+      if (!file->open(QIODevice::WriteOnly)) /* Flawfinder: ignore */
       {
           QMessageBox msgBox;
           msgBox.setIcon(QMessageBox::Warning);
@@ -293,8 +324,8 @@ int LoTWUtilities::fullDownload()
     QMessageBox msgBox;
     msgBox.setIcon(QMessageBox::Question);
     msgBox.setWindowTitle(tr("KLog - LoTW Start date selection"));
-    QString aux = QString(tr("This is the first date of a QSO with the call %1 in this log If you think that in LoTW you may have previous QSOs, answer No.").arg(stationCallsign) );
-    msgBox.setText(tr("Do you want to used this date (%1) as start date?").arg(startDate));
+    QString aux = QString(tr("This is the first date of a QSO with the callsign %1 in this log If you think that in LoTW you may have previous QSOs, answer No.").arg(stationCallsign) );
+    msgBox.setText(tr("Do you want to use this date (%1) as start date?").arg(startDate));
     msgBox.setDetailedText(aux);
     msgBox.setStandardButtons(QMessageBox::Yes|QMessageBox::No);
     msgBox.setDefaultButton(QMessageBox::Yes);
@@ -361,7 +392,7 @@ int LoTWUtilities::startThefullDownload()
        }
        //qDebug() << "LoTWUtilities::startThefulldownload: - 23 Filename: -" << endl;
 
-     if (!file->open(QIODevice::WriteOnly))
+     if (!file->open(QIODevice::WriteOnly)) /* Flawfinder: ignore */
      {
          QMessageBox msgBox;
          msgBox.setIcon(QMessageBox::Warning);
@@ -493,7 +524,7 @@ void LoTWUtilities::slotFinished()
         {
             url = newUrl;
             //reply->deleteLater();
-            file->open(QIODevice::WriteOnly);
+            file->open(QIODevice::WriteOnly); /* Flawfinder: ignore */
             file->resize(0);
             startRequest(url);
              //qDebug() << "LoTWUtilities::slotFinished - END-1" << endl;
@@ -555,7 +586,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
     QString aux;
 
     QFile file( _fileName );
-    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) /* Flawfinder: ignore */
     {
         //qDebug() << "LoTWUtilities::parseDownloadedFile File not found" << _fileName << endl;
         msgBox.setIcon(QMessageBox::Warning);
