@@ -1,4 +1,13 @@
- /* This file is part of KLog.                                               *
+/***************************************************************************
+                          main.cpp  -  description
+                             -------------------
+    begin                : sept 2011
+    copyright            : (C) 2011 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
  *                                                                           *
  *    KLog is free software: you can redistribute it and/or modify           *
  *    it under the terms of the GNU General Public License as published by   *
@@ -11,10 +20,11 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
+
 #include <QtWidgets>
 //#include <QtSql>
 #include <QTranslator>
@@ -22,6 +32,10 @@
 #include <QTextStream>
 #include <QCoreApplication>
 #include <QCommandLineParser>
+#include <QApplication>
+#include <QSystemSemaphore>
+#include <QSharedMemory>
+#include <QMessageBox>
 
 //#include <QDebug>
 
@@ -37,12 +51,14 @@ int main(int argc, char *argv[])
     //qDebug() << "KLog Main: " << QSslSocket::supportsSsl() << QSslSocket::sslLibraryBuildVersionString() << QSslSocket::sslLibraryVersionString() << endl;
     QT_REQUIRE_VERSION(argc, argv, "5.11")
     QDir d1 = QDir();
-    QString version = "1.4.6";
+    QString version = "1.7";
     //qDebug() << "KLog Main STARTED: " << version << endl;
     Utilities util = Utilities();
     QStringList arguments;
     QTextStream cout(stdout);
-
+    QCoreApplication::setOrganizationName("EA4K");
+    QCoreApplication::setOrganizationDomain("klog.xyz");
+    QCoreApplication::setApplicationName("KLog");
     QApplication app(argc, argv);
 
     QString iconSt;
@@ -96,7 +112,7 @@ int main(int argc, char *argv[])
     //qDebug() << "KLog Main: Detected language: " << (QLocale::system().name()).left(2) << ".qm" << endl;
     // Translations begin
     QTranslator qtTranslator;
-    qtTranslator.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+    qtTranslator.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)); /* Flawfinder: ignore */
     app.installTranslator(&qtTranslator);
     QTranslator myappTranslator;
 
@@ -106,15 +122,15 @@ int main(int argc, char *argv[])
     #if defined(Q_OS_WIN)
         //qDebug() << "KLog WIN " << endl;
         //qDebug() << "KLog Main: -20 - WIN" << endl;
-        if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") )
+        if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
-            myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm");
+            myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm"); /* Flawfinder: ignore */
         }
-        else if (QFile::exists(QDir::homePath()+"/klog/klog_" + (QLocale::system().name()).left(2)+ ".qm") )
+        else if (QFile::exists(QDir::homePath()+"/klog/klog_" + (QLocale::system().name()).left(2)+ ".qm") ) /* Flawfinder: ignore */
         {
-            myappTranslator.load(QDir::homePath()+"/klog/klog_" + (QLocale::system().name()));
+            myappTranslator.load(QDir::homePath()+"/klog/klog_" + (QLocale::system().name())); /* Flawfinder: ignore */
         }
-        else if (((QLocale::system().name()).left(2)) == "en")
+        else if (((QLocale::system().name()).left(2)) == "en") /* Flawfinder: ignore */
         { // If language is English, it will execute without showing message
         }
         else
@@ -126,37 +142,36 @@ int main(int argc, char *argv[])
     #elif defined(Q_OS_OSX)
     //qDebug() << "KLog OSX " << endl;
 
-        if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" +  (QLocale::system().name()).left(2) + ".qm") )
+        if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" +  (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
-            myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm");
+            myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm"); /* Flawfinder: ignore */
         }
-        else if (((QLocale::system().name()).left(2)) == "en")
+        else if (((QLocale::system().name()).left(2)) == "en") /* Flawfinder: ignore */
         { // If language is English, it will execute without showing message
 
         }
         else
         {
             missingTranslation = true;
-            //msgOSFilePath = QCoreApplication::applicationDirPath() + "/translations/" ;
         }
     #else
            //qDebug() << "KLog OTHER OS: " << (QLocale::system()).name() << endl;
-        if (QFile::exists("klog_" + (QLocale::system().name()).left(2) + ".qm") )
+        if (QFile::exists("klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
-            myappTranslator.load("klog_" + (QLocale::system().name()).left(2));
+            myappTranslator.load("klog_" + (QLocale::system().name()).left(2)); /* Flawfinder: ignore */
         }
-        else if (QFile::exists("/usr/share/klog/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") )
+        else if (QFile::exists("/usr/share/klog/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
-               //qDebug() << "KLog OTHER -2: " << "/usr/share/klog/klog_" + (QLocale::system().name()).left(2) << endl;
-            myappTranslator.load("/usr/share/klog/translations/klog_" + (QLocale::system().name()));
+               //qDebug() << "KLog OTHER -2: " << "/usr/share/klog/klog_" + (QLocale::system().name()).left(2) << endl; /* Flawfinder: ignore */
+            myappTranslator.load("/usr/share/klog/translations/klog_" + (QLocale::system().name()));  /* Flawfinder: ignore */
         }
-        else if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm"))
+        else if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm")) /* Flawfinder: ignore */
         {
             //qDebug() << "KLog OTHER -3: " << QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) << endl;
-            myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()));
+            myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name())); /* Flawfinder: ignore */
         }
 
-        else if (((QLocale::system().name()).left(2)) == "en")
+        else if (((QLocale::system().name()).left(2)) == "en") /* Flawfinder: ignore */
         { // If language is English, it will execute without showing message
 
         }
@@ -180,7 +195,7 @@ int main(int argc, char *argv[])
             msgBox.setWindowTitle("KLog");
             msgBox.setIcon(QMessageBox::Warning);
             msgBox.setTextFormat(Qt::RichText);
-            QString language = (QLocale::system().name()).left(2);
+            QString language = (QLocale::system().name()).left(2); /* Flawfinder: ignore */
 
             msg = QString("No translation files for your language have been found so KLog will be shown in English.") + "<p>" +
                   QString("If you have the klog_%1.qm file for your language, you can copy it into the %2/translations/ folder and restart KLog.</p><p>If you want to help to translate KLog into your language, please contact the author.").arg(language).arg(QCoreApplication::applicationDirPath()) +
@@ -199,6 +214,58 @@ int main(int argc, char *argv[])
     //qDebug() << "KLog Main: End of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss") << endl;
     // Traslations end
 
+    /* Application Singleton
+     *
+     * We want to run only one instance of KLog application
+     */
+    QSystemSemaphore semaphore("klogapp", 1);  // create semaphore with unique ID klogapp
+    semaphore.acquire();                       // Raise the semaphore, barring other instances to work with shared memory
+
+#ifndef Q_OS_WIN32
+    // in linux / unix shared memory is not freed when the application terminates abnormally,
+    // so you need to get rid of the garbage
+    QSharedMemory nix_fix_shared_memory("klogshm");
+
+    if (nix_fix_shared_memory.attach())
+    {
+        nix_fix_shared_memory.detach(); // if there is no running instance then it remove the orphaned shared memory
+    }
+#endif
+
+    QSharedMemory sharedMemory("klogshm");  // Create a copy of the shared memory - Unique ID klogshm
+    bool is_running;
+
+    /*
+     * trying to attach a copy of the shared memory to an existing segment
+     *
+     * if successful, it determines that there is already a running instance
+     * otherwise allocate 1 byte of memory and no instance is running
+     */
+    if (sharedMemory.attach())
+    {
+        is_running = true;
+    }
+    else
+    {
+        sharedMemory.create(1);
+        is_running = false;
+    }
+
+    semaphore.release();
+
+    // If you already run one instance of the application, then we inform the user about it
+    // and complete the current instance of the application
+    if (is_running)
+    {
+        QMessageBox msgBox;
+        msgBox.setIcon(QMessageBox::Warning);
+        msgBox.setText(QObject::tr("KLog is already running.") + "\n" + QObject::tr("It is allowed to run only one instance."));
+        msgBox.exec();
+        return 1;
+    }
+
+    // END OF Application Singleton
+
     QString configFileName, klogDir;
 
     klogDir = util.getHomeDir();
