@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
@@ -33,9 +33,12 @@
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <QtAlgorithms>
+#include <QDesktopServices>
+#include <QUrl>
 
 //#include "database.h"
 #include "setupdialog.h"
+#include "setuppages/setuppagemisc.h"
 //#include "helpaboutdialog.h"
 #include "aboutdialog.h"
 //#include "dxccsummarydialog.h"
@@ -50,12 +53,13 @@
 #include "locator.h"
 #include "dxcluster.h"
 #include "awards.h"
-#include "mainwindowsattab.h"
-#include "mainwindowmydatatab.h"
-#include "mainwindowinputcomment.h"
-#include "mainwindowinputothers.h"
-#include "mainwindowinputeqsl.h"
-#include "mainwindowinputqsl.h"
+#include "inputwidgets/mainwindowsattab.h"
+#include "inputwidgets/mainwindowmydatatab.h"
+#include "inputwidgets/mainwindowinputcomment.h"
+#include "inputwidgets/mainwindowinputothers.h"
+#include "inputwidgets/mainwindowinputeqsl.h"
+#include "inputwidgets/mainwindowinputqsl.h"
+#include "inputwidgets/mainwindowinputqso.h"
 #include "mainqsoentrywidget.h"
 #include "elogclublog.h"
 #include "utilities.h"
@@ -78,7 +82,10 @@
 #include "eqslutilities.h"
 #include "widgets/adiflotwexportwidget.h"
 #include "widgets/showadifimportwidget.h"
+//#include "widgets/advancedsearch/advancedsearchwidget.h"
 //#include "worldmapwidget.h"
+#include "widgets/showkloglogwidget.h"
+#include "qso.h"
 
 
 class QTimer;
@@ -102,10 +109,6 @@ class QGroupBox;
 class QTabWidget;
 class QFrame;
 class QTableView;
-
-
-
-
 class QLabel;
 
 
@@ -140,15 +143,15 @@ class MainWindow : public  QMainWindow
 
 public:
     MainWindow(const QString &_klogDir, const QString &tversion);
+    ~MainWindow();
     void checkIfNewVersion();
     void recommendBackupIfNeeded();
     void init();
 
-     ~MainWindow();
-
 private slots:
     //void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery);
     //void slotTest();        // Slot for testing purposes only
+    void slotOpenWiki();
     void slotAWAImport();
     void slotClearNoMorErrorShown();
     void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString queryFailed);
@@ -158,11 +161,11 @@ private slots:
     //void slotSRXTextChanged();
     //void slotSTXTextChanged();
     void slotUpdateLocator(QString _loc);
-    void slotLocatorTextChanged();
+    void slotLocatorTextChanged(const QString &_loc);
     //void slotMyLocatorTextChanged();
-    void slotFreqTXChanged();
-    void slotFreqRXChanged();
-    void slotSplitCLicked();
+    void slotFreqTXChanged(const double _fr);
+    void slotFreqRXChanged(const double _fr);
+    //void slotSplitCLicked();
 
     void slotSearchBoxTextChanged();
     //void slotCloseStats(bool _vis);
@@ -175,93 +178,77 @@ private slots:
     void slotToolLoTWMarkAllYesThisLog();
     void slotToolLoTWMarkAllYes();
     void slotLoTWDownloadedFileProcess(const QString &_fn);
-    //void slotLoTWTest();
 
     void slotClubLogLogUpload();
     void sloteQSLLogUpload();
     void slotElogEQSLModifyCurrentLog();
-    //void slotModeComboBoxChanged();
-    //void slotBandComboBoxChanged();
-    //void slotIOTAComboBoxChanged();
-    //void slotOperatingYearComboBoxChanged();
+
     void slotOKButtonClicked();
-    //void slotSpotItButtonClicked();
+
     void slotClearButtonClicked();
     void slotBandChanged (const QString &_b);
     void slotModeChanged (const QString &_m);
+    void slotValidBandsReceived(const QStringList &_b);
+
     void slotRefreshDXCCWidget();
-    //void slotUpdateTime();
+
     void slotLogWinShow();
     void slotLogRefresh();
-    //void slotScoreWinShow();
+
     void slotQSODelete(const int _id);
     void slotQSOsDelete(QList<int> _id);
     void slotQSOsExportToADIF(QList<int> _id);
     void slotQRZcomUpload(QList<int> _id);
     void slotQRZCOMLogUpload();
 
-
     void slotShowAwards();
     void slotUpdateStatusBar(const QString &statusm);
     void setMainWindowTitle(const QString _s);
     void slotSetup(const int _page=0);
 
-    //void slotrstTXTextChanged();
-    //void slotrstRXTextChanged();
     void slotADIFExport();
-    //void slotLoTWImport();
-    //void slotLoTWExport();
 
     void slotLoTWExport();
     void slotLoTWDownload();
     void slotLoTWFullDownload();
     void slotADIFExportSelection(const QString &_st, const QDate &_startDate, const QDate &_endDate, const ExportMode _eM);
-    //void slotADIFExportPeriod(const QString &_st, const QDate &_startDate, const QDate &_endDate, const ExportMode _eM);
 
     void slotADIFExportAll();
     void slotADIFImport();
     void slotRQSLExport();
     void slotReceiveQSOListToShowFromFile(QStringList _qs);
-    //void slotCabrilloExport();
-    //void slotQSLViaTextChanged();
+
     void slotTimeOutInfoBars(); // Clears the infoLabels when the timeout emits the signal
 
-    void slotSetPropMode(const QString &_p);
+    void slotSetPropModeFromOther(const QString &_p);
+    void slotSetPropModeFromSat(const QString &_p, bool _keep);
     void slotFillEmptyDXCCInTheLog();
     void slotUpdateCTYDAT();
     void slotUpdateSATSDAT();
     void slotShowStats();
-    //void slotShowDXCCSummary();
+
     void slotWorldReload(const bool _b);
 
     void slotExitFromSlotDialog(const int exitID);
     void slotSetupDialogFinished (const int _s);
     void exitQuestion();
 
-    //void slotDownloadFinished(QNetworkReply *reply);
 
     void fillQSOData();
 
-    //void newFile();
-    //void openFile();
-    //bool saveFile(const QString &_fileName);
-    //bool saveFileAs();
     bool slotOpenKLogFolder();
 
     void slotFilePrint();
     void slotFileClose();
 
-    //void slotHelpHelpAction();
     void slotHelpAboutAction();
     void slotHelpCheckUpdatesAction();
     void slotAboutQt();
     void slotTipsAction();
+    void slotDebugAction();
 
     // MainQSOEntryWidget
     void slotShowInfoLabel(const QString _m);
-    //void slotClearForNextQSO();
-    // To support AwardsWidget
-    //void slotRecalculateAwardsButtonClicked();
     void slotAwardsWidgetSetLog();
     void slotAwardsWidgetSetYear();
 
@@ -273,7 +260,7 @@ private slots:
     void slotDoubleClickLog( const int _qsoID);
     //void slotDoubleClickLog( const QModelIndex & index);
 
-    //SEARCH    
+    //SEARCH
     void slotShowSearchWidget();                // The SearchWidget request being shown
     //SEARCH
 
@@ -306,10 +293,6 @@ private slots:
     //SATELLITE
     //void slotSatBandTXComboBoxChanged(const QString _q);
     void slotDefineNewBands (const QStringList _bands);
-    void slotSatTXFreqNeeded(const double _f);
-    void slotSatRXFreqNeeded(const double _f);
-    void slotSatChangeRXFreq(const double _f);
-    void slotSatChangeTXFreq(const double _f);
 
     //HAMLIB
     void slotHamlibTXFreqChanged(const double _f);
@@ -336,29 +319,26 @@ private slots:
                      const QString &_opCall, const QDateTime &_datetime, const QDateTime &_datetime_off,
                      const QString &_exchangeTX, const QString &_exchangeRX, const QString &_mypwr);
 
-    //void slotWSJTXloggedQSO (const QString &_dxcall, const QString &_mode, const QString &band, const double _freq,
-    //                 const QString &mygrid, const QString &dxgrid, const QString &rstTX, const QString &rstRX, const QString &comment, const QString &stationcallsign,
-    //                 const QDateTime &datetime, const QDateTime &datetime_off);
+    void slotCaptureDebugLogs(const QString &_func, const QString &_msg, DebugLogLevel _level=Info);
+    //void slotTakeOverFocus(int _id);
+    void slotTakeOverFocusToQSOTabWidget();
+    void slotTakeOverFocusToMainQSOInput();
 
-
-
-    //void slotTipsFindQSL2QSO();
-    //void slotTipsFillInDXCC();
-    //void slotsTipsFillQSO();
-
-    void slotCaptureDebugLogs(const QString &_func, const QString &_msg, const int _level=7);
 private:
     //void setWidgetsOrder();
+    void startServices();
+    void backupCurrentQSO();
+    void restoreCurrentQSO(const bool restoreConfig);
     void showMessageToEnableTheOnlineService(const OnLineProvider _service);
     void cleanQRZCOMreceivedDataFromUI();
     void saveWindowsSize();
-    void setWindowsSize(const int _width, const int _height);
+    void setWindowSize(const QSize &_size);
     bool maybeSave();
     void setCleaning(const bool _c);
-
-    void logEvent(const QString &_func, const QString &_msg, const int _level=7);
-    void setSeverity(const int _sev);
-    void updateBandComboBox(const QString &_band);
+    bool setHamlib(const bool _b);
+    bool setUDPServer(const bool _b);
+    void logEvent(const QString &_func, const QString &_msg, const DebugLogLevel _level=Info);
+    void setSeverity(const DebugLogLevel _sev);
     void fileExportLoTW(const QString &_st, const QDate &_startDate, const QDate &_endDate);
     void fileExportClubLog(const QString &_st, const QDate &_startDate, const QDate &_endDate);
     void fileExportEQSL(const QString &_st, const QDate &_startDate, const QDate &_endDate);
@@ -370,10 +350,15 @@ private:
     //UPDATE CTY.DAT
     DownLoadCTY *downloadcty;
     HamLibClass *hamlib;
+    QSO *qso;
+
     bool hamlibActive;
     bool hamlibChangingMode;
     bool hamlibModeNotADIFSupported;
 
+    bool sendQSLByDefault;
+    bool deleteAlwaysAdiFile;
+
     // PST Rotator
     //PSTRotatorSupport *pstRotator;
     //bool usePSTRotator;
@@ -381,7 +366,7 @@ private:
     //</UPDATE CTY.DAT>
     //WorldMapWidget *worldMapWidget;
     void createStatusBar();
-    void createUI();    
+    void createUI();
     void createUIDX();
     void reconfigureDXMarathonUI(const bool _dxM);
     //void createDXClusterUI();
@@ -394,8 +379,8 @@ private:
 
     bool readCtyFile();
 
-    bool isQSLReceived(const int _qsoId);
-    bool isQSLSent(const int _qsoId);
+    //bool isQSLReceived(const int _qsoId);
+    //bool isQSLSent(const int _qsoId);
 
     //bool validCharactersInCall(const QString &_qrz); // Looks for SQLi and no valid chars in the QRZ
     QString readDataFromUI(); // Reads the QSO data from the UI and returns the SQL Query
@@ -403,7 +388,7 @@ private:
     QString readDataFromUIDXModifying();
     void actionsJustAfterAddingOneQSO();
     //void clearForNextQSO();
-    void clearUIDX(bool full=false); //full= false leaves some data to allow pileup or normal Dx in same band; full removes freqs and everything
+    void clearUIDX(bool _full = false); //full= false leaves the "keep this data"; full = true clears everything
 
     void setAwardDXCC(const int _qsoId, bool modifying); // Adds or modify the status of a DXCC entity
     // data << dxcc(id) << band(id) << mode(id) << confirmed(0/1) << qsoid(id) << modify(0/1);
@@ -417,8 +402,8 @@ private:
     void createData();
     void openSetup(const int _page=0);
     bool processConfigLine(const QString &_line);
-    void readConfigData();    
-    void defineStationCallsign();
+    void readConfigData();
+    void defineStationCallsign(const QString &_call);
     QString selectStationCallsign();
 
     void checkIfNewBandOrMode();
@@ -438,8 +423,8 @@ private:
     //void showAwards();
     //void showDXMarathon(const int _year);
     void updateQSLRecAndSent();
-    double checkFreqRanges(double _f);
-    void setRSTToMode(const QString &_m);
+    //double checkFreqRanges(double _f);
+    //void setRSTToMode(const QString &_m);
 
 
     // CLUSTER
@@ -462,12 +447,16 @@ private:
     Locator *locator;
     Awards *awards;
     Utilities *util;
+    SetupPageMisc *miscPage;
+
+
     //WorldEditorWidget *worldEditor;
 
     //HelpHelpDialog *helpHelpDialog;
     //HelpAboutDialog *helpAboutDialog;
     AboutDialog *aboutDialog;
     TipsDialog *tipsDialog;
+    ShowKLogLogWidget * showKLogLogWidget;
     //DXCCSummaryDialog *dxccSummaryDialog;
 
 
@@ -496,7 +485,6 @@ private:
     QGroupBox *gridGroupBox, *qrzgroupBox;//, *searchgroupBox;
     QFrame *dxUpLeftInputFrame;//, *dxUpRightOutputFrame;
 
-    QLineEdit *nameLineEdit, *qthLineEdit, *locatorLineEdit;
     //QComboBox *bandComboBox, *modeComboBox;
     //QDateEdit *dateEdit;
     //QTimeEdit *timeEdit;
@@ -515,7 +503,7 @@ private:
     //QMenu *lotwMarkAllAsQueuedMenu;
     //QMenu *lotwMarkAllInThisLogAsQueuedMenu;
     QMenu *viewMenu;
-    QMenu *setupMenu;
+    //QMenu *setupMenu;
     QMenu *helpMenu;
 
     //QAction *TestAct;       // Action for testing purposes only
@@ -533,6 +521,7 @@ private:
     QAction *helpAct;
     QAction *aboutAct;
     QAction *tipsAct;
+    QAction *debugAct;
     QAction *aboutQtAct;
     QAction *updateAct;
 
@@ -578,7 +567,7 @@ private:
     QAction *loggWinAct;
 /*
     QAction *delQSOFromLogAct;
-    QAction *qsoToEditFromLogAct; 
+    QAction *qsoToEditFromLogAct;
     QAction *qslSentViaBureauFromLogAct;
     QAction *qslSentViaDirectFromLogAct;
     QAction *qslRecViaBureauFromLogAct;
@@ -599,9 +588,6 @@ private:
     //QAction *qslRecViaDirectFromSearchAct;
     //QAction *qslRecViaBureauMarkReqFromSearchAct;
     //QAction *qslRecViaDirectMarkReqFromSearchAct;
-
-    QLineEdit *rstTXLineEdit;
-    QLineEdit *rstRXLineEdit;
     //QLineEdit *STXLineEdit;
     //QLineEdit *SRXLineEdit;
     //QPushButton *OKButton, *spotItButton, *clearButton;
@@ -625,9 +611,7 @@ private:
 
     QLineEdit *operatorLineEdit, *stationCallSignLineEdit;//, *commentLineEdit, *iotaNumberLineEdit;
     QTextEdit *notesTextEdit;
-    QDoubleSpinBox *rxPowerSpinBox,  *txFreqSpinBox, *rxFreqSpinBox; //*myPowerSpinBox,
-    QCheckBox *splitCheckBox;
-    QLCDNumber *freqQLCDNumber;
+    QDoubleSpinBox *rxPowerSpinBox;//  *txFreqSpinBox, *rxFreqSpinBox, *myPowerSpinBox,
 
     QString lotwTQSLpath;
 
@@ -643,7 +627,7 @@ private:
 
     //QLineEdit *searchBoxLineEdit;
     //QPushButton *searchBoxClearButton, *searchBoxExportButton, *searchBoxSelectAllButton, *searchBoxReSearchButton;
-    //QRadioButton *searchAllRadioButton;
+    //QCheckBox *searchAllQCheckbox;
     //QPushButton *recalculateAwardsButton;
     //bool searchSelectAllClicked, stationCallSignShownInSearch;
 
@@ -651,9 +635,9 @@ private:
     bool logEvents;                     // Should KLog log the events for debugging
     bool debugFileOpen;                 //Is the debugFile open?
     QFile *debugFile;
-    int logSeverity;    // Manages as syslog, the severity of the application debug log (7 means debug, 0 emergency)
+    DebugLogLevel logSeverity;    // Manages as syslog, the severity of the application debug log (7 means debug, 0 emergency)
 
-    bool txFreqBeingChanged, rxFreqBeingChanged, updatingBands;            // When the freqs is being modified it is defined to true to prevent other automated to change.
+    bool txFreqBeingChanged,  updatingBands; //rxFreqBeingChanged  // When the freqs is being modified it is defined to true to prevent other automated to change.
     bool txFreqBeingAutoChanged, rxFreqBeingAutoChanged;        // This is defined to true when freq is being changed by the Sat tab to prevent a loop.
     bool qslingNeeded;
     bool noMoreErrorShown;              // If true, the errors shown in slotQueryErrorManagement will not be shown anymore in that KLog execution
@@ -665,12 +649,15 @@ private:
     MainWindowInputOthers *othersTabWidget;
     MainWindowInputEQSL *eQSLTabWidget;
     MainWindowInputQSL *QSLTabWidget;
+    MainWindowInputQSO *QSOTabWidget;
     MainQSOEntryWidget *mainQSOEntryWidget;
 
     AwardsWidget *awardsWidget;
     SearchWidget *searchWidget;
     InfoWidget *infoWidget;
 
+    //AdvancedSearchWidget *advancedSearchWidget;
+
     bool keepSatPage;
 
     // UI DX
@@ -695,6 +682,9 @@ private:
     QString klogDir, ctyDatFile, defaultADIFLogFile, configFileName;
     QString softwareVersion;
     bool itIsANewversion;
+    int dupeSlotInSeconds;
+
+
 
 
     //QString currentQrz;
@@ -732,9 +722,11 @@ private:
     QColor confirmedColor;
     QColor newOneColor;
 
+    QSize windowSize;
+
     //<CLUBLOG>
     bool clublogActive, clublogRealTime, eQSLActive, eQSLRealTime, eQSLUseQSOStationCallSign; //clublogUseStationCallSign,
-    QString clublogPass, clublogEmail; //clublogUser,   
+    QString clublogPass, clublogEmail; //clublogUser,
 
     eLogClubLog *elogClublog;
     int clublogAnswer;
@@ -759,7 +751,7 @@ private:
 
     SoftwareUpdate *softUpdate;
     bool callingUpdate;
-    
+
     bool UDPServerStart;
     // LOTWUTILITIES
     LoTWUtilities *lotwUtilities;
@@ -772,6 +764,8 @@ private:
     //QString bandOld, modeOld;
     //LOGVIEW
 
+
+
 signals:
     void queryError(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery); // To alert about any failed query execution
 
@@ -779,6 +773,7 @@ signals:
 protected:
     void keyPressEvent(QKeyEvent *event) override;
     void closeEvent(QCloseEvent *event) override;
+    void showEvent(QShowEvent *event);
 
 };
 
