@@ -40,18 +40,33 @@ public:
     QSO();
     ~QSO();
 
+    void setBackup(const bool _rt);
+    bool getBackup();
+
+    void setModifying(const bool _mod);
+    bool getModifying();
+
     bool setData(const QString &_adifPair);
     void clear();
     bool isValid();
     void setLoTWUpdating(bool _lotw);
 
+    bool setCall(const QString &_c);
+    QString getCall();
+    bool setBand(const QString &_c);
+    QString getBand();
+    bool setMode(const QString &_c);
+    QString getMode();
     bool setDate(const QDate &_c);
     QDate getDate();
 
     bool setTimeOn(const QTime &_c);
     QTime getTimeOn();
-
     QDateTime getDateTimeOn();
+    bool setDateTimeOn(const QDateTime &_c);
+
+    void setRealTime(const bool _rt);
+    bool getRealTime();
 
     bool setQSOid(const int _i);
     int getQSOid();
@@ -59,27 +74,63 @@ public:
     bool setLogId(const int _i);
     int getLogId();
 
-    bool setBand(const QString &_c);
-    QString getBand();
+
     bool setBandRX(const QString &_c);
     QString getBandRX();
 
-    bool setMode(const QString &_c);
-    QString getMode();
 
-    bool setCall(const QString &_c);
-    QString getCall();
+    bool setRSTTX(const QString &_c);
+    QString getRSTTX();
+    bool setRSTRX(const QString &_c);
+    QString getRSTRX();
+    double setFreqTX(const double _f);
+    bool setFreqRX(const double _f);
+    double getFreqTX();
+    double getFreqRX();
+    bool setQTH(const QString &_c);
+    QString getQTH();
+    bool setGridSquare(const QString &_c);
+    QString getGridSquare();
+    bool setName(const QString &_c);
+    QString getName();
+    bool setRXPwr(const double _f);
+    double getRXPwr();
 
-    bool setFreq(const float _f);
-    bool setFreqRX(const float _f);
-    float getFreq();
-    float getFreqRX();
+    // QSL TAB
+    bool setQSL_SENT(const QString &_c);
+    QString getQSL_SENT();
+    bool setQSLSDate(const QDate &_c);
+    QDate getQSLSDate();
+    bool setQSLSenVia(const QString _qs);
+    QString getSentVia();
 
     bool setQSL_RCVD(const QString &_c);
     QString getQSL_RCVD();
-
     bool setQSLRDate(const QDate &_c);
     QDate getQSLRDate();
+    bool setQSLRecVia(const QString _qs);
+    QString getRecVia();
+
+    bool setQSLVia(const QString _qs);
+    QString getQSLVia();
+    bool setQSLMsg(const QString _qs);
+    QString getQSLMsg();
+
+
+    // eQSL tab
+    bool setClubLogStatus(const QString &_c);
+    QString getClubLogStatus();
+    bool setClubLogDate(const QDate &_c);
+    QDate getClubLogDate();
+
+    bool setEQSLQSL_RCVD(const QString &_c);
+    QString getEQSLQSL_RCVD();
+    bool setEQSLQSL_SENT(const QString &_c);
+    QString getEQSLQSL_SENT();
+    bool setEQSLQSLRDate(const QDate &_c);
+    QDate getEQSLQSLRDate();
+    bool setEQSLQSLSDate(const QDate &_c);
+    QDate getEQSLQSLSDate();
 
     bool setLoTWQSL_RCVD(const QString &_c);
     QString getLoTWQSL_RCVD();
@@ -90,14 +141,59 @@ public:
     bool setLoTWQSLSDate(const QDate &_c);
     QDate getLoTWQSLSDate();
 
+    bool setQRZCOMStatus(const QString &_c);
+    QString getQRZCOMStatus();
+    bool setQRZCOMDate(const QDate &_c);
+    QDate getQRZCOMDate();
+
+    // Comment Tab
+    bool setComment(const QString &_c);
+    QString getComment();
+    bool setKeepComment(bool _k);
+    bool getKeepComment();
+
+    // Others Tab
+    bool setDXCC(const int _i);
+    int getDXCC();
     bool setPropMode(const QString &_c);
     QString getPropMode();
+    bool setSOTA_REF(const QString &_c);
+    QString getSOTA_REF();
+    bool setMySOTA_REF(const QString &_c);
+    QString getMySOTA_REF();
+    bool setMyRig(const QString &_c);
+    QString getMyRig();
+    bool setMyAntenna(const QString &_c);
+    QString getMyAntenna();
+    double setAge(const double _c);
+    double getAge();
+    bool setIOTA(const QString &_c);
+    QString getIOTA();
+    bool setKeepOthers(bool _k);
+    bool getKeepOthers();
 
-    bool setSatName(const QString &_c);
-    QString getSatName();
-
+    // My data Tab
+    bool setTXPwr(const double _f);
+    double getTXPwr();
+    bool setOperatorCallsign(const QString &_c);
+    QString getOperatorCallsign();
     bool setStationCallsign(const QString &_c);
     QString getStationCallsign();
+    bool setMyGridSquare(const QString &_c);
+    QString getMyGridSquare();
+    bool setKeepMyData(bool _k);
+    bool getKeepMyData();
+
+    // Satellite Tab
+    bool setSatName(const QString &_c);
+    QString getSatName();
+    bool setSatMode(const QString &_c);
+    QString getSatMode();
+    bool setKeepSatTab(bool _k);
+    bool getKeepSatTab();
+
+
+
 
     bool add();
 
@@ -106,17 +202,29 @@ private:
 
 
 
-    QString satName, callsign, stationCallsign, propMode, band, mode ;
-    int qsoId, logId;
-    QString qsl_rcvd;
-    QDate QSLRDate, QSLLoTWRDate, QSLLoTWSDate;
-    QDateTime qso_dateTime;    
-    float freq, freq_rx;
-    QString lotw_qsl_sent, lotw_qsl_rcvd;
+    QString satName, satMode, callsign, stationCallsign, operatorCall, propMode, band, mode, gridsquare, myGridsquare, qth, name, RST_tx, RST_rx;
+    int qsoId, logId, dxcc;
+    QString qsl_rcvd, qsl_sent, qslSenVia, qslRecVia, qslVia, qslMsg;
+    QDate QSLRDate, QSLSDate, QSLLoTWRDate, QSLLoTWSDate;
+    QDateTime qso_dateTime;
+    double freq_tx, freq_rx, pwr_rx, pwr_tx, age;
+    QString lotw_qsl_sent, lotw_qsl_rcvd, sota_ref, my_sota_ref, my_rig, my_antenna;
+
+    QString clublog_status;
+    QDate clublogDate;
+    QString eqsl_qsl_sent, eqsl_qsl_rcvd;
+    QDate eQSLRDate, eQSLSDate;
+    QString QRZCom_status;
+    QDate QRZComDate;
+    QString comment;
+    bool keepComment, keepOther, keepMyData, keepSat, modifying;
+
+    QString iota;
 
     Utilities *util;
 
-    bool lotwUpdating;
+    bool lotwUpdating, realTime;
+    bool backup;
    // DataProxy_SQLite *dataProxy;
 
 
