@@ -1,3 +1,29 @@
+/***************************************************************************
+                          searchwidget.cpp  -  description
+                             -------------------
+    begin                : jul 2017
+    copyright            : (C) 2017 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "searchwidget.h"
 
 SearchWidget::SearchWidget(DataProxy_SQLite *dp, QWidget *parent) :
@@ -25,7 +51,7 @@ SearchWidget::SearchWidget(DataProxy_SQLite *dp, QWidget *parent) :
     searchBoxExportButton  = new QPushButton(tr("&Export Highlighted"), this);
     searchBoxSelectAllButton  = new QPushButton(tr("&Select All"), this);
     searchBoxReSearchButton = new QPushButton(tr("&Search"), this);
-    searchAllRadioButton = new QRadioButton (tr("All logs"), this);
+    searchAllQCheckbox = new QCheckBox (tr("All logs"), this);
 
     stationCallSignShownInSearch = true;
 
@@ -55,6 +81,7 @@ void SearchWidget::clear()
 
 void SearchWidget::setCallToSearch (const QString _st)
 {
+    //qDebug() << Q_FUNC_INFO << " : " << _st;
     searchBoxLineEdit->setText(_st);
 }
 
@@ -133,8 +160,8 @@ void SearchWidget::createUI()
     searchBoxExportButton->setToolTip(tr("Export the search result to an ADIF file."));
     searchBoxSelectAllButton->setToolTip(tr("Select/Unselect all the QSOs shown."));
     searchBoxReSearchButton->setToolTip(tr("Search in the log."));
-    searchAllRadioButton->setToolTip(tr("Search in all logs."));
-    searchBoxLineEdit->setToolTip(tr("Enter the Callsign to search for. Enter '*' to show all the QSOs... it may be slow in big logs!"));
+    searchAllQCheckbox->setToolTip(tr("Search in all logs."));
+    searchBoxLineEdit->setToolTip(tr("Enter the callsign to search for. Enter '*' to show all the QSOs... it may be slow in big logs!"));
 
     stationCallsignComboBox->setToolTip(tr("Select the Station Callsign used to do this QSO."));
 
@@ -153,7 +180,7 @@ void SearchWidget::createUI()
     QHBoxLayout *dxUpRightSearchTopLayout = new QHBoxLayout;
     dxUpRightSearchTopLayout->addWidget(searchBoxLineEdit);
     dxUpRightSearchTopLayout->addWidget(stationCallsignComboBox);
-    dxUpRightSearchTopLayout->addWidget(searchAllRadioButton);
+    dxUpRightSearchTopLayout->addWidget(searchAllQCheckbox);
 
     QHBoxLayout *dxUpRightButtonsLayout = new QHBoxLayout;
     dxUpRightButtonsLayout->addWidget(searchBoxReSearchButton);
@@ -182,7 +209,7 @@ void SearchWidget::createUI()
     //connect(searchResultsTreeWidget, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(slotDoubleClickSearch(QTreeWidgetItem *, int)));
     //connect(searchResultsTreeWidget, SIGNAL(customContextMenuRequested( const QPoint& ) ), this, SLOT(slotRightButtonSearch( const QPoint& ) ) );
     connect(stationCallsignComboBox, SIGNAL(currentIndexChanged (int)), this, SLOT(slotStationCallsignChanged() ) ) ;
-    connect(searchAllRadioButton, SIGNAL(toggled(bool)), this, SLOT(slotRadioButtonToggled() ) ) ;
+    connect(searchAllQCheckbox, SIGNAL(toggled(bool)), this, SLOT(slotQCheckboxToggled() ) ) ;
 
     connect(searchWindow, SIGNAL( actionQSODoubleClicked(int)), this, SLOT(slotQSOToEditFromSearch(int)));
     connect(searchWindow, SIGNAL( actionDeleteQSO(int)), this, SLOT( slotQsoDeleteFromSearch(int) ));
@@ -197,13 +224,8 @@ void SearchWidget::slotRequestFocus()
     emit requestBeingShown();
 }
 
-void showMenuRightButtonSearchCreateActions()
-{
-    //qDebug() << "SearchWidget::showMenuRightButtonSearchCreateActions" << endl;
 
 
-}
-
 /*
 void SearchWidget::slotRightButtonSearch(const QPoint& pos)
 {
@@ -216,18 +238,66 @@ void SearchWidget::slotRightButtonSearch(const QPoint& pos)
 void SearchWidget::slotQsoDeleteFromSearch(const int _qsoId)
 {
     //qDebug() << "SearchWidget::slotQsoDeleteFromSearch: " << QString::number(_qsoId) << endl;
-    actionQSODelete(_qsoId);
-    if(qslingNeeded)
+
+
+    int QSOid = _qsoId;
+    //int x = -1;
+
+    QString _qrz = dataProxy->getCallFromId(QSOid);
+    if (_qrz.length()>=3)
     {
-        searchWindow->slotToolSearchQSL(0);
+
+        QString message = QString(tr("You have requested to delete the QSO with: %1").arg(_qrz));
+
+        QMessageBox msgBox;
+        msgBox.setIcon(QMessageBox::Question);
+        msgBox.setText(message);
+        msgBox.setInformativeText(tr("Are you sure?"));
+        msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+        msgBox.setDefaultButton(QMessageBox::No);
+        int ret = msgBox.exec();
+
+        switch (ret)
+        {
+            case QMessageBox::Yes:
+
+            if(dataProxy->deleteQSO(QSOid))
+            {
+                emit actionQSODelete(QSOid);
+
+                emit logRefresh();
+                if(qslingNeeded)
+                {
+                    searchWindow->slotToolSearchQSL(0);
+                }
+                else
+                {
+                    slotSearchBoxTextChanged();
+                }
+                //dxccStatusWidget->refresh();
+                //awards->recalculateAwards();
+                emit updateAwards();
+
+            }
+            else
+            {
+                //TODO: The QSO could not be removed...
+            }
+
+            break;
+            case QMessageBox::No:
+              // No was clicked
+            break;
+            default:
+              // should never be reached
+            break;
+        }
+
     }
     else
     {
-        slotSearchBoxTextChanged();
+         // TODO: The QSO to be removed was not found in the log
     }
-    //dxccStatusWidget->refresh();
-    //awards->recalculateAwards();
-    //
 }
 
 void SearchWidget::slotQSLRecViaBureauFromSearch()
@@ -270,7 +340,9 @@ void SearchWidget::slotStartDelayInputTimer()
 {
     //qDebug() << "SearchWidget::slotStartDelayInputTimer"  << endl;
     int cursorP = searchBoxLineEdit->cursorPosition();
-    searchBoxLineEdit->setText((searchBoxLineEdit->text()).toUpper());
+
+
+    searchBoxLineEdit->setText((util->getClearSQLi(searchBoxLineEdit->text())).toUpper());
     searchBoxLineEdit->setCursorPosition(cursorP);
 
     delayInputTimer->start(800); //TODO: Define the delay in the Settings
@@ -280,13 +352,13 @@ void SearchWidget::slotDelayInputTimedOut()
 {
     //qDebug() << "SearchWidget::slotDelayInputTimedOut"  << endl;
     delayInputTimer->stop();
-    QString _text = (searchBoxLineEdit->text()).toUpper();
+
+    QString _text = searchBoxLineEdit->text();
     if( _text != lastSearch)
     {
         //DO WHATEVER
         lastSearch = _text;
         slotSearchBoxTextChanged();
-
     }
 }
 
@@ -295,7 +367,7 @@ void SearchWidget::fillStationCallsignComboBox()
     stationCallsignComboBox->clear();
     stationCallsignComboBox->addItem(tr("All in log"));
     stationCallsignComboBox->addItem(tr("Not defined"));
-    if (searchAllRadioButton->isChecked())
+    if (searchAllQCheckbox->isChecked())
     {
         stationCallsignComboBox->addItems(dataProxy->getStationCallSignsFromLog(-1));
     }
@@ -305,9 +377,9 @@ void SearchWidget::fillStationCallsignComboBox()
     }
 }
 
-void SearchWidget::slotRadioButtonToggled()
+void SearchWidget::slotQCheckboxToggled()
 {
-    //qDebug() << "SearchWidget::slotRadioButtonToggled"  << endl;
+    //qDebug() << "SearchWidget::slotQCheckboxToggled"  << endl;
     fillStationCallsignComboBox();
     slotSearchBoxTextChanged();
 }
@@ -530,7 +602,7 @@ void SearchWidget::slotSearchBoxTextChanged()
     //QString _id, _call, _dateTime, _band, _bandid, _mode, _qsltx, _qslrx, _stationcallsign, _dxcc;
     //QStringList q;
     //_stationcallsign = QString();
-    bool searchAll = searchAllRadioButton->isChecked();
+    bool searchAll = searchAllQCheckbox->isChecked();
     //int i = -1;
     int cursorP = searchBoxLineEdit->cursorPosition();
     /*
@@ -761,7 +833,7 @@ void SearchWidget::slotSearchExportButtonClicked()
                                    util->getHomeDir(),
                                    "ADIF (*.adi *.adif)");
         filemanager->adifLogExportMarked(fileName);
-           //qDebug() << "SearchWidget::slotSearchExportButtonClicked: to call save file" << endl;
+           //qDebug() << "SearchWidget::slotSearchExportButtonClicked: to callsign save file" << endl;
         dataProxy->unMarkAllQSO();
     }
     else
