@@ -7,20 +7,20 @@
  ***************************************************************************/
 
 /*****************************************************************************
- * This file is part of KLog.                                             *
+ * This file is part of KLog.                                                *
  *                                                                           *
- *    KLog is free software: you can redistribute it and/or modify        *
+ *    KLog is free software: you can redistribute it and/or modify           *
  *    it under the terms of the GNU General Public License as published by   *
  *    the Free Software Foundation, either version 3 of the License, or      *
  *    (at your option) any later version.                                    *
  *                                                                           *
- *    KLog is distributed in the hope that it will be useful,             *
+ *    KLog is distributed in the hope that it will be useful,                *
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.       *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
@@ -82,12 +82,12 @@ void SearchWindow::createUI()
     QStringList labels;
     if (showStationCallsignInHeader)
     {
-        labels << tr("Callsign") << tr("Date/Time") << tr("Band") << tr("Mode") << tr("QSL Sent") << tr("QSL Rcvd") << tr("Station Callsign") << tr("ID") ;
+        labels << tr("Call") << tr("Date/Time") << tr("Band") << tr("Mode") << tr("QSL Sent") << tr("QSL Rcvd") << tr("Station Callsign") << tr("ID") ;
         //treeView->setColumnCount(8);
     }
     else
     {
-       labels << tr("Callsign") << tr("Date/Time") << tr("Band") << tr("Mode") << tr("QSL Sent") << tr("QSL Rcvd") << tr("ID") ;
+       labels << tr("Call") << tr("Date/Time") << tr("Band") << tr("Mode") << tr("QSL Sent") << tr("QSL Rcvd") << tr("ID") ;
        //treeView->setColumnCount(7);
     }
 
@@ -126,8 +126,7 @@ void SearchWindow::setStationCallsignInHeader(const bool _h)
 {
     showStationCallsignInHeader = _h;
     setColumnsToDX();
-    //labels << tr("Callsign") << tr("Date/Time") << tr("Band") << tr("Mode") << tr("QSL Sent") << tr("QSL Rcvd") << tr("Station Callsign") << tr("ID") ;
-    //labels << tr("Callsign") << tr("Date/Time") << tr("Band") << tr("Mode") << tr("QSL Sent") << tr("QSL Rcvd") << tr("ID") ;
+
 }
 
 void SearchWindow::createlogPanel(const int _currentLog)
@@ -165,7 +164,7 @@ void SearchWindow::createlogPanel(const int _currentLog)
 void SearchWindow::setColumnsToDX()
 {
       //qDebug() << "SearchWindow::setColumnsToDX"  << endl;
-    //labels << tr("Callsign") << tr("Date/Time") << tr("Band") << tr("Mode") << tr("QSL Sent") << tr("QSL Rcvd") << tr("Station Callsign") << tr("ID") ;
+
     QString stringQuery;
     //stringQuery = QString("SELECT call, qso_date, bandid, modeid, qsl_sent, qsl_rcvd, station_callsign, id FROM log LIMIT 1");
     stringQuery = QString("SELECT * FROM log LIMIT 1");
@@ -194,7 +193,7 @@ void SearchWindow::setColumnsToDX()
 
     columns = rec.indexOf("call");
     treeView->setColumnHidden(columns, false);
-    searchModel->setHeaderData(columns, Qt::Horizontal,tr("Callsign"));
+    searchModel->setHeaderData(columns, Qt::Horizontal,tr("Call"));
 
     columns = rec.indexOf("bandid");
     searchModel->setBandIdColumn(columns);
@@ -351,7 +350,8 @@ void SearchWindow::slotDoubleClickLog(const QModelIndex & index)
 bool SearchWindow::isQSLReceived(const int _qsoId)
 {
        //qDebug() << "SearchWindow::isQSLReceived: " << QString::number(_qsoId) << endl;
-    return dataProxy->isQSLReceived(_qsoId);
+    return dataProxy->isQSOConfirmed(_qsoId, true, false); // We check just paper QSL
+    //return dataProxy->isQSLReceived(_qsoId);
 }
 
 bool SearchWindow::isQSLSent(const int _qsoId)
@@ -651,7 +651,10 @@ void SearchWindow::slotToolSearchQSL(const int actionQSL)
     {
         case 0://void searchToolNeededQSLToSend();
             //qDebug() << "SearchWidget::slotToolSearchQSL: CASE 0" << endl;
-            stringQuery = QString("SELECT call, qso_date, bandid, modeid, qsl_sent, qsl_rcvd, station_callsign, log.id FROM log JOIN awarddxcc ON awarddxcc.qsoid=log.id WHERE awarddxcc.confirmed='0' AND log.qsl_sent!='Y' AND log.qsl_sent!='Q' AND log.qsl_sent!='R' AND log.lognumber='%1'").arg(currentLog);
+
+
+            stringQuery = QString("SELECT call, qso_date,dxcc, bandid, modeid, qsl_sent, qsl_rcvd, lotw_qsl_rcvd, station_callsign, id FROM log WHERE (qsl_rcvd<>'Y' AND lotw_qsl_rcvd<>'Y') AND qsl_sent<>'Y' AND qsl_sent<>'Q' AND qsl_sent<>'R' AND lognumber='%1' AND (bandid, dxcc) NOT IN (SELECT distinct bandid, dxcc from log WHERE qsl_rcvd='Y' OR lotw_qsl_rcvd='Y')").arg(currentLog);
+            //stringQuery = QString("SELECT call, qso_date, bandid, modeid, qsl_sent, qsl_rcvd, station_callsign, log.id FROM log JOIN awarddxcc ON awarddxcc.qsoid=log.id WHERE awarddxcc.confirmed='0' AND log.qsl_sent!='Y' AND log.qsl_sent!='Q' AND log.qsl_sent!='R' AND log.lognumber='%1'").arg(currentLog);
             message = tr("Needed QSO to send the QSL");
             setNeedingQSL(true);
             //qslingNeeded = true;
