@@ -20,141 +20,24 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
 #include "setupdialog.h"
+#include "setuppages/setuppagemisc.h"
 //#include <QDebug>
 
 /*
 This class calls all the othet "Setup..." to manage the configuration
 
 */
-/*
-SetupDialog::SetupDialog(DataProxy_SQLite *dp, const bool _firstTime, QWidget *parent)
-{
-    //qDebug() << "SetupDialog::SetupDialog 1" << endl;
-    logSeverity = 7;  //7 Debug /0=emergency or no debug
-    util = new Utilities;
-    constrid = 1;
-    nolog = true;
-    configFileName = "klogrc";
-    version = ".";
-    pageRequested = 0;
-     //qDebug() << "SetupDialog::SetupDialog 2" << endl;
-    dataProxy = dp;
-      //qDebug() << "SetupDialog::SetupDialog 3" << endl;
 
-    firstTime = _firstTime;
-    if (firstTime)
-    {
-          //qDebug() << "SetupDialog::SetupDialog FIRST TIME = TRUE" << endl;
-    }
-    else
-    {
-          //qDebug() << "SetupDialog::SetupDialog FIRST TIME = FALSE" << endl;
-    }
-      //qDebug() << "SetupDialog::SetupDialog 3.1" << endl;
-
-    logsPageTabN=-1;
-      //qDebug() << "SetupDialog::SetupDialog 3.2" << endl;
-    locator = new Locator();
-      //qDebug() << "SetupDialog::SetupDialog 3.3" << endl;
-    tabWidget = new QTabWidget;
-      //qDebug() << "SetupDialog::SetupDialog 3.4" << endl;
-    hamlibPage = new SetupPageHamLib(dataProxy, this);
-      //qDebug() << "SetupDialog::SetupDialog 3.4.1" << endl;
-    userDataPage = new SetupPageUserDataPage(dataProxy);
-      //qDebug() << "SetupDialog::SetupDialog 3.5" << endl;
-    bandModePage = new SetupPageBandMode(dataProxy, this);
-      //qDebug() << "SetupDialog::SetupDialog 3.6" << endl;
-    dxClusterPage = new SetupPageDxCluster(this);
-      //qDebug() << "SetupDialog::SetupDialog 3.7" << endl;
-    colorsPage = new SetupPageColors(this);
-      //qDebug() << "SetupDialog::SetupDialog 3.8" << endl;
-    miscPage = new SetupPageMisc(this);
-      //qDebug() << "SetupDialog::SetupDialog 3.9" << endl;
-    worldEditorPage = new SetupPageWorldEditor (dataProxy, this);
-      //qDebug() << "SetupDialog::SetupDialog 3.10" << endl;
-    logsPage = new SetupPageLogs(dataProxy, this);
-      //qDebug() << "SetupDialog::SetupDialog 3.11" << endl;
-    eLogPage = new SetupPageELog(this);
-    //clubLogPage = new SetupPageClubLog(this);
-    //lotwPage = new SetupPageLoTW(this);
-    //eQSLPage = new SetupPageEQSL(this);
-       //qDebug() << "SetupDialog::SetupDialog 3.12" << endl;
-    UDPPage = new SetupPageUDP(this);    
-      //qDebug() << "SetupDialog::SetupDialog 3.13" << endl;
-    satsPage = new SetupPageSats(dataProxy, this);
-    subdivisionsPage = new SetupPageSubdivisions(dataProxy, this);
-    //regionalAwardsPage = new SetupPageRegionalAwards(dataProxy, this);
-    //hamlibPage = new SetupPageHamLib(dataProxy, this);
-    //interfacesWindowsPage = new SetupPageInterfacesWindows(this);
-
-      //qDebug() << "SetupDialog::SetupDialog 4" << endl;
-    //tabWidget->addTab(subdivisionsPage, tr("Subdivisions"));
-    tabWidget->addTab(userDataPage, tr("My Data"));    
-    tabWidget->addTab(bandModePage, tr("Bands/Modes"));
-    tabWidget->addTab(dxClusterPage, tr("DX-Cluster"));
-    tabWidget->addTab(colorsPage, tr("Colors"));
-    tabWidget->addTab(miscPage, tr("Misc"));
-    tabWidget->addTab(worldEditorPage, tr("World Editor"));
-    logsPageTabN = tabWidget->addTab(logsPage, tr("Logs"));
-    tabWidget->addTab(eLogPage, "eLog");
-    //tabWidget->addTab(clubLogPage, "ClubLog");
-    //tabWidget->addTab(lotwPage, "LoTW");
-    //tabWidget->addTab(eQSLPage, "eQSL");
-    tabWidget->addTab(UDPPage, "WSJT-X");
-    tabWidget->addTab(satsPage , tr("Satellites"));
-    tabWidget->addTab(hamlibPage, tr ("HamLib"));
-    //tabWidget->addTab(interfacesWindowsPage, tr ("Interfaces"));
-
-
-    QPushButton *closeButton = new QPushButton(tr("Cancel"));
-    okButton = new QPushButton(tr("Ok"));
-
-    connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
-
-    connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));       
-    connect(logsPage, SIGNAL(queryError(QString, QString, int, QString)), this, SLOT(slotQueryErrorManagement(QString, QString, int, QString)) );    
-
-    connectActions();
-
-
-    QHBoxLayout *horizontalLayout = new QHBoxLayout;
-    horizontalLayout->addWidget(tabWidget);
-
-    QHBoxLayout *buttonsLayout = new QHBoxLayout;
-    buttonsLayout->addStretch(1);
-    buttonsLayout->addWidget(okButton);
-    buttonsLayout->addWidget(closeButton);
-
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    mainLayout->addLayout(horizontalLayout);
-    mainLayout->addLayout(buttonsLayout);
-    userDataPage->setFocus();
-    setLayout(mainLayout);
-
-    setWindowTitle(tr("Config Dialog"));
-    windowSize.clear();
-    slotReadConfigData();
-
-
-    if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
-    {
-        tabWidget->setCurrentIndex(logsPageTabN);
-    }
-    nolog = !(haveAtleastOneLog());
-    //qDebug() << "SetupDialog::SetupDialog 1 END" << endl;
-}
-
-*/
 SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const QString &_softwareVersion, const int _page, const bool _firstTime, QWidget *parent)
 {
     //qDebug() << "SetupDialog::SetupDialog 2: " << _configFile << "/" << _softwareVersion << "/" << QString::number(_page) << util->boolToQString(_firstTime) << endl ;
 
-    logSeverity = 7;
+    logSeverity = Info;
     constrid = 2;
     util = new Utilities;
     firstTime = _firstTime;
@@ -169,26 +52,32 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const
     locator = new Locator();
 
     tabWidget = new QTabWidget;
-
+    //qDebug() << "SetupDialog::SetupDialog 01.0" << endl;
     userDataPage = new SetupPageUserDataPage(dataProxy);
+    //qDebug() << "SetupDialog::SetupDialog 01.10" << endl;
     bandModePage = new SetupPageBandMode(dataProxy, this);
+    //qDebug() << "SetupDialog::SetupDialog 01.20" << endl;
     dxClusterPage = new SetupPageDxCluster(this);
+    //qDebug() << "SetupDialog::SetupDialog 01.30" << endl;
     colorsPage = new SetupPageColors(this);
+    //qDebug() << "SetupDialog::SetupDialog 01.40" << endl;
     miscPage = new SetupPageMisc(this);
+    //qDebug() << "SetupDialog::SetupDialog 01.50" << endl;
     worldEditorPage = new SetupPageWorldEditor (dataProxy, this);
+    //qDebug() << "SetupDialog::SetupDialog 01.60" << endl;
     logsPage = new SetupPageLogs(dataProxy, this);
+    //qDebug() << "SetupDialog::SetupDialog 01.70" << endl;
     eLogPage = new SetupPageELog(this);
-    //clubLogPage = new SetupPageClubLog(this);
-    //lotwPage = new SetupPageLoTW(this);
-    //eQSLPage = new SetupPageEQSL(this);
+    //qDebug() << "SetupDialog::SetupDialog 01.80" << endl;
     UDPPage = new SetupPageUDP(this);
+    //qDebug() << "SetupDialog::SetupDialog 01.90" << endl;
     satsPage = new SetupPageSats(dataProxy, this);
+    //qDebug() << "SetupDialog::SetupDialog 01.100" << endl;
     hamlibPage = new SetupPageHamLib(dataProxy, this);
     //subdivisionsPage = new SetupPageSubdivisions(dataProxy, this);
     //regionalAwardsPage = new SetupPageRegionalAwards(dataProxy, this);
     //interfacesWindowsPage = new SetupPageInterfacesWindows(this);
 
-
     //qDebug() << "SetupDialog::SetupDialog 02" << endl;
     //tabWidget->addTab(subdivisionsPage, tr("Subdivisions"));
     tabWidget->addTab(userDataPage, tr("User data"));
@@ -227,7 +116,6 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const
     //qDebug() << "SetupDialog::SetupDialog 04" << endl;
 
     setLayout(mainLayout);
-
     setWindowTitle(tr("Settings"));
 
     //qDebug() << "SetupDialog::SetupDialog 05" << endl;
@@ -237,10 +125,10 @@ SetupDialog::SetupDialog(DataProxy_SQLite *dp, const QString &_configFile, const
 
     if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
     {
-          //qDebug() << "SetupDialog::SetupDialog 05.2" << endl;
+         //qDebug() << "SetupDialog::SetupDialog 05.2" << endl;
         tabWidget->setCurrentIndex(logsPageTabN);
     }
-      //qDebug() << "SetupDialog::SetupDialog 05.3" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 05.3" << endl;
     nolog = !(haveAtleastOneLog());
 
     connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
@@ -296,6 +184,7 @@ void SetupDialog::setData(const QString &_configFile, const QString &_softwareVe
 
     setConfigFile(_configFile);
     setSoftVersion(_softwareVersion);
+    slotReadConfigData ();
     setPage(_page);
     //removeBandModeDuplicates();
     emit debugLog (Q_FUNC_INFO, "END", logSeverity);
@@ -360,6 +249,7 @@ void SetupDialog::slotCancelButtonClicked()
             }
         }
     }
+    QDialog::reject ();
     close();
     emit debugLog (Q_FUNC_INFO, "END", logSeverity);
 }
@@ -449,8 +339,8 @@ void SetupDialog::slotOkButtonClicked()
     if (!util->isValidCall(userDataPage->getStationQrz())){ //
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Information);
-        msgBox.setText(tr("You need to enter at least a valid QRZ."));
-        msgBox.setInformativeText(tr("Go to the User tab and enter valid QRZ."));
+        msgBox.setText(tr("You need to enter at least a valid callsign."));
+        msgBox.setInformativeText(tr("Go to the User tab and enter valid callsign."));
         msgBox.exec();
         emit debugLog (Q_FUNC_INFO, "END-2", logSeverity);
         return;
@@ -477,7 +367,8 @@ void SetupDialog::slotOkButtonClicked()
     QFile file (configFileName);
     QString tmp;
     tmp = "true";
-    if (file.open (QIODevice::WriteOnly)){
+    if (file.open (QIODevice::WriteOnly))   /* Flawfinder: ignore */
+    {
         QTextStream stream (&file);
     /*QString stationCall;
     int contest;
@@ -587,6 +478,13 @@ void SetupDialog::slotOkButtonClicked()
         stream << "DebugLog=" << miscPage->getDebugLog() << ";" << endl;
         //stream << "LogSort=" << miscPage->getLogSort() << ";" << endl;
         stream << "SendEQSLByDefault=" << miscPage->getSendEQSLByDefault() << ";" << endl;
+        stream << "DeleteAlwaysAdiFile=" << miscPage->getDeleteAlwaysAdiFile() << ";" << endl;
+
+        if (miscPage->getDupeTime()>0)
+        {
+            stream << "DuplicatedQSOSlot=" << QString::number(miscPage->getDupeTime()) << ";" << endl;
+        }
+
         //stream << "PSTRotatorActive=" << interfacesWindowsPage->getSendToPSTRotator() << ";" << endl;
         //stream << "PSTRotatorServer=" << interfacesWindowsPage->getPSTRotatorUDPServer() << ";" << endl;
         //stream << "PSTRotatorPort=" << interfacesWindowsPage->getPSTRotatorUDPServerPort() << ";" << endl;
@@ -616,21 +514,22 @@ void SetupDialog::slotOkButtonClicked()
             }
         }
 
-        stream << "DXClusterShowHF=" << dxClusterPage->getShowHFRadiobutton() << ";" <<  endl;
-        stream << "DXClusterShowVHF=" << dxClusterPage->getShowVHFRadiobutton() << ";" <<  endl;
-        stream << "DXClusterShowWARC=" << dxClusterPage->getShowWARCRadiobutton() << ";" <<  endl;
-        stream << "DXClusterShowWorked=" << dxClusterPage->getShowWorkedRadiobutton() << ";" <<  endl;
-        stream << "DXClusterShowConfirmed=" << dxClusterPage->getShowConfirmedRadiobutton() << ";" <<  endl;
-        stream << "DXClusterShowAnn=" << dxClusterPage->getShowANNRadiobutton() << ";" <<  endl;
-        stream << "DXClusterShowWWV=" << dxClusterPage->getShowWWVRadiobutton() << ";" <<  endl;
-        stream << "DXClusterShowWCY=" << dxClusterPage->getShowWCYRadiobutton() << ";" <<  endl;
-        stream << "DXClusterSave=" << dxClusterPage->getSaveActivityRadiobutton() << ";" <<  endl;
+        stream << "DXClusterShowHF=" << dxClusterPage->getShowHFQCheckbox() << ";" <<  endl;
+        stream << "DXClusterShowVHF=" << dxClusterPage->getShowVHFQCheckbox() << ";" <<  endl;
+        stream << "DXClusterShowWARC=" << dxClusterPage->getShowWARCQCheckbox() << ";" <<  endl;
+        stream << "DXClusterShowWorked=" << dxClusterPage->getShowWorkedQCheckbox() << ";" <<  endl;
+        stream << "DXClusterShowConfirmed=" << dxClusterPage->getShowConfirmedQCheckbox() << ";" <<  endl;
+        stream << "DXClusterShowAnn=" << dxClusterPage->getShowANNQCheckbox() << ";" <<  endl;
+        stream << "DXClusterShowWWV=" << dxClusterPage->getShowWWVQCheckbox() << ";" <<  endl;
+        stream << "DXClusterShowWCY=" << dxClusterPage->getShowWCYQCheckbox() << ";" <<  endl;
+        stream << "DXClusterSave=" << dxClusterPage->getSaveActivityQCheckbox() << ";" <<  endl;
 
         stream << "NewOneColor=" << colorsPage->getNewOneColor() << ";" <<  endl;
         stream << "NeededColor=" << colorsPage->getNeededColor() << ";" <<  endl;
         stream << "WorkedColor=" << colorsPage->getWorkedColor() << ";" <<  endl;
         stream << "ConfirmedColor=" << colorsPage->getConfirmedColor() << ";" <<  endl;
         stream << "DefaultColor=" << colorsPage->getDefaultColor() << ";" <<  endl;
+        stream << "DarkMode=" << colorsPage->getDarkMode() << ";" << endl;
         stream << "SelectedLog=" << QString::number(logsPage->getSelectedLog()) << ";" <<  endl;
         //qDebug() << "SetupDialog::slotOkButtonClicked SelectedLog: " << logsPage->getSelectedLog() << endl;
         // CLUBLOG
@@ -640,12 +539,18 @@ void SetupDialog::slotOkButtonClicked()
             {
                 stream << "ClubLogActive=True;"<<  endl;
             }
-
+            else
+            {
+                stream << "ClubLogActive=False;"<< endl;
+            }
             if (eLogPage->getClubLogRealTime())
             {
                 stream << "ClubLogRealTime=True;" <<  endl;
             }
-
+            else
+            {
+                stream << "ClubLogRealTime=False;" << endl;
+            }
             tmp = eLogPage->getClubLogEmail() ;
             if (tmp.length()>0)
             {
@@ -666,8 +571,10 @@ void SetupDialog::slotOkButtonClicked()
             {
                 stream << "eQSLActive=True;" <<  endl;
             }
-
-
+            else
+            {
+                stream << "eQSLActive=False;" << endl;
+            }
             tmp = eLogPage->getEQSLUser();
             if (tmp.length()>0)
             {
@@ -690,6 +597,10 @@ void SetupDialog::slotOkButtonClicked()
             {
                 stream << "QRZcomActive=True;" <<  endl;
             }
+            else
+            {
+                stream << "QRZcomActive=False;" << endl;
+            }
             tmp = eLogPage->getQRZCOMUser();
             if (tmp.length()>0)
             {
@@ -705,6 +616,10 @@ void SetupDialog::slotOkButtonClicked()
             {
                  stream << "QRZcomAuto=True;" << endl;
             }
+            else
+            {
+                stream << "QRZcomAuto=False;" <<endl;
+            }
             tmp = eLogPage->getQRZCOMLogBookKEY();
             if (tmp.length()>0)
             {
@@ -787,7 +702,8 @@ void SetupDialog::slotReadConfigData()
     //qDebug() << "SetupDialog::slotReadConfigData - 1" << endl;
 
     QFile file(configFileName);
-    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))  /* Flawfinder: ignore */
+    {
         //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << endl;
         //firstTime = true;
         emit debugLog (Q_FUNC_INFO, "END-1", logSeverity);
@@ -796,9 +712,9 @@ void SetupDialog::slotReadConfigData()
     //qDebug() << "SetupDialog::slotReadConfigData - 2" << endl;
     //dxClusterServers.clear();
 
-    while (!file.atEnd()) {
+    while (!file.atEnd()){
         QByteArray line = file.readLine();
-        processConfigLine(line);        
+        processConfigLine(line);
         //qDebug() << "SetupDialog::slotReadConfigData - in the while" << endl;
     }
     //qDebug() << "SetupDialog::slotReadConfigData - 3" << endl;
@@ -921,6 +837,13 @@ bool SetupDialog::processConfigLine(const QString &_line)
     else if (tab=="SENDEQSLBYDEFAULT"){
         miscPage->setSetEQSLByDefault(value);
     }
+    else if (tab=="DUPLICATEDQSOSLOT"){
+        if (value.toInt()>=0)
+        {
+            miscPage->setDupeTime(value.toInt());
+        }
+    }
+
     /*
     else if (tab=="PSTROTATORACTIVE"){
         interfacesWindowsPage->setSendToPSTRotator(value);
@@ -1030,29 +953,29 @@ bool SetupDialog::processConfigLine(const QString &_line)
             userDataPage->setStationLocator(value);
         }
     }else if (tab =="DXCLUSTERSHOWHF"){
-        dxClusterPage->setShowHFRadiobutton(value);
+        dxClusterPage->setShowHFQCheckbox(value);
     }else if (tab =="DXCLUSTERSHOWVHF"){
-        dxClusterPage->setShowVHFRadiobutton(value);
+        dxClusterPage->setShowVHFQCheckbox(value);
     }else if (tab =="DXCLUSTERSHOWWARC"){
-        dxClusterPage->setShowWARCRadiobutton(value);
+        dxClusterPage->setShowWARCQCheckbox(value);
     }else if (tab =="DXCLUSTERSHOWWORKED"){
-        dxClusterPage->setShowWorkedRadiobutton(value);
+        dxClusterPage->setShowWorkedQCheckbox(value);
     }else if (tab =="DXCLUSTERSHOWCONFIRMED"){
-        dxClusterPage->setShowConfirmedRadiobutton(value);
+        dxClusterPage->setShowConfirmedQCheckbox(value);
     }else if (tab =="DXCLUSTERSHOWANN"){
-        dxClusterPage->setShowANNRadiobutton(value);
+        dxClusterPage->setShowANNQCheckbox(value);
     }else if (tab =="DXCLUSTERSHOWWWV"){
-        dxClusterPage->setShowWWVRadiobutton(value);
+        dxClusterPage->setShowWWVQCheckbox(value);
     }else if (tab =="DXCLUSTERSHOWWCY"){
-        dxClusterPage->setShowWCYRadiobutton(value);
+        dxClusterPage->setShowWCYQCheckbox(value);
     }else if(tab =="DXCLUSTERSERVERPORT"){
         dxClusterServers << value;
            //qDebug() << "SetupDialog::processConfigLine: dxClusterServers: " << dxClusterServers.last() << endl;
-    }else if (tab  =="DXCLUSTERSERVERTOUSE"){        
+    }else if (tab  =="DXCLUSTERSERVERTOUSE"){
         dxClusterServerToUse=value;
     }
     else if (tab  =="DXCLUSTERSAVE"){
-        dxClusterPage->setSaveActivityRadiobutton(value);
+        dxClusterPage->setSaveActivityQCheckbox(value);
     }
     else if(tab =="NEWONECOLOR"){
         colorsPage->setNewOneColor(value);
@@ -1065,6 +988,8 @@ bool SetupDialog::processConfigLine(const QString &_line)
     }else if(tab =="DEFAULTCOLOR"){
         colorsPage->setDefaultColor(value);
           //qDebug() << "SetupDialog::processConfigLine: DEFAULTCOLOR: " << value << endl;
+    }else if(tab =="DARKMODE"){
+        colorsPage->setDarkMode(value);
     }else if(tab =="HAMLIBRIGTYPE"){
           //qDebug() << "SetupDialog::processConfigLine: Before HAMLIBRIGTYPE: " << value << endl;
         hamlibPage->setRigType(value);
@@ -1100,6 +1025,10 @@ bool SetupDialog::processConfigLine(const QString &_line)
         //hamlibPage->setDTR(value);
     }else if (tab == "HAMLIBRIGPOLLRATE"){
         hamlibPage->setPollingInterval(value.toInt());
+    }else if (tab == "HAMLIBNETADDRESS"){
+        hamlibPage->setRadioNetworkAddress (value);
+    }else if (tab == "HAMLIBNETPORT"){
+        hamlibPage->setRadioNetworkPort (value.toInt ());
     }else if(tab =="SELECTEDLOG"){
            //qDebug() << "SetupDialog::processConfigLine: SELECTEDLOG: " << value << endl;
         i = value.toInt();
@@ -1122,7 +1051,7 @@ bool SetupDialog::processConfigLine(const QString &_line)
 
     }else if(tab =="CLUBLOGACTIVE"){
         eLogPage->setClubLogActive(util->trueOrFalse(value));
-        //clubLogPage->setClubLog(value);
+
     }
     else if(tab =="CLUBLOGREALTIME"){
         //clubLogPage->setClubLogRealTime(value);
@@ -1142,12 +1071,12 @@ bool SetupDialog::processConfigLine(const QString &_line)
     }
     else if(tab =="EQSLCALL"){
         //eQSLPage->setCallsign(value);
-        eLogPage->setEQSLEmail(value);
+        eLogPage->setEQSLUser(value);
     }
     else if(tab =="EQSLPASS"){
         //eQSLPage->setPassword(value);
         eLogPage->setEQSLPassword(value);
-    }    
+    }
     else if(tab =="QRZCOMACTIVE"){
         //eQSLPage->setActive(value);
         eLogPage->setQRZCOMActive(value);
@@ -1184,10 +1113,11 @@ bool SetupDialog::processConfigLine(const QString &_line)
         {
             windowSize = value;
         }
-
     }
-    else if (tab == "LATESTBACKUP")
-    {
+    else if(tab =="DELETEALWAYSADIFILE"){
+            miscPage->setDeleteAlwaysAdiFile(util->trueOrFalse(value));
+        }
+    else if (tab == "LATESTBACKUP"){
         if (value.length()>0)
         {
             latestBackup = value;
@@ -1198,7 +1128,6 @@ bool SetupDialog::processConfigLine(const QString &_line)
         }
     //s.append("LatestBackup=" + (QDateTime::currentDateTime()).toString("yyyyMMdd-hhmmss") + ";\n" );
     }
-
     else
     {
            //qDebug() << "SetupDialog::processConfigLine: NONE: " << endl;
@@ -1246,7 +1175,7 @@ void SetupDialog::readActiveBands (const QString &actives)
 
     bands << dataProxy->getBandsInLog(-1);
     bands << _abands;
-    bands.removeDuplicates();    
+    bands.removeDuplicates();
     emit debugLog (Q_FUNC_INFO, "END", logSeverity);
 }
 
@@ -1315,7 +1244,7 @@ void SetupDialog::setDefaults()
     miscPage->setImperial("FALSE"); //Metric system is the default
     miscPage->setAlwaysADIF("FALSE");
     miscPage->setSendQSLWhenRec("TRUE");
-    miscPage->setShowStationCallSignInSearch("TRUE");    
+    miscPage->setShowStationCallSignInSearch("TRUE");
     miscPage->setCheckNewVersions("TRUE");
     miscPage->setReportInfo("FALSE");
     miscPage->setDXMarathon("FALSE");
@@ -1333,14 +1262,14 @@ void SetupDialog::setDefaults()
     //interfacesWindowsPage->setPSTRotatorUDPServer("locahost");
     //interfacesWindowsPage->setPSTRotatorUDPServerPort("12040");
 
-    dxClusterPage->setShowHFRadiobutton("TRUE");
-    dxClusterPage->setShowVHFRadiobutton("TRUE");
-    dxClusterPage->setShowWARCRadiobutton("TRUE");
-    dxClusterPage->setShowWorkedRadiobutton("TRUE");
-    dxClusterPage->setShowConfirmedRadiobutton("TRUE");
-    dxClusterPage->setShowANNRadiobutton("TRUE");
-    dxClusterPage->setShowWWVRadiobutton("TRUE");
-    dxClusterPage->setShowWCYRadiobutton("TRUE");
+    dxClusterPage->setShowHFQCheckbox("TRUE");
+    dxClusterPage->setShowVHFQCheckbox("TRUE");
+    dxClusterPage->setShowWARCQCheckbox("TRUE");
+    dxClusterPage->setShowWorkedQCheckbox("TRUE");
+    dxClusterPage->setShowConfirmedQCheckbox("TRUE");
+    dxClusterPage->setShowANNQCheckbox("TRUE");
+    dxClusterPage->setShowWWVQCheckbox("TRUE");
+    dxClusterPage->setShowWCYQCheckbox("TRUE");
     dxClusterServers.clear();
     dxClusterServers.append("dxfun.com:8000");
     dxClusterServerToUse = "dxfun.com:8000";
@@ -1470,7 +1399,7 @@ void SetupDialog::slotSetOperators(const QString &_p)
     emit debugLog (Q_FUNC_INFO, "END", logSeverity);
 }
 
-void SetupDialog::setSeverity(const int _sev)
+void SetupDialog::setSeverity(const DebugLogLevel _sev)
 {
     logSeverity = _sev;
 }
@@ -1489,6 +1418,9 @@ void SetupDialog::slotFocusOK()
 
 void SetupDialog::showEvent(QShowEvent *event)
 {
+    //qDebug() << Q_FUNC_INFO << endl;
+    //qDebug() << Q_FUNC_INFO << " - selectedLog: " << QString::number(logsPage->getSelectedLog()) << endl;
     QWidget::showEvent(event);
+
     userDataPage->setStationFocus();
 }
