@@ -9,26 +9,27 @@
  ***************************************************************************/
 
 /*****************************************************************************
- * This file is part of KLog.                                             *
+ * This file is part of KLog.                                                *
  *                                                                           *
- *    KLog is free software: you can redistribute it and/or modify        *
+ *    KLog is free software: you can redistribute it and/or modify           *
  *    it under the terms of the GNU General Public License as published by   *
  *    the Free Software Foundation, either version 3 of the License, or      *
  *    (at your option) any later version.                                    *
  *                                                                           *
- *    KLog is distributed in the hope that it will be useful,             *
+ *    KLog is distributed in the hope that it will be useful,                *
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.       *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
 //#include <QtWidgets>
 //#include <QPalette>
 #include <QtWidgets>
+#include "utilities.h"
 
 class SetupPageColors : public QWidget {
     Q_OBJECT
@@ -42,12 +43,14 @@ public:
     QString getWorkedColor();
     QString getConfirmedColor();
     QString getDefaultColor();
+    QString getDarkMode();
 
-    void setNewOneColor(const QString c);
-    void setNeededColor(const QString c);
-    void setWorkedColor(const QString c);
-    void setConfirmedColor(const QString c);
-    void setDefaultColor(const QString c);
+    void setNewOneColor(const QString &_c);
+    void setNeededColor(const QString &_c);
+    void setWorkedColor(const QString &_c);
+    void setConfirmedColor(const QString &_c);
+    void setDefaultColor(const QString &_c);
+    void setDarkMode(const QString _dm);
 
 
 
@@ -57,16 +60,17 @@ private slots:
     void slotWorkedColorButtonClicked();
     void slotNeededColorButtonClicked();
     void slotDefaultColorButtonClicked();
-
     void slotWSJTXButtonClicked();
     void slotKLogButtonClicked();
+    void slotSetDarkMode();
 
 
 private:
+    Utilities *util;
+    bool darkMode;
     void setDefaultColors();
     void setWSJTXColors();
     QColor giveColor (QColor c);
-
     QPalette palette;
 
     QPushButton *newOneColorButton;     // In ANY band
@@ -76,6 +80,7 @@ private:
     QPushButton *defaultColorButton;  // In this band
     QPushButton *wsjtxColorButton;  // In this band
     QPushButton *klogColorButton;  // In this band
+    QPushButton *darkModeButton;
 
     QColor color;
 /*
