@@ -111,7 +111,7 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     QRZCOMPasswordLabel = new QLabel(tr("Password"));
     QRZCOMActiveCheckBox = new QCheckBox(tr("Activate QRZ.com"), this);
     QRZCOMAutoCheckCheckBox = new QCheckBox(tr("Check automatically"), this);
-    QRZCOMAutoCheckCheckBox->setToolTip(tr("Check in Qrz.com all QRZ as they are entered"));
+    QRZCOMAutoCheckCheckBox->setToolTip(tr("Check in Qrz.com all Calls as they are entered"));
     //qDebug() << "SetupPageELog::SetupPageELog - 00050" << endl;
 
     QRZLogBookKeyLabel = new QLabel(tr("LogBook Key"));
@@ -145,7 +145,7 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     lotwDownGroup = new QGroupBox (tr("Download"));
 
     lotwUserLineEdit = new QLineEdit;
-    //lotwUserLineEdit->setValidator(new QRegularExpressionValidator(rx, this));
+    lotwUserLineEdit->setValidator(new QRegularExpressionValidator(rx, this));
 
     lotwPasswordLineEdit = new QLineEdit;
     lotwPasswordLineEdit->setEchoMode(QLineEdit::PasswordEchoOnEdit);
@@ -244,7 +244,8 @@ void SetupPageELog::slotQRZCallTextChanged()
    //qDebug() << "SetupPageELog::slotQRZCallTextChanged" << endl;
     int cursor = QRZCOMUserLineEdit->cursorPosition();
    //qDebug() << "SetupPageELog::slotQRZCallTextChanged-1" << endl;
-    QString aux = QRZCOMUserLineEdit->text();
+
+    QString aux = util->getClearSQLi (QRZCOMUserLineEdit->text());
    //qDebug() << "SetupPageELog::slotQRZCallTextChanged-2" << endl;
 
     if (util->isValidCall(aux))
@@ -269,7 +270,8 @@ void SetupPageELog::sloteQSLCallTextChanged()
 {
    //qDebug() << "SetupPageELog::sloteQSLCallTextChanged" << endl;
     int cursor = eQSLUserLineEdit->cursorPosition();
-    QString aux = eQSLUserLineEdit->text();
+
+    QString aux = util->getClearSQLi (eQSLUserLineEdit->text());
     if (util->isValidCall(aux))
     {
         eQSLUserLineEdit->setPalette(palBlack);
@@ -370,7 +372,7 @@ void SetupPageELog::setClubLogActive(const bool &_b)
 {
     clubLogActive = _b;
     clubLogActiveCheckBox->setChecked(clubLogActive);
-    //clubLogActiveCheckBox->setEnabled(clubLogActive);
+    clubLogSendInRealTimeCheckBox->setEnabled(clubLogActive);
 }
 
 void SetupPageELog::slotClubLogActive(const bool _s)
@@ -400,10 +402,10 @@ bool SetupPageELog::getClubLogRealTime()
 
  // Start of eQSL.CC
 
-void SetupPageELog::setEQSLEmail(const QString &c)
+void SetupPageELog::setEQSLUser(const QString &c)
 {
     eqslUser = c;
-    eQSLemailLabel->setText(eqslUser);
+    eQSLUserLineEdit->setText(eqslUser);
 }
 
 void SetupPageELog::setEQSLPassword(const QString &c)
@@ -434,10 +436,11 @@ void SetupPageELog::setEQSLActive(const bool _b)
 {
     eqslActive = _b;
     eQSLActiveCheckBox->setChecked(eqslActive);
+    //eQSLActiveCheckBox->setEnabled(eqslActive);
 }
 
 void SetupPageELog::slotEQSLActive(const bool _s)
-{   
+{
     //qDebug() << "SetupPageELog::slotEQSLActive: "  << util->boolToQString(_s) << endl;
     eQSLemailLabel->setEnabled(_s);
     eQSLpasswordLabel->setEnabled(_s);
@@ -446,7 +449,7 @@ void SetupPageELog::slotEQSLActive(const bool _s)
 }
 
 void SetupPageELog::slotTQSLActive(const bool _s)
-{    
+{
     //qDebug() << "SetupPageELog::slotTQSLActive: " << util->boolToQString(_s) << endl;
     setLoTWActive(_s);
 }
@@ -461,7 +464,7 @@ void SetupPageELog::setLoTWActive(const bool &_s)
     lotwTQSL = _s;
     lotwUseTQSLCheckBox->setChecked(lotwTQSL);
     lotwTQSLPathLineEdit->setEnabled(lotwTQSL);
-    lotwSearchTQSLPushButton->setEnabled(lotwTQSL);
+    lotwSearchTQSLPushButton->setEnabled(_s);
     //lotwUserLineEdit->setEnabled(_s);
     //lotwPasswordLineEdit->setEnabled(_s);
 }
@@ -487,16 +490,18 @@ QString SetupPageELog::getTQSLPath()
 void SetupPageELog::slotSelectTQSLClicked()
 {
       //qDebug() << "SetupPageELogr::slotSelectTQSLClicked: " << QStandardPaths::ApplicationsLocation << endl;
-    QString appsDir;
-    QString executableName, proposedName;
-    proposedName = util->getTQSLsFileName();
-    appsDir = util->getTQSLsPath();
+    QString appsDir= util->getTQSLsPath();
+    QString proposedName = util->getTQSLsFileName();
+
     QString filter;
     filter.clear();
     #if defined(Q_OS_WIN)
         filter = "TQSL (*.exe)";
+    #elif defined(Q_OS_MACOS)
+        filter = "TQSL (*.app)";
     #else
         filter = "TQSL (tqsl)";
+        //filter = "TQSL (tqsl*)";
     #endif
     QString tqslFile;
     tqslFile.clear();
@@ -562,6 +567,7 @@ void SetupPageELog::setQRZCOMActive(const QString &_s)
     //qDebug() << "SetupPageELog::setQRZCOMActive " << endl;
     qrzcomActive = util->trueOrFalse(_s);
     QRZCOMActiveCheckBox->setChecked(qrzcomActive);
+    QRZCOMAutoCheckCheckBox->setEnabled(qrzcomActive);
 }
 
 bool SetupPageELog::SetupPageELog::getQRZCOMActive()
@@ -645,7 +651,7 @@ bool SetupPageELog::getQRZCOMAutoCheck()
 void SetupPageELog::setQRZCOMAutoCheck(const QString &_s)
 {
     qrzcomAutoFill = util->trueOrFalse(_s);
-    QRZCOMAutoCheckCheckBox->setEnabled(qrzcomAutoFill);
+    QRZCOMAutoCheckCheckBox->setChecked(qrzcomAutoFill);
 }
 
 void SetupPageELog::showEvent(QShowEvent *event)
