@@ -9,20 +9,20 @@
  ***************************************************************************/
 
 /*****************************************************************************
- * This file is part of KLog.                                             *
+ * This file is part of KLog.                                                *
  *                                                                           *
- *    KLog is free software: you can redistribute it and/or modify        *
+ *    KLog is free software: you can redistribute it and/or modify           *
  *    it under the terms of the GNU General Public License as published by   *
  *    the Free Software Foundation, either version 3 of the License, or      *
  *    (at your option) any later version.                                    *
  *                                                                           *
- *    KLog is distributed in the hope that it will be useful,             *
+ *    KLog is distributed in the hope that it will be useful,                *
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.       *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
@@ -60,7 +60,7 @@ public:
     QString getLoTWPass();
 
     // eQSL
-    void setEQSLEmail(const QString &c);
+    void setEQSLUser(const QString &c);
     void setEQSLPassword(const QString &c);
     void setEQSLActive(const bool _b);
     //void setEQSLRealTime(const QString &_s);
@@ -113,13 +113,13 @@ private:
     //QString defaultFileName;
     QGroupBox *clubLogGroup;
     QCheckBox *clubLogSendInRealTimeCheckBox, *clubLogActiveCheckBox;//, *useQSOStationCallCheckBox;
-    QLineEdit *clubLogPasswordLineEdit, *clubLogEmailLineEdit;//, *callLineEdit;   
+    QLineEdit *clubLogPasswordLineEdit, *clubLogEmailLineEdit;//, *callLineEdit;
     QLabel *clubLogPasswordLabel, *clubLogEmailLabel; //*callLabel,
     QString clubLogEmail, clubLogPass;
     bool clubLogActive, clubLogRealTime;
 
     QGroupBox *eQSLccGroup;
-    QLineEdit *eQSLUserLineEdit, *eQSLPasswordLineEdit;    
+    QLineEdit *eQSLUserLineEdit, *eQSLPasswordLineEdit;
     QCheckBox *eQSLActiveCheckBox; //*eQSLSendInRealTimeCheckBox,
     QLabel *eQSLpasswordLabel, *eQSLemailLabel;
     bool eqslActive;
