@@ -1,8 +1,35 @@
+/***************************************************************************
+                          setuppagehamlib.cpp  -  description
+                             -------------------
+    begin                : feb 2018
+    copyright            : (C) 2018 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
 #include "setuppages/setuppagehamlib.h"
 
 SetupPageHamLib::SetupPageHamLib(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent)
 {
       //qDebug() << "SetupPageHamLib::SetupPageHamLib" << endl;
+    ready = false;
+    hamlibTestOK = false;
     hamlib = new HamLibClass();
     activateHamlibCheckBox = new QCheckBox();
     readOnlyModeCheckBox = new QCheckBox();
@@ -15,11 +42,18 @@ SetupPageHamLib::SetupPageHamLib(DataProxy_SQLite *dp, QWidget *parent) : QWidge
     flowControlComboBox = new QComboBox();
     parityComboBox = new QComboBox();
     stopBitsComboBox = new QComboBox();
+    hostAddressLineEdit = new QLineEdit();
+
+    portQSpinBox = new QSpinBox;
+
+    serialGroup = new QGroupBox;
+    networkGroup = new QGroupBox;
 
     //RTSCheckBox = new QCheckBox();
     //DTRCheckBox = new QCheckBox();
 
     scanSerialPortButton = new QPushButton();
+    testHamlibPushButton = new QPushButton();
 
     //serialBaudsSpinBox = new QSpinBox;
 
@@ -29,12 +63,63 @@ SetupPageHamLib::SetupPageHamLib(DataProxy_SQLite *dp, QWidget *parent) : QWidge
    //strings << "1200" << "2400" << "4800" << "9600" << "19200" << "38400" << "57600" << "115200";
     pollMax = 5000;
     pollMin = 10;
+    rigctlport = 4532;
+    networkRadio = false;
+    connect(scanSerialPortButton, SIGNAL(clicked(bool)), this, SLOT(slotScanPorts()) );
+    connect(testHamlibPushButton, SIGNAL(clicked(bool)), this, SLOT(slotTestHamlib()) );
 
 
+    connect(rigTypeComboBox, SIGNAL(currentIndexChanged (QString)), this, SLOT(slotRadioComboBoxChanged(QString)) );
+
     createUI();
     setDefaults();
+    ready = true;
+    slotTestHamlib();
+    //qDebug() << "SetupPageHamLib::SetupPageHamLib END" << endl;
+}
 
-      //qDebug() << "SetupPageHamLib::SetupPageHamLib END" << endl;
+void SetupPageHamLib::slotTestHamlib()
+{
+    QPalette pal = testHamlibPushButton->palette();
+    //qDebug() << Q_FUNC_INFO;
+    hamlib->stop ();
+    if (rigTypeComboBox->currentText ().contains ("NET rigctl"))
+    {
+        hamlib->setNetworkPort (portQSpinBox->value ());
+        hamlib->setNetworkAddress (hostAddressLineEdit->text ());
+    }
+    else
+    {
+        hamlib->setPort (serialPortComboBox->currentText());
+        hamlib->setSpeed (serialBaudsComboBox->currentText ());
+        hamlib->setParity(getParity ());
+        hamlib->setFlow(getFlowControl ());
+        hamlib->setStop(getStopBits ());
+        hamlib->setData(getDataBits ());
+    }
+
+    hamlib->setModelId (hamlib->getModelIdFromName (rigTypeComboBox->currentText ()));
+    hamlib->setPoll (2000);
+
+
+   if (hamlib->init (true))
+   {
+       //qDebug() << Q_FUNC_INFO << " - Tested OK";
+       testHamlibPushButton->setText (tr("Test: OK"));
+        pal.setColor(QPalette::Button, QColor(Qt::green));
+
+   }
+   else
+   {
+       //qDebug() << Q_FUNC_INFO << " - Tested NOK";
+       testHamlibPushButton->setText (tr("Test: NOK"));
+       pal.setColor(QPalette::Button, QColor(Qt::red));
+
+   }
+   //hamlib->stop ();
+   //testHamlibPushButton->setAutoFillBackground(true);
+   testHamlibPushButton->setPalette(pal);
+   testHamlibPushButton->update();
 }
 
 void SetupPageHamLib::fillSerialPortsComboBox()
@@ -45,41 +130,66 @@ void SetupPageHamLib::fillSerialPortsComboBox()
     //serialPortComboBox->setCurrentIndex(0);
 }
 
+void SetupPageHamLib::slotRadioComboBoxChanged(QString _r)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << _r;
+
+    if (_r == "NET rigctl")
+    {
+        serialGroup->setEnabled (false);
+        networkGroup->setEnabled (true);
+        //qDebug() << Q_FUNC_INFO << ": Network radio found!" ;
+        networkRadio = true;
+    }
+    else
+    {
+        serialGroup->setEnabled (true);
+        networkGroup->setEnabled (false);
+        networkRadio = false;
+    }
+}
+
 void SetupPageHamLib::createUI()
 {
-      //qDebug() << "SetupPageHamLib::createUI" << endl;
-
-    connect(scanSerialPortButton, SIGNAL(clicked(bool)), this, SLOT(slotScanPorts()) );
+    //qDebug() << Q_FUNC_INFO;
 
     activateHamlibCheckBox->setText(tr("Activate HamLib"));
     activateHamlibCheckBox->setToolTip(tr("Activates the hamlib support that will enable the connection to a radio."));
     readOnlyModeCheckBox->setText(tr("Read-Only mode"));
     readOnlyModeCheckBox->setToolTip(tr("If enabled, the KLog will read Freq/Mode from the radio but will never send any command to the radio."));
+    testHamlibPushButton->setText (tr("Test"));
+    testHamlibPushButton->setToolTip (tr("Click to test the connection to the radio"));
 
-    //RTSCheckBox->setText(tr("RTS on"));
-    //RTSCheckBox->setToolTip(tr("Setting RTS may be needed for some serial ports."));
-    //DTRCheckBox->setText(tr("DTR on"));
-    //DTRCheckBox->setToolTip(tr("Setting DTR may be needed for some serial ports."));
+    hostAddressLineEdit->setToolTip (tr("Enter the hostname or address of the radio."));
+    portQSpinBox->setToolTip (tr("Set de network port of the radio."));
+
+    serialGroup->setTitle (tr("Serial radio"));
+    networkGroup->setTitle (tr("Network radio"));
+
+    portQSpinBox->setMaximum (65535);
+    portQSpinBox->setMinimum (0);
+    portQSpinBox->setValue (rigctlport);
 
 
     rigTypeComboBox->clear();
     strings.clear();
     setRig();
-      //qDebug() << "SetupPageHamLib::createUI-20" << endl;
-    //serialPortComboBox->addItems(getAvailableSerialPorts());
+    //qDebug() << Q_FUNC_INFO << " - 10";
+
     fillSerialPortsComboBox();
-      //qDebug() << "SetupPageHamLib::createUI-21" << endl;
+    //qDebug() << Q_FUNC_INFO << " - 11";
+
     rigTypeComboBox->setCurrentIndex(0);
-      //qDebug() << "SetupPageHamLib::createUI-22" << endl;
+    //qDebug() << Q_FUNC_INFO << " - 12";
 
     QLabel *rigTypeLabel = new QLabel(tr("Radio"));
     rigTypeLabel->setBuddy(rigTypeComboBox);
     rigTypeLabel->setToolTip(tr("Select your rig."));
     rigTypeLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
     rigTypeLabel->setEnabled(true);
-      //qDebug() << "SetupPageHamLib::createUI-30" << endl;
-    QString pollTip = QString(tr("Defines the interval to poll the radio in msecs."));
+    //qDebug() << Q_FUNC_INFO << " - 30";
 
+    QString pollTip = QString(tr("Defines the interval to poll the radio in msecs."));
     pollIntervalQSpinBox->setToolTip(pollTip);
     pollIntervalQSpinBox->setMinimum(pollMin);
     pollIntervalQSpinBox->setMaximum(pollMax);
@@ -94,28 +204,30 @@ void SetupPageHamLib::createUI()
     pollIntervalLayout->addWidget(pollIntervalLabel);
     pollIntervalLayout->addWidget(pollIntervalQSpinBox);
 
-
+    QLabel *serialPortLabel = new QLabel();
+    //qDebug() << Q_FUNC_INFO << " - 40";
     serialPortComboBox->addItems(serialPorts);
-    QLabel *serialPortLabel = new QLabel(tr("Port"));
     serialPortLabel->setBuddy(serialPortComboBox);
-    serialPortLabel->setToolTip(tr("Select the serial port. Only the serial ports that are detected are shown."));
     serialPortLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
-    serialPortLabel->setEnabled(true);
-
-    scanSerialPortButton->setText(tr("Scan"));
-    scanSerialPortButton->setToolTip(tr("Click to identify the serial ports available in your computer."));
-      //qDebug() << "SetupPageHamLib::createUI-40" << endl;
-    strings.clear();
-    strings << "1200" << "2400" << "4800" << "9600" << "19200" << "38400" << "57600" << "115200";
-    serialBaudsComboBox->addItems(strings);
     QLabel *serialBaudsLabel = new QLabel(tr("Bauds"));
     serialBaudsLabel->setBuddy(serialBaudsComboBox);
     serialBaudsLabel->setToolTip(tr("Select the serial port speed."));
     serialBaudsLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
+    //qDebug() << Q_FUNC_INFO << " - 50";
+
+    serialPortLabel->setText (tr("Port"));
+    serialPortLabel->setToolTip(tr("Select the serial port. Only the serial ports that are detected are shown."));
+    serialPortLabel->setEnabled(true);
+    scanSerialPortButton->setText(tr("Scan"));
+    scanSerialPortButton->setToolTip(tr("Click to identify the serial ports available in your computer."));
+    //qDebug() << Q_FUNC_INFO << " - 56";
+    strings.clear();
+    strings << "1200" << "2400" << "4800" << "9600" << "19200" << "38400" << "57600" << "115200";
+    serialBaudsComboBox->addItems(strings);
     serialBaudsLabel->setEnabled(true);
 
-      //qDebug() << "SetupPageHamLib::createUI-50" << endl;
-    dataBitsComboBox = new QComboBox();
+    //qDebug() << Q_FUNC_INFO << " - 60";
+
     strings.clear();
     strings << tr("5 bits") << tr("6 bits") << tr("7 bits") << tr("8 bits");
     dataBitsComboBox->addItems(strings);
@@ -125,8 +237,7 @@ void SetupPageHamLib::createUI()
     dataBitsLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
     dataBitsLabel->setEnabled(true);
 
-      //qDebug() << "SetupPageHamLib::createUI-60" << endl;
-    flowControlComboBox = new QComboBox();
+    //qDebug() << Q_FUNC_INFO << " - 70";
     strings.clear();
     strings << tr("None") << tr("Hardware") << tr("Software XON/XOFF");
     flowControlComboBox->addItems(strings);
@@ -136,7 +247,7 @@ void SetupPageHamLib::createUI()
     flowControlLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
     flowControlLabel->setEnabled(true);
 
-    parityComboBox = new QComboBox();
+    //qDebug() << Q_FUNC_INFO << " - 80";
     strings.clear();
     strings << tr("No parity") << tr("Even") << tr("Odd") << tr("Space") << tr("Mark") ;
     parityComboBox->addItems(strings);
@@ -146,8 +257,7 @@ void SetupPageHamLib::createUI()
     parityLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
     parityLabel->setEnabled(true);
 
-
-    stopBitsComboBox = new QComboBox();
+    //qDebug() << Q_FUNC_INFO << " - 90";
     strings.clear();
     strings << tr("1 bit") << tr("1.5 bits") << tr("2 bits");
     stopBitsComboBox->addItems(strings);
@@ -156,52 +266,65 @@ void SetupPageHamLib::createUI()
     stopBitsLabel->setToolTip(tr("Select the serial stop bits."));
     stopBitsLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
     stopBitsLabel->setEnabled(true);
+    //qDebug() << Q_FUNC_INFO << " - 100";
 
-    //QHBoxLayout *checkLayout = new QHBoxLayout;
-    //checkLayout->addWidget(RTSCheckBox);
-    //checkLayout->addWidget(DTRCheckBox);
+    QHBoxLayout *radioLayout = new QHBoxLayout;
+    radioLayout->addWidget (rigTypeLabel);
+    radioLayout->addWidget (rigTypeComboBox);
+    radioLayout->addLayout (pollIntervalLayout);
+    radioLayout->addWidget (testHamlibPushButton);
 
-    QGridLayout *topData = new QGridLayout;
-    topData->addWidget(rigTypeLabel, 0, 0);
-    topData->addWidget(rigTypeComboBox, 0, 1);
-    topData->addLayout(pollIntervalLayout, 0, 2);
-    topData->addWidget(serialPortLabel, 1, 0);
-    topData->addWidget(serialPortComboBox, 1, 1);
-    topData->addWidget(scanSerialPortButton, 1, 2);
-    topData->addWidget(serialBaudsLabel, 2, 0);
-    topData->addWidget(serialBaudsComboBox, 2, 1);
-    topData->addWidget(dataBitsLabel, 3, 0);
-    topData->addWidget(dataBitsComboBox, 3, 1);
-    topData->addWidget(stopBitsLabel, 4, 0);
-    topData->addWidget(stopBitsComboBox, 4, 1);
-    topData->addWidget(flowControlLabel, 5, 0);
-    topData->addWidget(flowControlComboBox, 5, 1);
-    topData->addWidget(parityLabel, 6, 0);
-    topData->addWidget(parityComboBox, 6, 1);
-    //topData->addLayout(checkLayout, 7, 1);
+    QGridLayout *serialLayout = new QGridLayout;
+    serialLayout->addWidget(serialPortLabel, 1, 0);
+    serialLayout->addWidget(serialPortComboBox, 1, 1);
+    serialLayout->addWidget(scanSerialPortButton, 1, 2);
+    serialLayout->addWidget(serialBaudsLabel, 2, 0);
+    serialLayout->addWidget(serialBaudsComboBox, 2, 1);
+    serialLayout->addWidget(dataBitsLabel, 3, 0);
+    serialLayout->addWidget(dataBitsComboBox, 3, 1);
+    serialLayout->addWidget(stopBitsLabel, 4, 0);
+    serialLayout->addWidget(stopBitsComboBox, 4, 1);
+    serialLayout->addWidget(flowControlLabel, 5, 0);
+    serialLayout->addWidget(flowControlComboBox, 5, 1);
+    serialLayout->addWidget(parityLabel, 6, 0);
+    serialLayout->addWidget(parityComboBox, 6, 1);
+    serialGroup->setLayout (serialLayout);
 
+    QLabel *hostAddLabel = new QLabel(tr("Host/Address"));
+    hostAddLabel->setBuddy(hostAddressLineEdit);
+    hostAddLabel->setToolTip(tr("Enter the hostname or address of the radio."));
+    hostAddLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
+    hostAddLabel->setEnabled(true);
 
-    QGridLayout *mainLayout = new QGridLayout;
-    mainLayout->addLayout(topData, 0, 0);
-    //mainLayout->addWidget(dataBitsGroupBox, 1, 0);
-    //mainLayout->addWidget(stopBitsGroupBox, 1, 1);
-    //mainLayout->addWidget(handShakeGroupBox, 2, 0);
-    //mainLayout->addWidget(flowControlLineGroupBox, 2, 1);
+    QLabel *portNetLabel = new QLabel(tr("Port"));
+    portNetLabel->setBuddy(portQSpinBox);
+    portNetLabel->setToolTip(tr("Enter the port of the radio."));
+    portNetLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
+    portNetLabel->setEnabled(true);
+
+    QGridLayout *networkLayout = new QGridLayout;
+    //qDebug() << Q_FUNC_INFO << " - 120";
+    networkLayout->addWidget (hostAddLabel, 0, 0);
+    networkLayout->addWidget (hostAddressLineEdit, 0, 1);
+    networkLayout->addWidget (portNetLabel, 1, 0);
+    networkLayout->addWidget (portQSpinBox, 1, 1);
+
+    networkGroup->setLayout (networkLayout);
 
     QHBoxLayout *checkBoxLayout = new QHBoxLayout;
     checkBoxLayout->addWidget(activateHamlibCheckBox);
     checkBoxLayout->addWidget(readOnlyModeCheckBox);
 
+    QGridLayout *mLayout = new QGridLayout;
+    //QVBoxLayout *mLayout = new QVBoxLayout;
+    mLayout->addLayout(checkBoxLayout, 0, 1);
+    mLayout->addLayout (radioLayout, 1, 0);
+    mLayout->addWidget (serialGroup, 2, 0);
+    mLayout->addWidget (networkGroup, 2, 1);
 
-    QVBoxLayout *mLayout = new QVBoxLayout;
-    mLayout->addLayout(checkBoxLayout);
-    //mLayout->addWidget(activateHamlibCheckBox);
-    mLayout->addLayout(mainLayout);
-    //mLayout->setAlignment(activateHamlibCheckBox, Qt::AlignHCenter | Qt::AlignTop);
-
-
+    //qDebug() << Q_FUNC_INFO << " - 199";
     setLayout(mLayout);
-      //qDebug() << "SetupPageHamLib::createUI-END" << endl;
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void SetupPageHamLib::setRig()
@@ -262,7 +385,7 @@ QStringList SetupPageHamLib::getAvailableSerialPorts()
 
 void SetupPageHamLib::setDefaults()
 {
-      //qDebug() << "SetupPageHamLib::setDefaults" << endl;
+    //qDebug() << Q_FUNC_INFO;
     rigTypeComboBox->setCurrentIndex(0);
     serialPortComboBox->setCurrentIndex(0);
     serialBaudsComboBox->setCurrentIndex(0);
@@ -274,8 +397,7 @@ void SetupPageHamLib::setDefaults()
 
     //RTSCheckBox->setChecked(false);
     //DTRCheckBox->setChecked(false);
-      //qDebug() << "SetupPageHamLib::setDefaults-END" << endl;
-
+    //qDebug()  << Q_FUNC_INFO << " - END";
 }
 
 QString SetupPageHamLib::getData()
@@ -285,23 +407,20 @@ QString SetupPageHamLib::getData()
     _output.clear();
     QString _rigType, _serialPort, _baudsSpeed;//, dataBits, stopBits, handshake, flowControlLine;
 
-
     _rigType = rigTypeComboBox->currentText();
     _serialPort = serialPortComboBox->currentText();
     _baudsSpeed = serialBaudsComboBox->currentText();
 
-       //qDebug() << "SetupPageHamLib::getData: " << _rigType << endl;
-
-
     _output.clear();
     if (activateHamlibCheckBox->isChecked())
-    {        
+    {
         _output = _output + "Hamlib=True;\n";
     }
     else
     {
 
     }
+
     if (readOnlyModeCheckBox->isChecked())
     {
         _output = _output + "HamlibReadOnly=True;\n";
@@ -310,30 +429,21 @@ QString SetupPageHamLib::getData()
     {
         _output = _output + "HamlibReadOnly=False;\n";
     }
-    //if (RTSCheckBox->isChecked())
-    //{
-    //    _output = _output + "HamLibSerialRTS=True;\n";
-    //}
-    //if (DTRCheckBox->isChecked())
-    //{
-    //    _output = _output + "HamLibSerialDTR=True;\n";
-    //}
+
+    _output = _output + "HamLibRigType=" + QString::number(hamlib->getModelIdFromName(_rigType)) + ";\n";
+    _output = _output + "HamlibRigPollRate=" + QString::number(pollIntervalQSpinBox->value()) + ";\n";
+    _output = _output + "HamlibSerialPort=" + _serialPort + ";\n";
+    _output = _output + "HamlibSerialBauds=" + _baudsSpeed + ";\n";
     _output = _output + getDataBits() + ";\n";
-      //qDebug() << "SetupPageHamLib::getData: dataBits: " << getDataBits() << endl;
     _output = _output + getStopBits() + ";\n";
     _output = _output + getFlowControl() + ";\n";
     _output = _output + getParity() + ";\n";
 
-
-      //qDebug() << "SetupPageHamLib::getData: " << QString::number(hamlib->getModelIdFromName(_rigType)) << endl;
-    _output = _output + "HamLibRigType=" + QString::number(hamlib->getModelIdFromName(_rigType)) + ";\n";
-    //_output = _output + "HamLibRigType=" + _rigType + "\n";
-    _output = _output + "HamlibSerialPort=" + _serialPort + ";\n";
-    _output = _output + "HamlibSerialBauds=" + _baudsSpeed + ";\n";
-    _output = _output + "HamlibRigPollRate=" + QString::number(pollIntervalQSpinBox->value()) + ";\n";
-
-
-      //qDebug() << "SetupPageHamLib::getData: " << _output << endl;
+    if (hostAddressLineEdit->text ().length()>1)
+    {
+        _output = _output + "HamlibNetAddress=" + hostAddressLineEdit->text() + ";\n";
+        _output = _output + "HamlibNetPort=" + QString::number(portQSpinBox->value()) + ";\n";
+    }
     return _output;
 }
 
@@ -615,28 +725,21 @@ void SetupPageHamLib::setPollingInterval(const int _msecs)
     }
 }
 
-/*
-void SetupPageHamLib::setRTS(const QString &_state)
+void SetupPageHamLib::setRadioNetworkAddress(const QString &_m)
 {
-    //if (_state.toUpper() == "TRUE")
-    //{
-    //    RTSCheckBox->setChecked(true);
-    //}
-    //else
-    //{
-    //    RTSCheckBox->setChecked(false);
-    //}
+    if (_m.length ()>0)
+    {
+        hostAddressLineEdit->setText (_m);
+    }
+
 }
 
-void SetupPageHamLib::setDTR(const QString &_state)
+void SetupPageHamLib::setRadioNetworkPort(const int _p)
 {
-    //if (_state.toUpper() == "TRUE")
-    //{
-    //    DTRCheckBox->setChecked(true);
-    //}
-    //else
-    //{
-    //    DTRCheckBox->setChecked(false);
-    //}
+    if ((_p>0) && (_p<65535))
+    {
+        portQSpinBox->setValue (_p);
+    }
 }
-*/
+
+
