@@ -1,6 +1,5 @@
 #ifndef SETUPPAGEHAMLIB_H
 #define SETUPPAGEHAMLIB_H
-
 /***************************************************************************
                           setuppagehamlib.h  -  description
                              -------------------
@@ -23,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
@@ -35,7 +34,6 @@
 #include "dataproxy_sqlite.h"
 #include <hamlib/rig.h>
 
-
 class SetupPageHamLib : public QWidget
 {
     Q_OBJECT
@@ -55,13 +53,16 @@ public:
     void setStopBits(const QString &_st);
     //void setPollInterval(const QString &_st);
     void setReadOnly(const QString &_m);
-
+    void setRadioNetworkAddress(const QString &_m);
+    void setRadioNetworkPort(const int _p);
 
 
 signals:
 
 public slots:
     void slotScanPorts();
+    void slotRadioComboBoxChanged(QString _r);
+    void slotTestHamlib();
 
 private:
     void createUI();
@@ -76,6 +77,7 @@ private:
     QString getParity();
     QString getStopBits();
     QString getPollInterval();
+    QString getNetworkSettings();
 
 /*
 
@@ -85,14 +87,15 @@ Parity { NoParity, EvenParity, OddParity, SpaceParity, MarkParity, UnknownParity
 StopBits { OneStop, OneAndHalfStop, TwoStop, UnknownStopBits }
 
 */
-
-    QPushButton *scanSerialPortButton;
+    QPushButton *scanSerialPortButton, *testHamlibPushButton;
     QComboBox *rigTypeComboBox, *serialBaudsComboBox, *serialPortComboBox, *dataBitsComboBox,
                 *flowControlComboBox, *parityComboBox, *stopBitsComboBox;
     //QSpinBox *serialBaudsSpinBox;
-    QLineEdit *serialPort;
-    QSpinBox *pollIntervalQSpinBox;
-    int pollMin, pollMax;
+
+    QLineEdit *serialPort, *hostAddressLineEdit;
+    QSpinBox *pollIntervalQSpinBox, *portQSpinBox;
+    int pollMin, pollMax, rigctlport;
+
 
     HamLibClass *hamlib;
 
@@ -102,7 +105,9 @@ StopBits { OneStop, OneAndHalfStop, TwoStop, UnknownStopBits }
 
     QStringList strings, serialPorts;
     QCheckBox *activateHamlibCheckBox, *readOnlyModeCheckBox; //, *RTSCheckBox, *DTRCheckBox;
+    bool networkRadio, ready, hamlibTestOK;
 
+    QGroupBox *serialGroup, *networkGroup;
 
     //int defaultPortSpeed;
 };
