@@ -42,7 +42,7 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     useDefaultName = new QCheckBox(tr("Use this &default filename"), this);
     sendQSLWhenRecCheckBox = new QCheckBox(tr("Mark &QSO to send QSL when QSL is received"), this);
     completeWithPreviousCheckBox = new QCheckBox(tr("Complete QSO with previous data"));
-    showStationCallWhenSearchCheckBox = new QCheckBox(tr("Show the Station &Callsign used in the search box"), this);  
+    showStationCallWhenSearchCheckBox = new QCheckBox(tr("Show the Station &Callsign used in the search box"), this);
     //keepMyDataCheckBox = new QCheckBox(tr("&Reset to My Data for all QSOs"), this);
     checkNewVersionCheckBox = new QCheckBox(tr("&Check for new versions automatically"), this);
     provideCallCheckBox = new QCheckBox(tr("&Provide Info for statistics"), this);
@@ -50,8 +50,10 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     debugLogCheckBox = new QCheckBox(tr("Activate the application debug log"));
     //logSortCheckBox = new QCheckBox(tr("Sort log based in date && time"));
     sendEQSLByDefaultSearchCheckBox = new QCheckBox(tr("Mark sent eQSL && LoTW in new QSO as queued"));
+    deleteAlwaysAdiFileCheckBox = new QCheckBox(tr("&Delete always temp ADIF file after uploading QSOs"));
 
 
+    dupeTimeLineEdit = new QLineEdit;
     defaultFileNameLineEdit = new QLineEdit;
     dbPathLineEdit = new QLineEdit;
 
@@ -81,7 +83,8 @@ SetupPageMisc::~SetupPageMisc(){
 
 void SetupPageMisc::createUI()
 {
-
+    dupeTimeLineEdit->setInputMask("0000000");
+    dupeTimeLineEdit->setToolTip(tr("In seconds, enter the time range to consider a duplicate if same call, band and mode is entered."));
     palWrong.setColor(QPalette::Text, Qt::red);
     palRight.setColor(QPalette::Text, Qt::black);
 
@@ -105,7 +108,7 @@ void SetupPageMisc::createUI()
     dbPathLineEdit->setReadOnly(false);
     dbPathLineEdit->setText(dbDirCurrent);
     dbPathLineEdit->setEnabled(true);
-    
+
     //UDPServerCheckBox->setChecked(true);
     //UDPServerPortSpinBox->setEnabled(true);
     //UDPServerCheckBox->setEnabled(false);
@@ -122,7 +125,7 @@ void SetupPageMisc::createUI()
     //logSortCheckBox->setChecked(false);
     defaultFileNameLineEdit->setEnabled(true);
     fileNameButton->setEnabled(true);
-
+    dupeTimeLineEdit->setText("300");
     sendQSLWhenRecCheckBox->setToolTip(tr("QSOs will be marked as pending to send a QSL if you receive the DX QSL and have not sent yours."));
     showStationCallWhenSearchCheckBox->setToolTip(tr("The search box will also show the callsign on the air to do the QSO."));
     //keepMyDataCheckBox->setToolTip(tr("All the data from the My Data tab will be used or data from the previous QSO will be maintained."));
@@ -131,7 +134,7 @@ void SetupPageMisc::createUI()
     imperialCheckBox ->setToolTip(tr("Check it for Imperial system (Miles instead of Kilometers)."));
     realTimeCheckbox->setToolTip(tr("Select to use real time."));
     UTCCheckbox->setToolTip(tr("Select to use UTC time."));
-    alwaysADIFCheckBox->setToolTip(tr("Select if you want to save to ADIF on exit."));    
+    alwaysADIFCheckBox->setToolTip(tr("Select if you want to save to ADIF on exit."));
     useDefaultName->setToolTip(tr("Select to use the following name for the logfile without being asked for it again."));
     completeWithPreviousCheckBox->setToolTip(tr("Complete the current QSO with previous QSO data."));
     useDxMarathonCheckBox->setToolTip(tr("Select if you want to manage DX-Marathon."));
@@ -143,6 +146,7 @@ void SetupPageMisc::createUI()
     debugLogCheckBox->setToolTip(tr("Activates the application debug log. This may be useful if something is not working as expected. A debug file will be created in the KLog directory."));
     //logSortCheckBox->setToolTip(tr("Click to enable that log will be sorted based on date and time when clicking on the date column. It may be a little bit slower."));
     sendEQSLByDefaultSearchCheckBox->setToolTip(tr("Click to mark as Queued (to be sent) all the eQSL (LoTW and eQSL) in all the new QSO by default."));
+    deleteAlwaysAdiFileCheckBox->setToolTip(tr("Delete Always the adif file created after uploading QSOs"));
 
     QHBoxLayout *fileLayout = new QHBoxLayout;
     fileLayout->addWidget(useDefaultName);
@@ -155,6 +159,12 @@ void SetupPageMisc::createUI()
     dbLayout->addWidget(dbPushButton);
     dbLayout->addWidget(moveDBPushButton);
 
+    QLabel *timeRangeLabel = new QLabel;
+    timeRangeLabel->setText(tr("Dupe time range:"));
+    QHBoxLayout *timeRangeLayout = new QHBoxLayout;
+    timeRangeLayout->addWidget(timeRangeLabel);
+    timeRangeLayout->addWidget(dupeTimeLineEdit);
+
     QGridLayout *mainLayou1 = new QGridLayout;
     mainLayou1->addLayout(fileLayout, 0, 0, 1, -1);
     mainLayou1->addLayout(dbLayout, 1, 0, 1, -1);
@@ -164,7 +174,7 @@ void SetupPageMisc::createUI()
     mainLayou1->addWidget(realTimeCheckbox, 3, 1, 1, 1);
     mainLayou1->addWidget(imperialCheckBox, 4, 0, 1, 1);
     mainLayou1->addWidget(useDxMarathonCheckBox, 4, 1, 1, 1);
-    //mainLayou1->addWidget(keepMyDataCheckBox, 5, 0, 1, 1);
+    mainLayou1->addLayout(timeRangeLayout, 5, 0, 1, 1);
     mainLayou1->addWidget(completeWithPreviousCheckBox, 5, 1, 1, 1);
     mainLayou1->addWidget(sendQSLWhenRecCheckBox,6, 0, 1, 1);
     mainLayou1->addWidget(sendEQSLByDefaultSearchCheckBox, 6, 1, 1, 1);
@@ -172,6 +182,7 @@ void SetupPageMisc::createUI()
     mainLayou1->addWidget(provideCallCheckBox, 7, 1, 1, 1);
     //mainLayou1->addWidget(logSortCheckBox, 8, 0, 1, 1);
     mainLayou1->addWidget(showStationCallWhenSearchCheckBox, 8, 0, 1, 1);
+    mainLayou1->addWidget(deleteAlwaysAdiFileCheckBox, 8, 1, 1, 1);
 
     setLayout(mainLayou1);
 
@@ -191,6 +202,17 @@ void SetupPageMisc::createActions(){
 
 }
 
+void SetupPageMisc::setDeleteAlwaysAdiFile(const bool &_t){
+
+    deleteAlwaysAdiFileCheckBox->setChecked(_t);
+    //qDebug() << "SetupPageMisc::setDeleteAlwaysAdiFile - DELETEALWAYSADIFILE = " << _t << endl;
+}
+
+QString SetupPageMisc::getDeleteAlwaysAdiFile(){
+
+    return util->boolToQString(deleteAlwaysAdiFileCheckBox->isChecked());
+}
+
 QString SetupPageMisc::getSendEQSLByDefault(){
 
     return util->boolToQString(sendEQSLByDefaultSearchCheckBox->isChecked());
@@ -373,7 +395,7 @@ void SetupPageMisc::setReportInfo(const QString &_t)
 }
 
 QString SetupPageMisc::getDefaultDBPath()
-{    
+{
     return dbDirCurrent;
 }
 
@@ -550,3 +572,13 @@ bool SetupPageMisc::areDBPathChangesApplied()
 {
     return dbPathApplied;
 }
+
+void SetupPageMisc::setDupeTime(const int _t)
+{
+    dupeTimeLineEdit->setText(QString::number(_t));
+}
+
+int SetupPageMisc::getDupeTime()
+{
+    return dupeTimeLineEdit->text().toInt();
+}
