@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 
@@ -73,6 +73,11 @@ public:
     //void setLogSort(const QString &_t);
     QString getSendEQSLByDefault();
     void setSetEQSLByDefault(const QString &_t);
+    void setDeleteAlwaysAdiFile(const bool &_t);
+    QString getDeleteAlwaysAdiFile();
+
+    void setDupeTime(const int _t);
+    int getDupeTime();
 
     bool areDBPathChangesApplied();
 
@@ -97,11 +102,11 @@ private:
     QCheckBox *imperialCheckBox, *sendQSLWhenRecCheckBox, *showStationCallWhenSearchCheckBox;
     QCheckBox *checkNewVersionCheckBox, *provideCallCheckBox, *useDxMarathonCheckBox, *debugLogCheckBox;
     //QCheckBox *logSortCheckBox;
-    QCheckBox *sendEQSLByDefaultSearchCheckBox;
+    QCheckBox *sendEQSLByDefaultSearchCheckBox, *deleteAlwaysAdiFileCheckBox;
     QString defaultFileName;
     QLineEdit *defaultFileNameLineEdit, *dbPathLineEdit;
     QPushButton *fileNameButton, *dbPushButton, *moveDBPushButton;
-
+    QLineEdit *dupeTimeLineEdit;
 
     QString klogDir, dbDirNew, dbDirCurrent; //TODO: To be removed when the defaultDir is saved in the config file
     QPalette palRight, palWrong; // To paint Text in red or black(normal)
