@@ -9,27 +9,27 @@
  ***************************************************************************/
 
 /*****************************************************************************
- * This file is part of KLog.                                             *
+ * This file is part of KLog.                                                *
  *                                                                           *
- *    KLog is free software: you can redistribute it and/or modify        *
+ *    KLog is free software: you can redistribute it and/or modify           *
  *    it under the terms of the GNU General Public License as published by   *
  *    the Free Software Foundation, either version 3 of the License, or      *
  *    (at your option) any later version.                                    *
  *                                                                           *
- *    KLog is distributed in the hope that it will be useful,             *
+ *    KLog is distributed in the hope that it will be useful,                *
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.       *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 //
 // This class implements the Dialog to add a new satellite
 //
 #include "dataproxy_sqlite.h"
-
+#include "utilities.h"
 #include <QDialog>
 #include <QtWidgets>
 #include <QSqlQuery>
@@ -84,6 +84,7 @@ private:
 
 
     DataProxy_SQLite *dataProxy;
+    Utilities *util;
 
     QLineEdit *shortNameLineEdit, *nameLineEdit;
     QLineEdit *uplinkLineEdit, *downlinkLineEdit;
