@@ -1,8 +1,34 @@
+/***************************************************************************
+                          setuppageudp.cpp  -  description
+                             -------------------
+    begin                : sept 2018
+    copyright            : (C) 2018 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "setuppages/setuppageudp.h"
 
 SetupPageUDP::SetupPageUDP(QWidget *parent) : QWidget(parent)
 {
-    
+    //qDebug() << "SetupPageUDP::SetupPageUDP" << Qt::endl;
     logFromWSJTXCheckbox = new QCheckBox(this);
     realDataFromWSJTXCheckbox  = new QCheckBox(this);
     logAutomaticallyWSJTXCheckbox  = new QCheckBox(this);
@@ -11,6 +37,7 @@ SetupPageUDP::SetupPageUDP(QWidget *parent) : QWidget(parent)
     UDPServerPortSpinBox = new QSpinBox;
     miliSecsSpinBox = new QSpinBox;
     networkInterfacesComboBox = new QComboBox;
+    //qDebug() << "SetupPageUDP::SetupPageUDP: 1" << Qt::endl;
     util = new Utilities;
 
     //wsjtxIPAddress = new QLineEdit(this);
@@ -18,13 +45,17 @@ SetupPageUDP::SetupPageUDP(QWidget *parent) : QWidget(parent)
     //logFromWSJTx = false;
     //autoLogFromWSJTx = false;
     //realDataFromWSJTx = false;
-    
+
     defaultport = 2237;     // Default WSJTX port
     defaultTimer = 2000;  // 2 secs
 
+    //qDebug() << "SetupPageUDP::SetupPageUDP: 2" << Qt::endl;
     createUI();
+    //qDebug() << "SetupPageUDP::SetupPageUDP: 3" << Qt::endl;
     createActions();
+    //qDebug() << "SetupPageUDP::SetupPageUDP: 4" << Qt::endl;
     fillNetworkInterfaceComboBox();
+    //qDebug() << "SetupPageUDP::SetupPageUDP - END" << Qt::endl;
 }
 
 SetupPageUDP::~SetupPageUDP(){
@@ -44,7 +75,7 @@ void SetupPageUDP::createUI()
 
     realDataFromWSJTXCheckbox->setText(tr("Update status information from WSJT-X"));
     realDataFromWSJTXCheckbox->setToolTip(tr("KLog will automatically show and update data coming from WSJT-X (DX callsign, Report, mode, ...)"));
-    
+
     UDPServerCheckBox->setChecked(false);
     logFromWSJTXCheckbox->setChecked(false);
     logAutomaticallyWSJTXCheckbox->setChecked(false);
@@ -167,7 +198,7 @@ void SetupPageUDP::fillNetworkInterfaceComboBox()
             interfacesNames.append(i.humanReadableName() + "-" + i.hardwareAddress() );
         }
     }
-    interfacesNames.insert(-1, loopBack.humanReadableName());
+    interfacesNames.insert(0, loopBack.humanReadableName());
     networkInterfacesComboBox->addItems(interfacesNames);
 
 }
