@@ -1,3 +1,29 @@
+/***************************************************************************
+                          startwizard.cpp  -  description
+                             -------------------
+    begin                : feb 2015
+    copyright            : (C) 2015 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "startwizard.h"
 //#include <QDebug>
 
@@ -24,7 +50,7 @@
     setStartId(Page_Intro);
 
     QAbstractButton* finishButton = this->button(QWizard::FinishButton);
-    QAbstractButton* cancelButton = this->button(QWizard::CancelButton);    
+    QAbstractButton* cancelButton = this->button(QWizard::CancelButton);
     connect(finishButton, SIGNAL(clicked()), this, SLOT(slotButtonFinishedClicked()));
 
     disconnect( cancelButton, SIGNAL( clicked() ), this, SLOT( reject() ) );
@@ -150,7 +176,7 @@
 
     QString welcometxt = "<html><head><title>" + tr("Welcome to KLog") + "</title></head><body>" +
                             "<p>" + tr("This looks like it's the first time you've run KLog on this computer.") + "</p>" +
-                            "<p>" + tr("KLog is a free hamradio logging program that can run on Linux, macOS, and Windows.") +
+                            "<p>" + tr("KLog is a free hamradio logging program that can run on GNU/Linux, macOS, and Windows.") +
                             tr("It is designed to provide general purpose DX, and contest logging.") + "</p>" +
                             "<p>" + tr("It supports QSL management, import and export of ADIF ") +
                             tr("and Cabrillo file formats and many other features...") + "</p><p>" +
@@ -863,21 +889,21 @@ FileOrMemoryPage::FileOrMemoryPage(QWidget *parent)
 
       topLabel->setWordWrap(true);
 
-      memoryRadioButton = new QRadioButton(tr("Run KLog DB in &memory"));
-      fileRadioButton = new QRadioButton(tr("Run KLog DB in a &file"));
-      //memoryRadioButton->setChecked(true);
-      memoryRadioButton->setChecked(false);
-      fileRadioButton->setChecked(true);
-      memoryRadioButton->setToolTip(tr("Recommended for day-to-day logging"));
-      fileRadioButton->setToolTip(tr("Recommended for contest logging"));
+      memoryQCheckbox = new QCheckBox(tr("Run KLog DB in &memory"));
+      fileQCheckbox = new QCheckBox(tr("Run KLog DB in a &file"));
+      //memoryQCheckbox->setChecked(true);
+      memoryQCheckbox->setChecked(false);
+      fileQCheckbox->setChecked(true);
+      memoryQCheckbox->setToolTip(tr("Recommended for day-to-day logging"));
+      fileQCheckbox->setToolTip(tr("Recommended for contest logging"));
 
-      connect( memoryRadioButton, SIGNAL(toggled(bool) ), this, SLOT(slotRunningModeSelectedMemory(bool)));
-      connect( fileRadioButton, SIGNAL(toggled(bool) ), this, SLOT(slotRunningModeSelectedFile(bool)));
+      connect( memoryQCheckbox, SIGNAL(toggled(bool) ), this, SLOT(slotRunningModeSelectedMemory(bool)));
+      connect( fileQCheckbox, SIGNAL(toggled(bool) ), this, SLOT(slotRunningModeSelectedFile(bool)));
 
       QVBoxLayout *layout = new QVBoxLayout;
       layout->addWidget(topLabel);
-      layout->addWidget(memoryRadioButton);
-      layout->addWidget(fileRadioButton);
+      layout->addWidget(memoryQCheckbox);
+      layout->addWidget(fileQCheckbox);
       setLayout(layout);
 }
 
