@@ -1,3 +1,29 @@
+/***************************************************************************
+                          statisticswidget.cpp  -  description
+                             -------------------
+    begin                : oct 2020
+    copyright            : (C) 2020 by Jaime Robles
+    user                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "statisticswidget.h"
 
 StatisticsWidget::StatisticsWidget(DataProxy_SQLite *dp, QWidget *parent): QWidget(parent)
@@ -18,7 +44,7 @@ StatisticsWidget::StatisticsWidget(DataProxy_SQLite *dp, QWidget *parent): QWidg
     connect(statisticToShowComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotChartComboBoxChanged() ) ) ;
     connect(logComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotLogComboBoxChanged() ) ) ;
 
-    barChartStats->prepareChart(1);
+    //barChartStats->prepareChart(1);
 
 }
 
@@ -43,35 +69,36 @@ void StatisticsWidget::closeEvent(QCloseEvent *event)
 void StatisticsWidget::showEvent(QShowEvent *event)
 {
       //qDebug() << "StatisticsWidget::showEvent" << endl;
-    barChartStats->clear();
+    //barChartStats->clear();
     fillLogCombo();
     event->accept();
 }
 
 void StatisticsWidget::slotChartComboBoxChanged()
-{    
+{
        //qDebug() << "StatisticsWidget::slotChartComboBoxChanged: " << statisticToShowComboBox->currentText()  << endl;
-    //QString text = statisticToShowComboBox->currentText();
-    //text.truncate(2);
 
-
-    //barChartStats->prepareChart(text.toInt());
     updateChart();
     statisticToShowComboBox->setFocus();
 }
 
 void StatisticsWidget::slotLogComboBoxChanged()
 {
-
+    updateChart();
+    logComboBox->setFocus();
 }
 
 void StatisticsWidget::updateChart()
 {
     QString text = statisticToShowComboBox->currentText();
     text.truncate(2);
-    int log = ((logComboBox->currentText()).left((logComboBox->currentText()).indexOf('-')+1)).toInt();
-
+    //int log = ((logComboBox->currentText()).left((logComboBox->currentText()).indexOf('-')+1)).toInt();
+    int log = ((logComboBox->currentText()).section('-', 0, 0)).toInt();
+    //qDebug() << Q_FUNC_INFO << " Text : " << logComboBox->currentText() << endl;
+    //qDebug() << Q_FUNC_INFO << " Log : " << QString::number(log) << endl;
+    //barChartStats = new BarChartStats(dataProxy, this);
     barChartStats->prepareChart(text.toInt(), log);
+
 }
 
 void StatisticsWidget::createUI()
@@ -88,21 +115,24 @@ void StatisticsWidget::createUI()
      statisticsToShowList << "10-" + tr("Worked / Confirmed status");
      statisticsToShowList << "11-" + tr("Worked / Sent status");
      statisticsToShowList << "12-" + tr("Sent / Confirmed status");
+     statisticsToShowList << "13-" + tr("Satellite grid status");
+     statisticsToShowList << "14-" + tr("Satellite DXCC status");
+     statisticsToShowList << "15-" + tr("Grids per band status");
+     statisticsToShowList << "16-" + tr("DXCC per band status");
 
      statisticToShowComboBox->addItems(statisticsToShowList);
 
     fillLogCombo();
 
-     QHBoxLayout *hLayout = new QHBoxLayout;
-     hLayout->addWidget(statisticToShowComboBox);
-     hLayout->addWidget(logComboBox);
+    QHBoxLayout *hLayout = new QHBoxLayout;
+    hLayout->addWidget(statisticToShowComboBox);
+    hLayout->addWidget(logComboBox);
 
      QVBoxLayout *layout = new QVBoxLayout;
      layout->addLayout(hLayout);
-     //layout->addWidget(statisticToShowComboBox);
-     //layout->addWidget(graphWidget);
      layout->addWidget(barChartStats);
      setLayout(layout);
+
      resize(420,300);
 
  }
@@ -123,18 +153,4 @@ void StatisticsWidget::fillLogCombo()
     logComboBox->clear();
     logComboBox->addItems(logs);
 
-/*
-    QStringList getListOfManagedLogs();
-    int getMaxLogNumber();
-    QString getStationCallSignFromLog(const int _log);
-    QStringList getStationCallSignsFromLog(const int _log);
-    QString getOperatorsFromLog(const int _log);
-    QString getCommentsFromLog(const int _log);
-    QString getLogDateFromLog(const int _log);
-    QString getLogTypeNFromLog(const int _log);
-    bool addNewLog (const QStringList _qs);
-    bool doesThisLogExist(const int _log);
-
-
-*/
 }
