@@ -1,3 +1,29 @@
+/***************************************************************************
+                          udpserver.cpp  -  description
+                             -------------------
+    begin                : oct 2020
+    copyright            : (C) 2020 by Jaime Robles
+    user                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "udpserver.h"
 #include <QDateTime>
 //https://sourceforge.net/p/wsjt/wsjtx/ci/master/tree/UDPExamples/MessageServer.cpp
@@ -280,7 +306,11 @@ void UDPServer::parse(const QByteArray &msg)
                    >> fast_mode >> specialOpMode >> freqTolerance >> TRPeriod >> confName;
                 frequencyDouble = (double)frequency;
                 frequencyDouble = frequencyDouble/1000000; // Change to MHz
-
+               //if (!util->isValidCall(dx_call))
+               // {
+               //     //qDebug() << "UDPServer::parse: Status : Call not valid: -" << dx_call << "-" << endl;
+               //     return;
+               //}
                //qDebug() << "UDPServer::parse: Status - Freq double = " << QString::number(frequencyDouble)  << endl;
                //qDebug() << "UDPServer::parse: Status - Mode = " << mode << endl;
                //qDebug() << "UDPServer::parse: Status - DXCall = " << dx_call << endl;
@@ -324,7 +354,7 @@ void UDPServer::parse(const QByteArray &msg)
         break;
         case Clear:
             //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - OUT - Clear" << endl;
-            //emit clearSignal();
+            emit clearSignal();
         break;
         case Reply:
             //qDebug() << "UDPServer::parse: -   type = " << QString::number(type) << " - IN - Replay " << endl;
@@ -358,7 +388,7 @@ void UDPServer::parse(const QByteArray &msg)
 
 
                 //qDebug() << "UDPServer::parse: QSO to be logged: Time_on: " << time_on << endl;
-                //qDebug() << "UDPServer::parse: QSO to be logged: Time_off: " << time_off << endl;                
+                //qDebug() << "UDPServer::parse: QSO to be logged: Time_off: " << time_off << endl;
                 frequencyDouble = (double)frequency;
                 frequencyDouble = frequencyDouble/1000000; // Change to MHz
 
