@@ -1,3 +1,29 @@
+/***************************************************************************
+                          utilities.cpp  -  description
+                             -------------------
+    begin                : jun 2015
+    copyright            : (C) 2015 by Jaime Robles
+    email                : jaime@robles.es
+ ***************************************************************************/
+
+/*****************************************************************************
+ * This file is part of KLog.                                                *
+ *                                                                           *
+ *    KLog is free software: you can redistribute it and/or modify           *
+ *    it under the terms of the GNU General Public License as published by   *
+ *    the Free Software Foundation, either version 3 of the License, or      *
+ *    (at your option) any later version.                                    *
+ *                                                                           *
+ *    KLog is distributed in the hope that it will be useful,                *
+ *    but WITHOUT ANY WARRANTY; without even the implied warranty of         *
+ *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
+ *    GNU General Public License for more details.                           *
+ *                                                                           *
+ *    You should have received a copy of the GNU General Public License      *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
+ *                                                                           *
+ *****************************************************************************/
+
 #include "utilities.h"
 
 Utilities::Utilities()
@@ -157,7 +183,7 @@ QString Utilities::getAgent(const QString &_klogversion)
     QString version;
     QString ops;
     version = _klogversion;
-    
+
 #if defined(Q_OS_WIN32)
     ops = "KLog-Win32-";
 #elif defined(Q_OS_WIN64)
@@ -286,7 +312,8 @@ QString Utilities::getKLogDBFile()
     dbPath = getKLogDefaultDatabaseFile();
     QFile file(getCfgFile());
 
-    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))  /* Flawfinder: ignore */
+    {
 
         //return dbPath;
         //return getKLogDatabaseFile(dbPath);
@@ -314,7 +341,8 @@ QString Utilities::getKLogDBBackupFile()
     dbPath = getKLogDefaultDatabaseFile();
     QFile file(getCfgFile());
 
-    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) /* Flawfinder: ignore */
+    {
 
         //return dbPath;
         //return getKLogDatabaseFile(dbPath);
@@ -451,7 +479,7 @@ QString Utilities::getTQSLsFileName()
     return "tqsl.exe";
 #elif   defined(Q_OS_MACOS)
       //qDebug() << "macOS DETECTED!: "   << endl;
-    return "tqsl";
+    return "tqsl.app";
 #else
          //qDebug() << "NO WINDOWS/macOS DETECTED!: "   << endl;
     return "tqsl";
@@ -470,7 +498,7 @@ QString Utilities::getTQSLsPath()
     return "C:/Program Files (x86)/TrustedQSL/";
 #elif defined(Q_OS_MACOS)
       //qDebug() << "macOS DETECTED!: "   << endl;
-    return "/Applications/tqsl.app/Contents/MacOS/";
+    return "/Applications/TrustedQSL/";
 #else
          //qDebug() << "NO WINDOWS/macOS DETECTED!: "   << endl;
     return "/usr/bin/";
@@ -488,7 +516,7 @@ int Utilities::getNormalizedDXCCValue(const int _dxcc)
 {
     if (_dxcc >1000)
     {
-        return ((QString::number(_dxcc)).right(3)).toInt();
+        return ((QString::number(_dxcc)).rightRef(3)).toInt();
     }
     else
     {
@@ -531,233 +559,515 @@ bool Utilities::isValidDateTime(const QString &_d)
     return false;
 }
 
+bool Utilities::isValidSubCall(const QString &_c)
+{
+
+    //qDebug() << "Utilities::isValidSubCall: " << _c << endl;
+    // This functions only checks simple calls like EA4K, not composed like EA4K/F of F/EA4K/QRP
+    //Rules: http://life.itu.int/radioclub/rr/art19.pdf
+    if (_c.contains ('/'))
+    {
+        return false;
+    }
+    if (_c.length()<3)
+    {
+        //qDebug() << "Utilities::isValidSubCall: FALSE-1: " << _c << endl;
+        return false;
+    }
+    if (!(_c.at(_c.length ()-1).isLetter ()))
+    {
+        //qDebug() << "Utilities::isValidSubCall: FALSE-1.1: " << _c << endl;
+        return false;
+    }
+    for (int i = 0; i<_c.length ();i++)
+    {
+        if (!_c.at(i).isLetterOrNumber ())
+        {
+            // Non valid chars
+            return false;
+        }
+    }
+
+    int prefixLength = isAPrefix (_c);
+    if (prefixLength<1)
+    {
+        //qDebug() << "Utilities::isValidSubCall: FALSE-1.2: " << _c << endl;
+        return false;
+    }
+
+    int i = prefixLength;
+    //qDebug() << "Utilities::isValidSubCall: prefixLength" << QString::number(prefixLength) << endl;
+    //qDebug() << "Utilities::isValidSubCall: call" << _c << endl;
+    while(i<_c.length ()-1)
+    {
+        if (!((_c.at(i).isLetter()) ))
+        {
+            //qDebug() << "Utilities::isValidSubCall: FALSE-1.3: " << _c << endl;
+            return false;
+        }
+        i++;
+    }
+    //qDebug() << "Utilities::isValidSubCall: true" << endl;
+    return true;
+}
+
+int Utilities::isAPrefix (const QString &_c)
+{
+    // Returns -1 if it is not a prefix or valid call.
+    // Returns an int with the lenght of the prefix:
+    // The length would be including the number, if possible EA4 or;
+    // including just the country prefix: EA if the number is not included.
+
+    //qDebug() << "Utilities::isAPrefix: " << _c << endl;
+    // Prefixes are at least 1 chars (like in K1K)
+    int length = _c.length ();
+
+    if (length < 1)
+    {
+        //qDebug() << "Utilities::isAPrefix: TOO short prefix - false - END \n";
+        return -1;
+    }
+
+    QString call = _c;
+    //qDebug() << "Utilities::isAPrefix: -10: " << call.at(0) << endl;
+    QChar firstChar = call.at(0);
+    QList<QChar> validFirstLettersOnly = {'B', 'F', 'G', 'I', 'K', 'M', 'N', 'R', 'W'};
+
+    if (length == 1)
+    {
+        if (validFirstLettersOnly.contains (firstChar))
+        {
+            //qDebug() << "Utilities::isAPrefix: VALID 1 letter" << endl;
+            return 1;
+        }
+        else
+        {
+            //qDebug() << "Utilities::isAPrefix: NOT VALID 1 letter" << endl;
+            return -1;
+        }
+    }
+
+    QChar secondChar = call.at(1);
+    //qDebug() << "Utilities::isAPrefix: SecondChar: " << secondChar << endl;
+    int pref = -1;
+    if (call.count(QRegularExpression("\\d")) >0) // Does it has any digit?
+    {
+        //qDebug() << "Utilities::isAPrefix: It has digits: " << call << endl;
+        bool done = false;
+        int i = -1;
+        while ((i < length-1) && !done)
+        {
+            //qDebug() << "Utilities::isAPrefix: in the while: " << QString::number(i) << endl;
+            i++;
+            if (call.at(i).isLetter ())
+            {
+                //qDebug() << "Utilities::isAPrefix: in the while: is a Letter: " << call.at(i) << endl;
+                if (pref>0)
+                {
+                    pref = i;
+                    done = true;
+                }
+            }
+            else
+            {
+                //qDebug() << "Utilities::isAPrefix: in the while: is NOT a Letter: " << call.at(i) << endl;
+                if (i > 0)
+                {
+                    pref = i;
+                }
+            }
+        } // end of while
+    }
+
+    //qDebug() << "Utilities::isAPrefix: After the while: " << QString::number(pref) << endl;
+
+    QString prefix;
+    if (pref>0)
+    {
+         //qDebug() << "Utilities::isAPrefix: pref>0 =>: " << call.left (pref) << endl;
+        prefix = call.left (pref);
+    }
+    else
+    {
+        prefix = call;
+        //qDebug() << "Utilities::isAPrefix: pref<=0 =>: " << call << endl;
+    }
+
+    length = prefix.length();
+
+    QChar thirdChar = QChar();
+    if (length>2)
+    {
+        thirdChar = prefix.at(2);
+    }
+
+    //qDebug() << "Utilities::isAPrefix: -50 "  << endl;
+    // The first two characters shall be two letters or a letter followed
+    // by a digit or a digit followed by a letter. The first two characters or in certain cases
+    // the first character of a call sign constitute the nationality identification
+
+    if (firstChar.isDigit() && secondChar.isDigit())
+    {
+        //qDebug() << "Utilities::isAPrefix: FALSE-6: " << prefix << endl;
+        return -1;
+    }
+
+    //qDebug() << "Utilities::isAPrefix: -60 "  << endl;
+    if (firstChar.isLetter() && secondChar.isLetter() && thirdChar.isLetter())
+    {
+        //qDebug() << "Utilities::isAPrefix: FALSE-6: " << prefix << endl;
+        return -1;
+    }
+
+    //qDebug() << "Utilities::isAPrefix: -70 "  << endl;
+
+    QList<QChar> validFirstLetters = {'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'P', 'R', 'S', 'T' ,'U', 'V', 'W', 'Z'};
+
+    if (secondChar.isDigit ())
+    {
+        if (!validFirstLetters.contains (firstChar))
+        {
+            //qDebug() << "Utilities::isAPrefix: NOT VALID 1 letter not valid" << endl;
+            return -1;
+        }
+    }
+    /*
+     // The following if is to manage not format but specific IARU callsign assignments
+     // defined here: http://life.itu.int/radioclub/rr/ap42.pdf
+     // For the time being, KLog will not check that
+    if ( (firstChar.isLetter ()) && (secondChar.isDigit ()) && (validFirstLetters.contains(firstChar)))
+    {
+        //qDebug() << "Utilities::isAPrefix validFirstLetters contains the first one!" << endl;
+        if (firstChar == 'C')
+        {
+            if ((secondChar == '1') || (secondChar == '7'))
+            {
+                //qDebug() << "Utilities::isAPrefix: FALSE-7.1: " << prefix << endl;
+                return false;
+            }
+        }
+        if (firstChar == 'D')
+        {
+            //((secondChar == '1') || (secondChar == '8'))
+            if (false)
+            {
+                //qDebug() << "Utilities::isAPrefix: FALSE-7.2: " << prefix << endl;
+                return false;
+            }
+        }
+        if (firstChar == 'E')
+        {
+            if (!(secondChar == '2') && !(secondChar == '3') && !(secondChar == '4') && !(secondChar == '7')
+            {
+                //qDebug() << "Utilities::isAPrefix: FALSE-7.3: " << prefix << endl;
+                return false;
+            }
+        }
+        if (firstChar == 'H')
+        {
+            if ((secondChar == '1') )
+            {
+                //qDebug() << "Utilities::isAPrefix: FALSE-7.4: " << prefix << endl;
+                return false;
+            }
+        }
+        if (firstChar == 'J')
+        {
+            if ((secondChar == '1') || (secondChar == '9'))
+            {
+                //qDebug() << "Utilities::isAPrefix: FALSE-7.5: " << prefix << endl;
+                return false;
+            }
+        }
+        if (firstChar == 'P')
+        {
+            if (secondChar == '1')
+            {
+                //qDebug() << "Utilities::isAPrefix: FALSE-7.6: " << prefix << endl;
+                return false;
+            }
+        }
+        if (firstChar == 'S')
+        {
+            if ((secondChar == '1') || (secondChar == '6'))
+            {
+                //qDebug() << "Utilities::isAPrefix: FALSE-7.7: " << prefix << endl;
+                return false;
+            }
+        }
+        if (firstChar == 'T')
+        {
+            if (secondChar == '0')
+            {
+                //qDebug() << "Utilities::isAPrefix: FALSE-7.8: " << prefix << endl;
+                return false;
+            }
+        }
+        if (firstChar == 'V')
+        {
+            if ((secondChar == '1') || (secondChar == '9'))
+            {
+                //qDebug() << "Utilities::isAPrefix: FALSE-7.9: " << prefix << endl;
+                return false;
+            }
+        }
+        if (firstChar == 'Z')
+        {
+            if (!((secondChar == '2') || (secondChar == '3')))
+            {
+                //qDebug() << "Utilities::isAPrefix: FALSE-7.10: " << prefix << endl;
+                return false;
+            }
+        }
+        //qDebug() << "Utilities::isAPrefix: 1-Letter + number prefix valid: " << prefix << endl;
+    }
+    */
+    //qDebug() << "Utilities::isAPrefix: After the if's"  << endl;
+    // It seems to be a valid prefix, let's count how many chars belong to the prefix, first letter after the digit
+    // should be the suffix starting point
+
+    //qDebug() << "Utilities::isAPrefix: Prefix length: " << QString::number(pref) << "/" << prefix << endl;
+    if (pref>0)
+    {
+        return pref;
+    }
+    else
+    {
+        return prefix.length ();
+    }
+}
+
 bool Utilities::isValidCall(const QString &_c)
 {
     //qDebug() << "Utilities::isValidCall: " << _c << endl;
-    //Rules: http://life.itu.int/radioclub/rr/art19.pdf
+    // Prefixes are at least 2 chars
+    QString call = _c;
     if (_c.length()<3)
     {
         //qDebug() << "Utilities::isValidCall: FALSE-1: " << _c << endl;
         return false;
     }
 
-    if ( !(_c.at(0).isLetterOrNumber()) )
+    call.replace('\\', '/');
+
+    if (call.count('/')>2)
     {
-        //qDebug() << "Utilities::isValidCall: FALSE-2: " << _c << endl;
+        //qDebug() << "Utilities::isValidCall: FALSE-3: " << call << endl;
         return false;
     }
-
-
-    QString call = _c;
-    //qDebug() << "Utilities::isValidCall: -10 "  << endl;
-    if ((call.contains('/')) || (call.contains('\\')))
-    {
-        call.replace('\\', '/');
-        if (call.count('/')>2)
-        {
-            //qDebug() << "Utilities::isValidCall: FALSE-3: " << call << endl;
-            return false;
-        }
-
+    if (call.count('/') == 2)
+    { //Things like F/EA4K/P will become F/EA4K
+        //qDebug() << "Utilities::isValidCall: Two /; Ignoring the last part: " << call << endl;
         QStringList parts;
         parts.clear();
         parts << call.split('/');
+        call = parts.at(0) + "/" + parts.at(1);
+    }
+    //qDebug() << "Utilities::isValidCall: Call: " << call << endl;
 
-        if ((parts.at(0)).length()==(parts.at(1)).length())
+    if (call.count('/') == 1)
+    { // Complex calls (like F/EA4K or EA4K/F OR /p OR /qrp
+      // We are just checking the call format not if it belongs to a country or whatever.
+      // It may return true for wrong calls like "ABC/EA4K"
+      // TODO: Add a check just for prefixes to fix the previous
+        //qDebug() << "Utilities::isValidCall: Call with one /: " << call << endl;
+        QStringList parts;
+        parts.clear();
+        parts << call.split ('/');
+
+        //return ( ((isAPrefix (parts.at (0)))>0) || ((isAPrefix (parts.at (1)))>0) || (isValidSubCall (parts.at(0)) ) || (isValidSubCall (parts.at(1)) ));
+
+
+        if (parts.at(0).length ()<parts.at(1).length ())
         {
-            if ((((parts.at(0)).back()).isLetter()) && !(((parts.at(1)).back()).isLetter()))
+            return ( ((isAPrefix (parts.at (0)))>0) && (isValidSubCall (parts.at(1)) ) );
+        }
+        else
+        { //Both lenght are just the same or the second is showter, we need to check both parts and return true if one is valid
+          // It may happen that we have a EA4K/QRP or EA4K/F or EA4K/TTT
+            return isValidSubCall (parts.at(0));
+        }
+    }
+    return isValidSubCall (call);
+}
+
+QString Utilities::getPrefixFromCall(const QString &_c)
+{
+    //qDebug() << "Utilities::getPrefixFromCall: " << _c << endl;
+
+    QString call = _c;
+    call.replace('\\', '/');
+
+    if (call.count('/') == 2)
+    { //Things like F/EA4K/P will become F/EA4K
+        QStringList parts;
+        parts.clear();
+        parts << call.split('/');
+        call = parts.at(0) + "/" + parts.at(1);
+    }
+
+    QString prefix = QString();
+    int pref = -1;
+    if (call.count('/') == 1)
+    { // Complex calls (like F/EA4K or EA4K/F OR /p OR /qrp
+
+        QStringList parts;
+        parts.clear();
+        parts << call.split ('/');
+        if (parts.at(0).length ()<parts.at(1).length ())
+        { // First one is shorter
+            //qDebug() << "Utilities::getPrefixFromCall: First one is shorter: " << endl;
+            int pref = isAPrefix (parts.at(0));
+            if (pref>0)
             {
-                call = parts.at(0);
+                //qDebug() << "Utilities::getPrefixFromCall: R1=" << call.left (pref) << endl;
+                return parts.at(0);
             }
             else
             {
-                call = parts.at(1);
+                //qDebug() << "Utilities::getPrefixFromCall: EMPTY-2"  << endl;
+                return QString();
             }
         }
-        else if ((parts.at(0)).length()>(parts.at(1)).length())
-        {
-            call = parts.at(0);
-            if (parts.length()>2)
+        else if(parts.at(0).length ()>parts.at(1).length ())
+        { // Second one is shorter
+            //qDebug() << "Utilities::getPrefixFromCall: Second one is shorter: " << endl;
+            pref = isAPrefix (parts.at(1));
+            if (pref>0)
             {
-                if( (parts.at(2)).length() > call.length() )
-                {
-                    call = parts.at(2);
-                }
-            }
-        }
-        else
-        {
-            call = parts.at(1);
-            if (parts.length()>2)
-            {
-                if( (parts.at(2)).length() > call.length() )
-                {
-                    call = parts.at(2);
-                }
-            }
-        }
-    }
-    //qDebug() << "Utilities::isValidCall: -20 "  << endl;
-    for (int i=0; i<call.length(); i++)
-    {
-        //qDebug() << "Utilities::isValidCall: FOR: " << call << "/" << call.at(i)  << endl;
-        if (( !(call.at(i).isLetterOrNumber()) ) && !(call.at(i) != "/"))
-        {
-            //qDebug() << "Utilities::isValidCall: FALSE-4 " << call << endl;
-            return false;
-        }
-    }
+                //qDebug() << "Utilities::getPrefixFromCall: R2=" << parts.at(1) << endl;
 
-   /*
-    if ((call.back()).isDigit())
-    {
-        //qDebug() << "Utilities::isValidCall: FALSE-3 " << call << endl;
-        return false;
-    }
- */
-    //qDebug() << "Utilities::isValidCall: -30 "  << endl;
-    QChar firstChar = call.at(0);
-    QChar secondChar = call.at(1);
-    QChar thirdChar = call.at(2);
-
-    if ((call.length() == 3) && ( thirdChar.isDigit()))
-    {
-        //qDebug() << "Utilities::isValidCall: FALSE-5: " << call << endl;
-        return false;
-    }
-
-    // The first two characters shall be two letters or a letter followed
-    // by a digit or a digit followed by a letter. The first two characters or in certain cases
-    // the first character of a call sign constitute the nationality identification4
-
-    if (firstChar.isDigit() && secondChar.isDigit())
-    {
-        //qDebug() << "Utilities::isValidCall: FALSE-6: " << call << endl;
-        return false;
-    }
-
-    if (firstChar.isLetter() && secondChar.isLetter() && thirdChar.isLetter())
-    {
-          //qDebug() << "Utilities::isValidCall: FALSE-6: " << call << endl;
-        return false;
-    }
-
-    QList<QChar> validFirstLetters = {'A', 'B', 'C', 'D', 'E', 'F', 'G', 'I', 'H', 'J', 'K', 'L', 'M', 'N', 'P', 'R', 'S', 'T' ,'U', 'V', 'W', 'Z'};
-
-    if ((firstChar.isLetter()) && (secondChar.isDigit()) && (!validFirstLetters.contains(firstChar)) )
-    {
-        if (validFirstLetters.contains(firstChar))
-        {
-            if (firstChar == 'C')
-            {
-                if ((secondChar == '1') || (secondChar == '7'))
-                {
-                      //qDebug() << "Utilities::isValidCall: FALSE-7.1: " << call << endl;
-                    return false;
-                }
+                return parts.at(1);
             }
-            if (firstChar == 'D')
+            else
             {
-                if ((secondChar == '5') )
+                pref = isAPrefix (parts.at(0));
+                if (pref>0)
                 {
-                      //qDebug() << "Utilities::isValidCall: FALSE-7.2: " << call << endl;
-                    return false;
+                    //qDebug() << "Utilities::getPrefixFromCall: R3=" << parts.at(0).left (pref) << endl;
+                    return parts.at(0).left (pref);
                 }
-            }
-            if (firstChar == 'E')
-            {
-                if (!(secondChar == '2') && !(secondChar == '3') && !(secondChar == '4'))
+                else
                 {
-                      //qDebug() << "Utilities::isValidCall: FALSE-7.3: " << call << endl;
-                    return false;
-                }
-            }
-            if (firstChar == 'H')
-            {
-                if ((secondChar == '1') )
-                {
-                      //qDebug() << "Utilities::isValidCall: FALSE-7.4: " << call << endl;
-                    return false;
-                }
-            }
-            if (firstChar == 'J')
-            {
-                if ((secondChar == '1') || (secondChar == '9'))
-                {
-                      //qDebug() << "Utilities::isValidCall: FALSE-7.5: " << call << endl;
-                    return false;
-                }
-            }
-            if (firstChar == 'P')
-            {
-                if (secondChar == '1')
-                {
-                      //qDebug() << "Utilities::isValidCall: FALSE-7.6: " << call << endl;
-                    return false;
-                }
-            }
-            if (firstChar == 'S')
-            {
-                if ((secondChar == '1') || (secondChar == '6'))
-                {
-                      //qDebug() << "Utilities::isValidCall: FALSE-7.7: " << call << endl;
-                    return false;
-                }
-            }
-            if (firstChar == 'T')
-            {
-                if (secondChar == '0')
-                {
-                      //qDebug() << "Utilities::isValidCall: FALSE-7.8: " << call << endl;
-                    return false;
-                }
-            }
-            if (firstChar == 'V')
-            {
-                if ((secondChar == '1') || (secondChar == '9'))
-                {
-                      //qDebug() << "Utilities::isValidCall: FALSE-7.9: " << call << endl;
-                    return false;
-                }
-            }
-            if (firstChar == 'Z')
-            {
-                if (!(secondChar == '2') && !(secondChar == '3'))
-                {
-                      //qDebug() << "Utilities::isValidCall: FALSE-7.10: " << call << endl;
-                    return false;
+                    //qDebug() << "Utilities::getPrefixFromCall: EMPTY-3"  << endl;
+                    return QString();
                 }
             }
 
         }
         else
-        {
-              //qDebug() << "Utilities::isValidCall: FALSE-8: " << call << endl;
-            return false;
+        { //Both lenght are just the same, we need to check both parts and return true if one is valid
+            //qDebug() << "Utilities::getPrefixFromCall: Same length, we shoudl consider the first one if valid, if not the second one " << endl;
         }
-
-          //qDebug() << "Utilities::isValidCall: FALSE-9: " << call << endl;
-        return false;
     }
 
+    pref = isAPrefix (call);
+    if (pref>0)
+    {
+        //qDebug() << "Utilities::getPrefixFromCall: R4=" << call.left (pref) << endl;
+        return call.left (pref);
+    }
+    //qDebug() << "Utilities::getPrefixFromCall: EMPTY-4"  << endl;
+    return QString();
+}
 
-    //Amateur and experimental stations19.68
-    //1) –one  character
-    // (provided  that  it  is  the  letter  B,  F,  G,  I,  K,  M,  N,  R  or  W)
-    // and  a  single  digit,
-    // followed  by  a  group  of  not  more  than  four  characters,
-    // the last of which shall be a letter,
+/*
+QPair<QString, QString> Utilities::getCallParts(const QString &_c)
+{ // DXCC prefix, if different from original, full call
 
+    QString call = _c;
+    QPair<QString, QString> pair;
+    pair.first = QString();
+    pair.second = QString();
 
-    //2) or–two characters and a single digit,
-    // followed by a group of not more than four characters, the last of which shall be a letter.
+    if (_c.length()<3)
+    {
+        //qDebug() << "Utilities::isValidCall: FALSE-1: " << _c << endl;
+        return pair;
+    }
 
-    // 5(WRC-03)19.68A1A)   On special occasions, for temporary use, administrations may authorize
-    // use of call signs with more than the four characters referred to in No. 19.68.(WRC-03
+    call.replace('\\', '/');
 
+    if (call.count('/')>2)
+    {
+        //qDebug() << "Utilities::isValidCall: FALSE-3: " << call << endl;
+        return pair;
+    }
+    if (call.count('/') == 2)
+    { //Things like F/EA4K/P will become F/EA4K
+        QStringList parts;
+        parts.clear();
+        parts << call.split('/');
+        call = parts.at(0)+parts.at(1);
+    }
+    QString prefix = QString();
 
-    //qDebug() << "Utilities::isValidCall: TRUE: " << call << endl;
-    return true;
+    if (call.count('/') == 1)
+    { // Complex calls (like F/EA4K or EA4K/F OR /p OR /qrp
+        QStringList parts;
+        parts.clear();
+        parts << call.split('/');
+        //qDebug() << "Utilities::isValidCall: first: " << parts.at(0) << endl;
+        //qDebug() << "Utilities::isValidCall: second: " << parts.at(1) << endl;
+
+        QStringList validSuffixes = {"P", "M", "MM", "QRP", "1", "2", "3", "4", "5", "6", "7", "8", "9", "0"};
+        if (validSuffixes.contains (parts.at(1)))
+        {
+            //qDebug() << "Utilities::isValidCall: returning a result just with: " << parts.at(1) << endl;
+            pair.second = parts.at(1);
+            return pair;
+        }
+
+        if (parts.at(0).length ()<=parts.at(1).length ())
+        {
+            if (isAPrefix (parts.at(0))>0)
+            //if (isAPrefix (parts.at(0)))
+            {
+                //qDebug() << "Utilities::isValidCall: first is shorter " << endl;
+                pair.first = parts.at(0);
+                pair.second = parts.at(1);
+            }
+            else
+            {
+                //qDebug() << "Utilities::isValidCall: first is shorter but not a prefix" << endl;
+                return pair;
+            }
+        }
+        else
+        {
+             //qDebug() << "Utilities::isValidCall: second is shorter " << endl;
+             if (isAPrefix (parts.at(1))>0)
+             {
+
+                 pair.first = parts.at(1);
+                 pair.second = parts.at(0);
+             }
+             else
+             {
+                 //qDebug() << "Utilities::isValidCall: second is shorter but not a prefix" << endl;
+                 return pair;
+             }
+        }
+    }
+    return pair;
+}
+*/
+
+bool Utilities::isSameFreq(const double fr1, const double fr2)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << QString::number(fr1) << "/" << QString::number(fr2) << " = " << QString::number(fabs(fr1 - fr2)) << endl;
+
+    if (fabs(fr1 - fr2) < 0.001)
+    {
+        //qDebug() << Q_FUNC_INFO << " - true" << endl;
+        return true;
+    }
+    else
+    {
+        //qDebug() << Q_FUNC_INFO << " - false" << endl;
+        return false;
+    }
+    //return fabs(fr1 - fr2) < 0.001;
 }
 
 bool Utilities::isValidBandId(const int _b)
@@ -975,6 +1285,17 @@ bool Utilities::isValidQSL_Sent(const QString &c)
     }
 }
 
+bool Utilities::isValidUpload_Status(const QString &c)
+{
+    if ((c == "Y") | (c == "N") | (c == "M"))
+    {
+        return true;
+    }
+    else {
+        return false;
+    }
+}
+
 QStringList Utilities::getValidADIFFieldAndData(const QString &_b)
 {
    //qDebug() << "Utilities::getValidADIFFieldAndData: " << _b << endl;
@@ -1084,7 +1405,7 @@ QString Utilities::getAValidCall (const QString &_wrongCall)
     {
 
         //qDebug() << "Utilities::getAValidCall (Don't have VALID CALL): " << _wrongCall << endl;
-        _confirmedCall = QString(QObject::tr("A wrong call has been found: %1. Please enter a new call or confirm that the current one is a good call.")).arg(_wrongCall);
+        _confirmedCall = QString(QObject::tr("A wrong callsign has been found: %1. Please enter a new callsign or confirm that the current one is a good callsign.")).arg(_wrongCall);
     }
     else
     {
@@ -1109,7 +1430,6 @@ QString Utilities::getAValidCall (const QString &_wrongCall)
     return _confirmedCall;
 }
 
-
 QString Utilities::getDateTimeSQLiteStringFromDateTime(const QDateTime &_d)
 {
     return QString(_d.toString("yyyy-MM-dd hh:mm:ss"));
@@ -1135,6 +1455,18 @@ bool Utilities::isValidDateTimeFromString(const QString &_s)
     return getDateTimeFromSQLiteString(_s).isValid();
 }
 
+bool Utilities::isValidDXCC(const int _d)
+{//TODO: Look for a better way to check, taking into account how KLog is identifiying the DXCC
+    if (((_d > 0) && (_d < 523))  || (_d == 1206) || (_d == 1279) || (_d == 1248) || (_d == 2248) || (_d == 1259) || (_d == 1390))
+    {
+        return true;
+    }
+    else
+    {
+        return false;
+    }
+}
+
 QDateTime Utilities::getDateTimeFromSQLiteString(const QString &_s)
 {
     return QDateTime::fromString(_s, "yyyy-MM-dd hh:mm:ss");
@@ -1286,6 +1618,12 @@ QString Utilities::getOnlineServiceName(OnLineProvider _service)
     }
     return QString();
 }
+
+QString Utilities::getClearSQLi(QString _s)
+{
+    return _s.remove ('\'');
+}
+
 /*
 QPalette Utilities::getPalete(bool _ok)
 {
@@ -1303,3 +1641,20 @@ QPalette Utilities::getPalete(bool _ok)
     }
 }
 */
+
+void Utilities::setDarkMode(const QString _dm)
+{
+    darkMode = trueOrFalse(_dm);
+}
+
+bool Utilities::isDarkMode()
+{
+    if (darkMode)
+    {
+        return true;
+    }
+    else
+    {
+        return false;
+    }
+}
