@@ -22,7 +22,7 @@
  *    GNU General Public License for more details.                           *
  *                                                                           *
  *    You should have received a copy of the GNU General Public License      *
- *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.          *
+ *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
 /*
@@ -37,17 +37,16 @@
 #include <QPalette>
 #include "locator.h"
 #include <QtDebug>
-
-enum ExportMode {ModeLotW, ModeADIF, ModeClubLog, ModeEQSL, ModeQRZ};
-enum OnLineProvider {ClubLog, LoTW, eQSL, QRZ}; //, HamQTH, HRDLog
-enum OnlineErrorCode {Ok, Fail};
-enum OnlineErrorReason {Other, Auth, DupeQSO, WrongLogBook};
+#include "klogdefinitions.h"
 
 class Utilities
 {
 public:
     Utilities();
     ~Utilities();
+    void setDarkMode(const QString _dm);
+    bool isDarkMode();
+    bool darkMode;
     int getProgresStepForDialog(int totalSteps);
     bool trueOrFalse(const QString &_s); // reads a String and return true if s.upper()== TRUE :-)
     QChar boolToCharToSQLite(const bool _b);
@@ -75,7 +74,7 @@ public:
     QString getClubLogFile();
     QString getEQSLFile();
     QString getLoTWAdifFile();
-
+    QString getClearSQLi(QString _s);
     void setVersion(const QString &_v);
     QString getVersion();
     double getVersionDouble();
@@ -89,6 +88,7 @@ public:
     bool isValidDateTime(const QString &_d);
     bool isValidCall(const QString &_c);
 
+    bool isSameFreq(const double fr1, const double fr2);
     bool isValidBandId(const int _b);
     bool isValidModeId(const int _m);
     bool isValidFreq(const QString &_b);
@@ -100,13 +100,16 @@ public:
     bool isValidADIFField(const QString &_b);
     bool isValidQSL_Rcvd(const QString &c);
     bool isValidQSL_Sent(const QString &c);
+    bool isValidUpload_Status(const QString &c);
 
     bool isValidTimeFromString(const QString &_s);
     bool isValidDateFromString(const QString &_s);
     bool isValidDateTimeFromString(const QString &_s);
-
+    bool isValidDXCC(const int _d);
     QStringList getValidADIFFieldAndData(const QString &_b);
     QString getAValidCall (const QString &_wrongCall);
+    QString getPrefixFromCall(const QString &_c);
+    //QString getPrefixFromFullCall(const QString &_c);
 
     // Write DATE/TIME to DB
     QString getDateTimeSQLiteStringFromDateTime(const QDateTime &_d);
@@ -139,6 +142,11 @@ public:
 private:
     bool processConfigLine(const QString &_line);
     QString getKLogDefaultDatabaseFile();
+    int isAPrefix(const QString &_c);
+    bool isValidSubCall(const QString &_c);
+    //QPair<QString, QString> getCallParts(const QString &_c);
+
+
     QString dbPath;
     QString softwareVersion;
     //QPalette palRed, palBlack;
